@@ -20,7 +20,7 @@ import org.basex.util.list.*;
 /**
  * Abstract class for performing REST operations.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 abstract class RESTCmd extends Command {
@@ -40,6 +40,7 @@ abstract class RESTCmd extends Command {
     super(max(session.cmds));
     this.session = session;
     cmds = session.cmds;
+    job().type(RESTText.REST);
   }
 
   @Override
@@ -79,26 +80,30 @@ abstract class RESTCmd extends Command {
 
   /**
    * Runs the specified command.
-   * @param c command
+   * @param cmd command
    * @return string result
    * @throws HTTPException HTTP exception
    */
-  final String run(final Command c) throws HTTPException {
+  final String run(final Command cmd) throws HTTPException {
     final ArrayOutput ao = new ArrayOutput();
-    run(c, ao);
+    run(cmd, ao);
     return ao.toString();
   }
 
   /**
    * Runs the specified command.
-   * @param c command
+   * @param cmd command
    * @param os output stream
    * @throws HTTPException HTTP exception
    */
-  final void run(final Command c, final OutputStream os) throws HTTPException {
-    final boolean ok = c.run(context, os);
-    error(c.info());
-    if(!ok) throw HTTPCode.BAD_REQUEST_X.get(c.info());
+  final void run(final Command cmd, final OutputStream os) throws HTTPException {
+    try {
+      final boolean ok = pushJob(cmd).run(context, os);
+      error(cmd.info());
+      if(!ok) throw HTTPCode.BAD_REQUEST_X.get(cmd.info());
+    } finally {
+      popJob();
+    }
   }
 
   /**
