@@ -20,7 +20,7 @@ import com.vividsolutions.jts.io.gml2.*;
 /**
  * This module contains geo spatial functions for the Geo module.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Masoumeh Seydi
  */
 public final class Geo extends QueryModule {
@@ -30,19 +30,19 @@ public final class Geo extends QueryModule {
   private static final byte[] GML = token("gml");
 
   /** QName gml:Point. */
-  private static final QNm Q_GML_POINT = QNm.get(GML, "Point", URI);
+  private static final QNm Q_GML_POINT = new QNm(GML, "Point", URI);
   /** QName gml:MultiPoint. */
-  private static final QNm Q_GML_MULTIPOINT = QNm.get(GML, "MultiPoint", URI);
+  private static final QNm Q_GML_MULTIPOINT = new QNm(GML, "MultiPoint", URI);
   /** QName gml:LineString. */
-  private static final QNm Q_GML_LINESTRING = QNm.get(GML, "LineString", URI);
+  private static final QNm Q_GML_LINESTRING = new QNm(GML, "LineString", URI);
   /** QName gml:LinearRing. */
-  private static final QNm Q_GML_LINEARRING = QNm.get(GML, "LinearRing", URI);
+  private static final QNm Q_GML_LINEARRING = new QNm(GML, "LinearRing", URI);
   /** QName gml:Polygon. */
-  private static final QNm Q_GML_POLYGON = QNm.get(GML, "Polygon", URI);
+  private static final QNm Q_GML_POLYGON = new QNm(GML, "Polygon", URI);
   /** QName gml:MultiPolygon. */
-  private static final QNm Q_GML_MULTIPOLYGON = QNm.get(GML, "MultiPolygon", URI);
+  private static final QNm Q_GML_MULTIPOLYGON = new QNm(GML, "MultiPolygon", URI);
   /** QName gml:MultiLineString. */
-  private static final QNm Q_GML_MULTILINESTRING = QNm.get(GML, "MultiLineString", URI);
+  private static final QNm Q_GML_MULTILINESTRING = new QNm(GML, "MultiLineString", URI);
 
   /** Array containing all QNames. */
   private static final QNm[] QNAMES = {
@@ -56,7 +56,7 @@ public final class Geo extends QueryModule {
    * @return dimension
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Int dimension(final ANode node) throws QueryException {
     return Int.get(checkGeo(node).getDimension());
   }
@@ -67,9 +67,9 @@ public final class Geo extends QueryModule {
    * @return geometry type
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public QNm geometryType(final ANode node) throws QueryException {
-    return QNm.get(GML, checkGeo(node).getGeometryType(), URI);
+    return new QNm(GML, checkGeo(node).getGeometryType(), URI);
   }
 
   /**
@@ -78,7 +78,7 @@ public final class Geo extends QueryModule {
    * @return integer value of CRS of the geometry
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Uri srid(final ANode node) throws QueryException {
     return Uri.uri(token(checkGeo(node).getSRID()));
   }
@@ -90,9 +90,9 @@ public final class Geo extends QueryModule {
    * @return envelop element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode envelope(final ANode node) throws QueryException {
-    return gmlWriter(checkGeo(node).getEnvelope());
+    return toElement(checkGeo(node).getEnvelope());
   }
 
   /**
@@ -101,7 +101,7 @@ public final class Geo extends QueryModule {
    * @return Well-Known Text geometry representation
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Str asText(final ANode node) throws QueryException {
     return Str.get(new WKTWriter().write(checkGeo(node)));
   }
@@ -112,7 +112,7 @@ public final class Geo extends QueryModule {
    * @return Well-Known Binary geometry representation
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public B64 asBinary(final ANode node) throws QueryException {
     return new B64(new WKBWriter().write(checkGeo(node)));
   }
@@ -123,7 +123,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln isEmpty(final ANode node) throws QueryException {
     if(node == null) return Bln.FALSE;
     checkGeo(node);
@@ -137,7 +137,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln isSimple(final ANode node) throws QueryException {
     return Bln.get(checkGeo(node).isSimple());
   }
@@ -149,9 +149,9 @@ public final class Geo extends QueryModule {
    * @return boundary element (geometry)
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode boundary(final ANode node) throws QueryException {
-    return gmlWriter(checkGeo(node).getBoundary());
+    return toElement(checkGeo(node).getBoundary());
   }
 
   /**
@@ -161,7 +161,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln equals(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -175,7 +175,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln disjoint(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -189,7 +189,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln intersects(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -203,7 +203,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln touches(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -217,7 +217,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln crosses(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -231,7 +231,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln within(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -245,7 +245,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln contains(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -259,7 +259,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln overlaps(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -276,12 +276,16 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln relate(final ANode node1, final ANode node2, final Str intersectionMatrix)
       throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
-    return Bln.get(geo1.relate(geo2, intersectionMatrix.toJava()));
+    try {
+      return Bln.get(geo1.relate(geo2, intersectionMatrix.toJava()));
+    } catch(final IllegalArgumentException ex) {
+      throw GeoErrors.illegalArg(intersectionMatrix);
+    }
   }
 
   /**
@@ -293,7 +297,7 @@ public final class Geo extends QueryModule {
    * @return distance double value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Dbl distance(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
@@ -309,9 +313,9 @@ public final class Geo extends QueryModule {
    * @return buffer geometry as gml element
    * @throws QueryException query exception
    */
-  @Deterministic
-  public ANode buffer(final ANode node, final Dbl distance) throws QueryException {
-    return gmlWriter(checkGeo(node).buffer(distance.dbl()));
+  @Deterministic @Requires(Permission.NONE)
+  public ANode buffer(final ANode node, final ANum distance) throws QueryException {
+    return toElement(checkGeo(node).buffer(distance.dbl()));
   }
 
   /**
@@ -321,9 +325,9 @@ public final class Geo extends QueryModule {
    * @return convex hull geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode convexHull(final ANode node) throws QueryException {
-    return gmlWriter(checkGeo(node).convexHull());
+    return toElement(checkGeo(node).convexHull());
   }
 
   /**
@@ -333,11 +337,11 @@ public final class Geo extends QueryModule {
    * @return intersection geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode intersection(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
-    return gmlWriter(geo1.intersection(geo2));
+    return toElement(geo1.intersection(geo2));
   }
 
   /**
@@ -347,11 +351,11 @@ public final class Geo extends QueryModule {
    * @return union geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode union(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
-    return gmlWriter(geo1.union(geo2));
+    return toElement(geo1.union(geo2));
   }
 
   /**
@@ -362,11 +366,11 @@ public final class Geo extends QueryModule {
    * @return difference geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode difference(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
-    return gmlWriter(geo1.difference(geo2));
+    return toElement(geo1.difference(geo2));
   }
 
   /**
@@ -377,11 +381,11 @@ public final class Geo extends QueryModule {
    * @return symmetric difference geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode symDifference(final ANode node1, final ANode node2) throws QueryException {
     final Geometry geo1 = checkGeo(node1);
     final Geometry geo2 = checkGeo(node2);
-    return gmlWriter(geo1.symDifference(geo2));
+    return toElement(geo1.symDifference(geo2));
   }
 
   /**
@@ -391,7 +395,7 @@ public final class Geo extends QueryModule {
    * @return integer value of number of geometries
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Int numGeometries(final ANode node) throws QueryException {
     return Int.get(checkGeo(node).getNumGeometries());
   }
@@ -404,12 +408,12 @@ public final class Geo extends QueryModule {
    * @return geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode geometryN(final ANode node, final Int number) throws QueryException {
     final Geometry geo = checkGeo(node);
     final long n = number.itr();
     if(n < 1 || n > geo.getNumGeometries()) throw GeoErrors.outOfRangeIdx(number);
-    return gmlWriter(geo.getGeometryN((int) n - 1));
+    return toElement(geo.getGeometryN((int) n - 1));
   }
 
   /**
@@ -418,7 +422,7 @@ public final class Geo extends QueryModule {
    * @return x double value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Dbl x(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Point", Q_GML_POINT);
     return Dbl.get(geo.getCoordinate().x);
@@ -430,7 +434,7 @@ public final class Geo extends QueryModule {
    * @return y double value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Dbl y(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Point", Q_GML_POINT);
     return Dbl.get(geo.getCoordinate().y);
@@ -442,7 +446,7 @@ public final class Geo extends QueryModule {
    * @return z double value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Dbl z(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Point", Q_GML_POINT);
     return Dbl.get(geo.getCoordinate().z);
@@ -455,7 +459,7 @@ public final class Geo extends QueryModule {
    * @return length double value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Dbl length(final ANode node) throws QueryException {
     return Dbl.get(checkGeo(node).getLength());
   }
@@ -466,10 +470,10 @@ public final class Geo extends QueryModule {
    * @return start point geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode startPoint(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Line", Q_GML_LINEARRING, Q_GML_LINESTRING);
-    return gmlWriter(((LineString) geo).getStartPoint());
+    return toElement(((LineString) geo).getStartPoint());
   }
 
   /**
@@ -478,10 +482,10 @@ public final class Geo extends QueryModule {
    * @return end point geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode endPoint(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Line", Q_GML_LINEARRING, Q_GML_LINESTRING);
-    return gmlWriter(((LineString) geo).getEndPoint());
+    return toElement(((LineString) geo).getEndPoint());
   }
 
   /**
@@ -491,7 +495,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln isClosed(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Line",
         Q_GML_LINEARRING, Q_GML_LINESTRING, Q_GML_MULTILINESTRING);
@@ -506,7 +510,7 @@ public final class Geo extends QueryModule {
    * @return boolean value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Bln isRing(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Line", Q_GML_LINEARRING, Q_GML_LINESTRING);
     return Bln.get(((LineString) geo).isRing());
@@ -518,7 +522,7 @@ public final class Geo extends QueryModule {
    * @return number of points int value
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Int numPoints(final ANode node) throws QueryException {
     return Int.get(checkGeo(node).getNumPoints());
   }
@@ -530,14 +534,13 @@ public final class Geo extends QueryModule {
    * @return n-th point as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode pointN(final ANode node, final Int number) throws QueryException {
     final Geometry geo = geo(node, "Line", Q_GML_LINEARRING, Q_GML_LINESTRING);
     final int max = geo.getNumPoints();
     final long n = number.itr();
     if(n < 1 || n > max) throw GeoErrors.outOfRangeIdx(number);
-
-    return gmlWriter(((LineString) geo).getPointN((int) n - 1));
+    return toElement(((LineString) geo).getPointN((int) n - 1));
   }
 
   /**
@@ -547,7 +550,7 @@ public final class Geo extends QueryModule {
    * @return geometry area as a double vaue
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Dbl area(final ANode node) throws QueryException {
     return Dbl.get(checkGeo(node).getArea());
   }
@@ -559,9 +562,9 @@ public final class Geo extends QueryModule {
    * @return centroid geometry as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode centroid(final ANode node) throws QueryException {
-    return gmlWriter(checkGeo(node).getCentroid());
+    return toElement(checkGeo(node).getCentroid());
   }
 
   /**
@@ -571,9 +574,9 @@ public final class Geo extends QueryModule {
    * @return a point as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode pointOnSurface(final ANode node) throws QueryException {
-    return gmlWriter(checkGeo(node).getInteriorPoint());
+    return toElement(checkGeo(node).getInteriorPoint());
   }
 
   /**
@@ -582,10 +585,10 @@ public final class Geo extends QueryModule {
    * @return exterior ring geometry (LineString) as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode exteriorRing(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Polygon", Q_GML_POLYGON);
-    return gmlWriter(((Polygon) geo).getExteriorRing());
+    return toElement(((Polygon) geo).getExteriorRing());
   }
 
   /**
@@ -594,7 +597,7 @@ public final class Geo extends QueryModule {
    * @return integer number of interior rings
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public Int numInteriorRing(final ANode node) throws QueryException {
     final Geometry geo = geo(node, "Polygon", Q_GML_POLYGON);
     return Int.get(((Polygon) geo).getNumInteriorRing());
@@ -607,13 +610,13 @@ public final class Geo extends QueryModule {
    * @return n-th interior ring geometry (LineString) as a gml element
    * @throws QueryException query exception
    */
-  @Deterministic
+  @Deterministic @Requires(Permission.NONE)
   public ANode interiorRingN(final ANode node, final Int number) throws QueryException {
     final Geometry geo = geo(node, "Polygon", Q_GML_POLYGON);
     final long n = number.itr();
     final int max = ((Polygon) geo).getNumInteriorRing();
     if(n < 1 || n > max) throw GeoErrors.outOfRangeIdx(number);
-    return gmlWriter(((Polygon) geo).getInteriorRingN((int) n - 1));
+    return toElement(((Polygon) geo).getInteriorRingN((int) n - 1));
   }
 
   // PRIVATE METHODS (hidden from user of module) ========================================
@@ -658,10 +661,8 @@ public final class Geo extends QueryModule {
    * @return geometry, or {@code null}
    * @throws QueryException query exception
    */
-  private static Geometry geo(final ANode node, final QNm... names)
-      throws QueryException {
-
-    if(node.type != NodeType.ELM) throw EXPTYPE_X_X_X.get(null, NodeType.ELM, node.type, node);
+  private static Geometry geo(final ANode node, final QNm... names) throws QueryException {
+    if(node.type != NodeType.ELM) throw castError(node, NodeType.ELM, null);
 
     final QNm qname = node.qname();
     for(final QNm geo : names) {
@@ -680,12 +681,12 @@ public final class Geo extends QueryModule {
   }
 
   /**
-   * Writes an geometry and returns a string representation of the geometry.
+   * Writes an geometry and returns a new element.
    * @param geometry geometry
    * @return DBNode database node
    * @throws QueryException exception
    */
-  private DBNode gmlWriter(final Geometry geometry) throws QueryException {
+  private ANode toElement(final Geometry geometry) throws QueryException {
     final String geo;
     try {
       // write geometry and add namespace declaration
@@ -696,8 +697,8 @@ public final class Geo extends QueryModule {
     }
 
     try {
-      final IO io = new IOContent(geo);
-      return new DBNode(MemBuilder.build(new XMLParser(io, queryContext.context.options)));
+      final XMLParser parser = new XMLParser(new IOContent(geo), queryContext.context.options);
+      return new DBNode(MemBuilder.build(parser)).children().next();
     } catch(final IOException ex) {
       throw IOERR_X.get(null, ex);
     }
