@@ -9,7 +9,7 @@ import org.basex.query.value.node.*;
 /**
  * This module contains standard RESTXQ functions.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class Restxq extends QueryModule {
@@ -41,6 +41,13 @@ public final class Restxq extends QueryModule {
     return Uri.uri(http().req.getRequestURI());
   }
 
+  /**
+   * Initializes the RESTXQ module cache.
+   */
+  public void init() {
+    RestXqModules.get().init();
+  }
+
   /**
    * Returns the servlet request instance.
    * @return request
