@@ -16,7 +16,7 @@ import org.xmldb.api.modules.*;
 /**
  * This class tests the XMLDB/API Collection implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 @SuppressWarnings("all")
@@ -316,7 +316,7 @@ public final class CollectionTest extends XMLDBBaseTest {
 
     // the following tests are database specific...
     assertEquals(COLL, coll.getProperty("name"));
-    assertEquals("true", coll.getProperty("chop"));
+    assertEquals("false", coll.getProperty("casesens"));
   }
 
   @Test
