@@ -3,7 +3,6 @@ package org.basex.api.xmldb;
 import static org.basex.core.Text.*;
 
 import org.basex.*;
-import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.core.users.*;
 import org.basex.util.*;
@@ -11,7 +10,7 @@ import org.basex.util.*;
 /**
  * Base class for all XMLDB tests.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Dimitar Popov
  */
 public abstract class XMLDBBaseTest extends SandboxTest {
@@ -39,18 +38,16 @@ public abstract class XMLDBBaseTest extends SandboxTest {
 
   /**
    * Create XMLDB database.
-   * @throws BaseXException exception during database create
    */
-  static void createDB() throws BaseXException {
-    new CreateDB(COLL, DOCPATH + DOC1).execute(context);
-    new Close().execute(context);
+  static void createDB() {
+    execute(new CreateDB(COLL, DOCPATH + DOC1));
+    execute(new Close());
   }
 
   /**
    * Drop XMLDB database.
-   * @throws BaseXException exception during database drop
    */
-  static void dropDB() throws BaseXException {
-    new DropDB(COLL).execute(context);
+  static void dropDB() {
+    execute(new DropDB(COLL));
   }
 }
