@@ -4,12 +4,13 @@ import static org.basex.core.Text.*;
 
 import org.basex.core.*;
 import org.basex.core.users.*;
+import org.basex.data.*;
 import org.basex.util.*;
 
 /**
  * Abstract class for database info.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 abstract class AInfo extends Command {
@@ -31,4 +32,14 @@ abstract class AInfo extends Command {
   static void info(final TokenBuilder tb, final Object key, final Object val) {
     tb.add(' ').add(key.toString()).add(COLS).add(val.toString()).add(NL);
   }
+
+  /**
+   * Formats the specified input.
+   * @param tb token builder
+   * @param prop meta property
+   * @param meta meta data
+   */
+  static void info(final TokenBuilder tb, final MetaProp prop, final MetaData meta) {
+    info(tb, prop.name(), prop.value(meta));
+  }
 }
