@@ -11,7 +11,7 @@ import org.basex.core.users.*;
 /**
  * Evaluates the 'alter password' command and alters the password of a user.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class AlterPassword extends AUser {
@@ -33,7 +33,7 @@ public final class AlterPassword extends AUser {
     final User user = users.get(name);
     if(user == null) return error(UNKNOWN_USER_X, name);
 
-    users.password(user, pass);
+    user.password(pass);
     users.write();
     return info(PW_CHANGED_X, name);
   }
