@@ -2,19 +2,20 @@ package org.basex.core.cmd;
 
 import static org.basex.core.Text.*;
 
+import java.io.*;
+
 import org.basex.core.parse.*;
-import org.basex.core.parse.Commands.Cmd;
-import org.basex.core.parse.Commands.CmdDrop;
-import org.basex.core.parse.Commands.CmdIndex;
+import org.basex.core.parse.Commands.*;
 import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.index.*;
+import org.basex.util.*;
 
 /**
  * Evaluates the 'drop index' command and deletes indexes in the currently
  * opened database.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class DropIndex extends ACreate {
@@ -32,24 +33,29 @@ public final class DropIndex extends ACreate {
     final CmdIndex ci = getOption(CmdIndex.class);
     final IndexType type;
     if(ci == CmdIndex.TEXT) {
-      data.meta.createtext = false;
       type = IndexType.TEXT;
+      data.meta.createtext = false;
     } else if(ci == CmdIndex.ATTRIBUTE) {
-      data.meta.createattr = false;
       type = IndexType.ATTRIBUTE;
+      data.meta.createattr = false;
+    } else if(ci == CmdIndex.TOKEN) {
+      type = IndexType.TOKEN;
+      data.meta.createtoken = false;
     } else if(ci == CmdIndex.FULLTEXT) {
-      if(data.inMemory()) return error(NO_MAINMEM);
-      data.meta.createftxt = false;
       type = IndexType.FULLTEXT;
+      data.meta.createft = false;
     } else {
       return error(UNKNOWN_CMD_X, this);
     }
+    data.meta.names(type, options);
 
     if(!startUpdate()) return false;
     boolean ok = true;
     try {
-      ok = drop(type, data) ? info(INDEX_DROPPED_X_X, type, perf) :
-        error(INDEX_NOT_DROPPED_X, type);
+      drop(type, data);
+      ok = info(INDEX_DROPPED_X_X, type, job().performance);
+    } catch(final IOException ex) {
+      ok = error(Util.message(ex));
     } finally {
       ok &= finishUpdate();
     }
@@ -60,4 +66,16 @@ public final class DropIndex extends ACreate {
   public void build(final CmdBuilder cb) {
     cb.init(Cmd.DROP + " " + CmdDrop.INDEX).args();
   }
+
+  /**
+   * Drops the specified index.
+   * @param type index type
+   * @param data data reference
+   * @throws IOException I/O exception
+   */
+  static void drop(final IndexType type, final Data data) throws IOException {
+    data.meta.dirty = true;
+    data.meta.index(type, false);
+    data.dropIndex(type);
+  }
 }
