@@ -10,7 +10,7 @@ import org.basex.data.*;
 /**
  * Evaluates the 'flush' command and flushes the database buffers.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class Flush extends Command {
@@ -25,7 +25,7 @@ public final class Flush extends Command {
   protected boolean run() {
     final Data data = context.data();
     if(!options.get(MainOptions.AUTOFLUSH)) data.flush(true);
-    return info(DB_FLUSHED_X, data.meta.name, perf);
+    return info(DB_FLUSHED_X, data.meta.name, job().performance);
   }
 
   @Override
