@@ -12,7 +12,7 @@ import org.basex.core.users.*;
 /**
  * Evaluates the 'help' command and returns help on the database commands.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class Help extends Command {
@@ -27,19 +27,19 @@ public final class Help extends Command {
   @Override
   protected boolean run() throws IOException {
     final String key = args[0];
-    if(!key.isEmpty()) {
+    if(key.isEmpty()) {
+      out.println(TRY_SPECIFIC_X);
+      for(final Cmd cmd : Cmd.values()) out.print(cmd.help(false));
+    } else {
       final Cmd cmd = getOption(key, Cmd.class);
       if(cmd == null) return error(UNKNOWN_CMD_X, this);
       out.println(cmd.help(true));
-    } else {
-      out.println(TRY_SPECIFIC_X);
-      for(final Cmd c : Cmd.values()) out.print(c.help(false));
     }
     return true;
   }
 
   @Override
   public void databases(final LockResult lr) {
-    // No locks needed
+    // no locks needed
   }
 }
