@@ -13,7 +13,7 @@ import org.basex.util.*;
 /**
  * Evaluates the 'repo install' command.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Rositsa Shadura
  */
 public final class RepoInstall extends ARepo {
@@ -34,7 +34,7 @@ public final class RepoInstall extends ARepo {
   protected boolean run() {
     try {
       final boolean exists = new RepoManager(context, info).install(args[0]);
-      return info(exists ? PKG_REPLACED_X_X : PKG_INSTALLED_X_X, args[0], perf);
+      return info(exists ? PKG_REPLACED_X_X : PKG_INSTALLED_X_X, args[0], job().performance);
     } catch(final QueryException ex) {
       return error(Util.message(ex));
     }
