@@ -13,7 +13,7 @@ import org.basex.io.in.*;
 /**
  * Evaluates the 'retrieve' command and retrieves binary content.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class Retrieve extends ACreate {
@@ -38,7 +38,7 @@ public final class Retrieve extends ACreate {
 
     try(final BufferInput bi = new BufferInput(bin)) {
       for(int b; (b = bi.read()) != -1;) out.write(b);
-      return info(QUERY_EXECUTED_X_X, "", perf);
+      return info(QUERY_EXECUTED_X_X, "", job().performance);
     } catch(final IOException ex) {
       return error(ex.toString());
     }
