@@ -1,15 +1,13 @@
 package org.basex.core.locks;
 
-import org.basex.core.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
 
 /**
  * Result object for databases function.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Jens Erat
- * @see Proc#databases(LockResult)
  */
 public class LockResult {
   /** Read locks. */
