@@ -9,6 +9,7 @@ import org.basex.core.cmd.*;
 import org.basex.data.*;
 import org.basex.gui.dialog.*;
 import org.basex.gui.layout.*;
+import org.basex.gui.text.TextEditor.*;
 import org.basex.gui.view.*;
 import org.basex.gui.view.editor.*;
 import org.basex.io.*;
@@ -23,7 +24,7 @@ import org.basex.util.list.*;
 /**
  * This enumeration encapsulates all commands that are triggered by GUI operations.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public enum GUIMenuCmd implements GUICommand {
@@ -144,7 +145,7 @@ public enum GUIMenuCmd implements GUICommand {
 
     @Override
     public boolean enabled(final GUI gui) {
-      final EditorArea ea = gui.editor == null ? null : gui.editor.getEditor();
+      final EditorArea ea = gui.editor.getEditor();
       return gui.gopts.get(GUIOptions.SHOWEDITOR) && ea != null && (ea.modified() || !ea.opened());
     }
   },
@@ -179,7 +180,7 @@ public enum GUIMenuCmd implements GUICommand {
   C_NEXTERROR(NEXT_ERROR, "% PERIOD", false, false) {
     @Override
     public void execute(final GUI gui) {
-      gui.editor.jumpToError();
+      gui.editor.markError(true);
     }
 
     @Override
@@ -227,6 +228,45 @@ public enum GUIMenuCmd implements GUICommand {
     }
   },
 
+  /** Lower case. */
+  C_LOWERCASE(LOWER_CASE, "% shift L", false, false) {
+    @Override
+    public void execute(final GUI gui) {
+      gui.editor.getEditor().toCase(Case.LOWER);
+    }
+
+    @Override
+    public boolean enabled(final GUI gui) {
+      return gui.gopts.get(GUIOptions.SHOWEDITOR);
+    }
+  },
+
+  /** Upper case. */
+  C_UPPERCASE(UPPER_CASE, "% shift U", false, false) {
+    @Override
+    public void execute(final GUI gui) {
+      gui.editor.getEditor().toCase(Case.UPPER);
+    }
+
+    @Override
+    public boolean enabled(final GUI gui) {
+      return gui.gopts.get(GUIOptions.SHOWEDITOR);
+    }
+  },
+
+  /** Title case. */
+  C_TITLECASE(TITLE_CASE, "% shift T", false, false) {
+    @Override
+    public void execute(final GUI gui) {
+      gui.editor.getEditor().toCase(Case.TITLE);
+    }
+
+    @Override
+    public boolean enabled(final GUI gui) {
+      return gui.gopts.get(GUIOptions.SHOWEDITOR);
+    }
+  },
+
   /** Exits the application. */
   C_EXIT(EXIT, "% Q", false, false) {
     @Override
@@ -850,17 +890,17 @@ public enum GUIMenuCmd implements GUICommand {
 
   /**
    * Constructor.
-   * @param l label of the menu item
-   * @param k shortcut
-   * @param d requires a database to be opened
-   * @param t indicates if this command has two states
+   * @param label label of the menu item
+   * @param key shortcut
+   * @param data requires a database to be opened
+   * @param toggle indicates if this command has two states
    */
-  GUIMenuCmd(final String l, final String k, final boolean d, final boolean t) {
-    label = l;
-    key = k;
-    data = d;
-    toggle = t;
-    shortcut = BaseXLayout.addShortcut(l, k);
+  GUIMenuCmd(final String label, final String key, final boolean data, final boolean toggle) {
+    this.label = label;
+    this.key = key;
+    this.data = data;
+    this.toggle = toggle;
+    shortcut = BaseXLayout.addShortcut(label, key);
   }
 
   @Override
@@ -916,7 +956,6 @@ public enum GUIMenuCmd implements GUICommand {
    * @return function string
    */
   private static String openPre(final DBNodes n, final int i) {
-    return Function._DB_OPEN_PRE.get(null, null, Str.get(n.data().meta.name),
-        Int.get(n.pre(i))).toString();
+    return Function._DB_OPEN_PRE.toString(Str.get(n.data().meta.name), Int.get(n.pre(i)));
   }
 }
