@@ -14,7 +14,7 @@ import org.basex.io.*;
 /**
  * General preferences.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 final class DialogGeneralPrefs extends BaseXBack {
@@ -70,7 +70,7 @@ final class DialogGeneralPrefs extends BaseXBack {
       public void actionPerformed(final ActionEvent e) {
         final String path = dbPath.getText();
         final IOFile dir = new BaseXFileChooser(CHOOSE_DIR, path, gui).select(Mode.DOPEN);
-        if(dir != null) dbPath.setText(dir.dir());
+        if(dir != null) dbPath.setText(dir.path());
       }
     });
 
@@ -80,7 +80,7 @@ final class DialogGeneralPrefs extends BaseXBack {
       public void actionPerformed(final ActionEvent e) {
         final String path = repoPath.getText();
         final IOFile dir = new BaseXFileChooser(CHOOSE_DIR, path, gui).select(Mode.DOPEN);
-        if(dir != null) repoPath.setText(dir.dir());
+        if(dir != null) repoPath.setText(dir.path());
       }
     });
 
@@ -158,8 +158,9 @@ final class DialogGeneralPrefs extends BaseXBack {
   /**
    * Reacts on user input.
    * @param source source
+   * @return success flag
    */
-  void action(final Object source) {
+  boolean action(final Object source) {
     mousefocus.assign();
     simplefd.assign();
 
@@ -183,5 +184,7 @@ final class DialogGeneralPrefs extends BaseXBack {
     creds.setText(TRANSLATION + COLS + creds(lang.getSelectedItem()));
     final int mh = HITS[limit.getValue()];
     label.setText(mh == -1 ? ALL : Integer.toString(mh));
+
+    return true;
   }
 }
