@@ -6,21 +6,21 @@ import java.awt.*;
 import java.io.*;
 
 import org.basex.build.json.*;
-import org.basex.build.json.JsonOptions.*;
+import org.basex.build.json.JsonOptions.JsonFormat;
 import org.basex.core.*;
 import org.basex.core.MainOptions.MainParser;
 import org.basex.gui.*;
 import org.basex.gui.layout.*;
 import org.basex.gui.text.*;
 import org.basex.io.*;
-import org.basex.query.value.node.*;
+import org.basex.io.parse.json.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
 
 /**
  * JSON parser panel.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 final class DialogJsonParser extends DialogParser {
@@ -41,8 +41,8 @@ final class DialogJsonParser extends DialogParser {
   private final BaseXCombo format;
   /** JSON: liberal. */
   private final BaseXCheckBox liberal;
-  /** JSON: unescape. */
-  private final BaseXCheckBox unescape;
+  /** JSON: escape. */
+  private final BaseXCheckBox escape;
   /** JSON: lax name conversion. */
   private final BaseXCheckBox lax;
   /** JSON: merge type information. */
@@ -69,7 +69,7 @@ final class DialogJsonParser extends DialogParser {
     format.setSelectedItem(jopts.get(JsonOptions.FORMAT));
 
     liberal = new BaseXCheckBox(LIBERAL_PARSING, JsonParserOptions.LIBERAL, jopts, d);
-    unescape = new BaseXCheckBox(UNESCAPE_CHARS, JsonParserOptions.UNESCAPE, jopts, d);
+    escape = new BaseXCheckBox(ESCAPE_CHARS, JsonParserOptions.ESCAPE, jopts, d);
     merge = new BaseXCheckBox(MERGE_TYPES, JsonOptions.MERGE, jopts, d);
     strings = new BaseXCheckBox(INCLUDE_STRINGS, JsonOptions.STRINGS, jopts, d);
     lax = new BaseXCheckBox(LAX_NAME_CONVERSION, JsonOptions.LAX, jopts, d);
@@ -84,7 +84,7 @@ final class DialogJsonParser extends DialogParser {
 
     p = new BaseXBack(new TableLayout(5, 1));
     p.add(liberal);
-    p.add(unescape);
+    p.add(escape);
     p.add(merge);
     p.add(strings);
     p.add(lax);
@@ -115,8 +115,8 @@ final class DialogJsonParser extends DialogParser {
         } else {
           json = EXAMPLE;
         }
-        final DBNode node = new DBNode(JsonParser.toXML(new IOContent(json), jopts));
-        example.setText(example(MainParser.JSON.name(), json, node.serialize().toString()));
+        example.setText(example(MainParser.JSON.name(), json,
+            JsonConverter.get(jopts).convert(new IOContent(json)).serialize().toString()));
       }
     } catch(final IOException ex) {
       example.setText(error(ex));
@@ -129,7 +129,7 @@ final class DialogJsonParser extends DialogParser {
     final String enc = encoding.getSelectedItem();
     jopts.set(JsonParserOptions.ENCODING, enc.equals(Strings.UTF8) ? null : enc);
     jopts.set(JsonParserOptions.LIBERAL, liberal.isSelected());
-    jopts.set(JsonParserOptions.UNESCAPE, unescape.isSelected());
+    jopts.set(JsonParserOptions.ESCAPE, escape.isSelected());
     jopts.set(JsonOptions.MERGE, merge.isSelected());
     jopts.set(JsonOptions.STRINGS, strings.isSelected());
     jopts.set(JsonOptions.FORMAT, format.getSelectedItem());
