@@ -9,7 +9,7 @@ import javax.swing.tree.*;
 /**
  * Project specific tree implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public class BaseXTree extends JTree {
@@ -38,7 +38,7 @@ public class BaseXTree extends JTree {
    * @param r right distance
    * @return self reference
    */
-  public BaseXTree border(final int t, final int l, final int b, final int r) {
+  public final BaseXTree border(final int t, final int l, final int b, final int r) {
     setBorder(BaseXLayout.border(t, l, b, r));
     return this;
   }
