@@ -9,7 +9,7 @@ import org.basex.util.list.*;
 /**
  * Returns an iterator for the visualized text.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 final class TextIterator {
@@ -159,8 +159,7 @@ final class TextIterator {
    */
   boolean selectStart() {
     return start != end && (inSelect() ||
-        (start < end ? start >= pos && start < posEnd :
-          end >= pos && end < posEnd));
+        (start < end ? start >= pos && start < posEnd : end >= pos && end < posEnd));
   }
 
   /**
@@ -168,8 +167,7 @@ final class TextIterator {
    * @return result of check
    */
   boolean inSelect() {
-    return start < end ? pos >= start && pos < end :
-      pos >= end && pos < start;
+    return start < end ? pos >= start && pos < end : pos >= end && pos < start;
   }
 
   /**
@@ -222,15 +220,15 @@ final class TextIterator {
 
   /**
    * Retrieves the current hyperlink.
-   * @return link string
+   * @return link string, or {@code null}
    */
   String link() {
     if(!link) return null;
-
     // find beginning and end of link
     int ls = pos, le = ls;
-    while(ls > 0 && text[ls - 1] != TokenBuilder.ULINE) ls--;
-    while(le < length && text[le] != TokenBuilder.ULINE) le++;
+    while(--ls > 0 && (text[ls] < -64 || cp(text, ls) != TokenBuilder.ULINE));
+    while(++le < length && (text[le] < -64 || cp(text, le) != TokenBuilder.ULINE));
+    ls += cl(text, ls);
     return string(text, ls, le - ls);
   }
 }
