@@ -9,38 +9,40 @@ import java.util.*;
 import javax.swing.*;
 import javax.swing.border.*;
 
-import org.basex.core.*;
 import org.basex.gui.*;
 import org.basex.gui.layout.*;
-import org.basex.gui.layout.BaseXFileChooser.Mode;
+import org.basex.gui.layout.BaseXFileChooser.*;
 import org.basex.gui.view.editor.*;
 import org.basex.io.*;
-import org.basex.query.*;
 import org.basex.util.*;
 
 /**
  * Project file tree.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class ProjectView extends BaseXPanel {
+  /** Cached file paths. */
+  final ProjectFiles files = new ProjectFiles();
   /** Root directory. */
   final ProjectDir root;
   /** Tree. */
   final ProjectTree tree;
-  /** Editor view. */
-  final EditorView editor;
-  /** Filter field. */
-  private final ProjectFilter filter;
   /** Filter list. */
   final ProjectList list;
+
+  /** Filter field. */
+  private final ProjectFilter filter;
   /** Root path. */
-  private final BaseXTextField path;
+  private final BaseXTextField rootPath;
   /** Splitter. */
   private final BaseXSplit split;
+
   /** Last focused component. */
   private Component last;
+  /** Indicates if the current project files have been parsed. */
+  private boolean parsed;
 
   /** Remembers the last focused component. */
   final FocusAdapter lastfocus = new FocusAdapter() {
@@ -56,7 +58,6 @@ public final class ProjectView extends BaseXPanel {
    */
   public ProjectView(final EditorView ev) {
     super(ev.gui);
-    editor = ev;
     setLayout(new BorderLayout());
 
     tree = new ProjectTree(this);
@@ -72,9 +73,9 @@ public final class ProjectView extends BaseXPanel {
     back.setBorder(new CompoundBorder(new MatteBorder(0, 0, 1, 0, GUIConstants.gray),
         BaseXLayout.border(3, 1, 3, 2)));
 
-    path = new BaseXTextField(gui);
-    path.setText(root.file.path());
-    path.setEnabled(false);
+    rootPath = new BaseXTextField(gui);
+    rootPath.setText(root.file.path());
+    rootPath.setEnabled(false);
 
     final BaseXButton browse = new BaseXButton(DOTS, gui);
     browse.setMargin(new Insets(0, 2, 0, 2));
@@ -82,11 +83,11 @@ public final class ProjectView extends BaseXPanel {
     browse.addActionListener(new ActionListener() {
       @Override
       public void actionPerformed(final ActionEvent e) {
-        change();
+        changeRoot();
       }
     });
 
-    back.add(path, BorderLayout.CENTER);
+    back.add(rootPath, BorderLayout.CENTER);
     back.add(browse, BorderLayout.EAST);
     back.add(filter, BorderLayout.SOUTH);
 
@@ -110,6 +111,14 @@ public final class ProjectView extends BaseXPanel {
     last = tree;
     tree.addFocusListener(lastfocus);
     list.addFocusListener(lastfocus);
+
+    addComponentListener(new ComponentAdapter() {
+      @Override
+      public void componentResized(final ComponentEvent e) {
+        // trigger parsing of project files
+        refresh(false, false);
+      }
+    });
   }
 
   /**
@@ -121,67 +130,132 @@ public final class ProjectView extends BaseXPanel {
   }
 
   /**
-   * Refreshes the specified file node.
+   * Refreshes the view after a file has been saved.
    * @param file file to be opened
    * @param rename file has been renamed
    */
   public void save(final IOFile file, final boolean rename) {
-    refresh(file);
-    if(rename) reset();
-    refresh();
+    SwingUtilities.invokeLater(new Runnable() {
+      @Override
+      public void run() {
+        final IOFile path = file.normalize();
+        if(path.path().startsWith(root.file.path())) refreshTree(path);
+        refresh(rename, file.hasSuffix(IO.XQSUFFIXES));
+      }
+    });
   }
 
   /**
-   * Refreshes the filter view.
+   * Returns the list of erroneous files.
+   * @return files
+   */
+  public TreeMap<String, InputInfo> errors() {
+    return files.errors();
+  }
+
+  /**
+   * Finds nodes to be highlighted as erroneous and refreshes the tree.
+   */
+  void refreshTree() {
+    // loop through all tree nodes
+    final Set<String> errPaths = files.errors().keySet();
+    final Enumeration<?> en = root.depthFirstEnumeration();
+    while(en.hasMoreElements()) {
+      final ProjectNode node = (ProjectNode) en.nextElement();
+      final IOFile file = node.file;
+      if(file == null) continue;
+
+      final String path = file.path(), dirPath = path + '/';
+      boolean found = false;
+
+      // loop through all erroneous paths
+      for(final String errPath : errPaths) {
+        // check if error path equals node path, or if it is a descendant
+        if(errPath.equals(path) || errPath.startsWith(dirPath)) {
+          found = true;
+          break;
+        }
+      }
+      node.error = found;
+    }
+    repaint();
+  }
+
+  /**
+   * Refreshes the project view.
    */
   void refresh() {
-    filter.refresh(true);
+    refresh(true, true);
   }
 
   /**
-   * Resets the filter cache.
+   * Refreshes the project view.
+   * @param reset invalidate the file cache
+   * @param parse parse
    */
-  void reset() {
-    filter.reset();
+  private void refresh(final boolean reset, final boolean parse) {
+    if(reset) files.reset();
+    filter.refresh(true);
+
+    final boolean parseproj = gui.gopts.get(GUIOptions.PARSEPROJ);
+    if(parseproj && !root.file.eq(new IOFile(Prop.USERHOME)) && (!parsed || parse)) {
+      parsed = false;
+      // do not parse if project view is hidden
+      if(getWidth() == 0) return;
+
+      new GUIWorker<Boolean>() {
+        @Override
+        protected Boolean doInBackground() throws InterruptedException {
+          final Performance perf = new Performance();
+          files.parse(root.file, gui.context);
+          parsed = true;
+          gui.status.setText(PARSING_CC + perf.getTime());
+          return true;
+        }
+        @Override
+        protected void done(final Boolean refresh) {
+          if(refresh) refreshTree();
+        }
+      }.execute();
+    }
   }
 
   /**
    * Jumps to the specified file.
    * @param file file to be focused
+   * @param focus focus tree
    */
-  public void jump(final IOFile file) {
+  public void jumpTo(final IOFile file, final boolean focus) {
     final IOFile fl = file.normalize();
     if(fl.path().startsWith(root.file.path())) tree.expand(root, fl.path());
-    tree.requestFocusInWindow();
+    if(focus) tree.requestFocusInWindow();
   }
 
   /**
-   * Refreshes the visualization of the specified file, or its parent, in the tree.
+   * Refreshes the rendering of the specified file, or its parent, in the tree.
+   * It may possibly be hidden in the current tree.
    * @param file file to be refreshed
    */
-  private void refresh(final IOFile file) {
-    final ProjectNode node = find(file);
+  private void refreshTree(final IOFile file) {
+    final ProjectNode node = find(file.path());
     if(node != null) {
       node.refresh();
     } else {
       final IOFile parent = file.parent();
-      if(parent != null) refresh(parent);
+      if(parent != null) refreshTree(parent);
     }
   }
 
   /**
    * Returns the node for the specified file.
-   * @param file file to be found
+   * @param path path of file to be found
    * @return node or {@code null}
    */
-  private ProjectNode find(final IOFile file) {
-    final IOFile fl = file.normalize();
-    if(fl.path().startsWith(root.file.path())) {
-      final Enumeration<?> en = root.depthFirstEnumeration();
-      while(en.hasMoreElements()) {
-        final ProjectNode node = (ProjectNode) en.nextElement();
-        if(node.file != null && node.file.path().equals(fl.path())) return node;
-      }
+  private ProjectNode find(final String path) {
+    final Enumeration<?> en = root.depthFirstEnumeration();
+    while(en.hasMoreElements()) {
+      final ProjectNode node = (ProjectNode) en.nextElement();
+      if(node.file != null && node.file.path().equals(path)) return node;
     }
     return null;
   }
@@ -191,19 +265,14 @@ public final class ProjectView extends BaseXPanel {
    */
   public void refreshLayout() {
     filter.refreshLayout();
-    root.refresh();
   }
 
   /**
-   * Focuses the project filter.
+   * Finds files with the text selected in the specified editor area.
    * @param ea calling editor
    */
   public void findFiles(final EditorArea ea) {
-    if(isFocusOwner()) {
-      filter.find(tree.selectedNode());
-    } else {
-      filter.find(ea);
-    }
+    filter.find(ea);
   }
 
   /**
@@ -241,43 +310,21 @@ public final class ProjectView extends BaseXPanel {
    * @param search search string
    */
   void open(final IOFile file, final String search) {
-    final EditorArea ea = editor.open(file);
-    if(ea == null) return;
-
-    // delay search and focus request (avoid keyTyped event to be handled in editor)
-    SwingUtilities.invokeLater(new Runnable() {
-      @Override
-      public void run() {
-        ea.jump(search);
-      }
-    });
-  }
-
-  /**
-   * Adds an import statement to the currently edited file.
-   * @param file file to be opened
-   */
-  void addImport(final IOFile file) {
-    final EditorArea edit = editor.getEditor();
-    final Context ctx = gui.context;
-    final String relative = edit.file().parent().relative(file).replace('\\', '/');
-
-    try(final QueryContext qc = new QueryContext(ctx)) {
-      final LibraryModule lm = qc.parseLibrary(file.string(), file.path(), null);
-      final TokenBuilder tmp = new TokenBuilder("import module namespace ");
-      tmp.add(lm.name.string()).add(" = \"").add(lm.name.uri());
-      tmp.add("\" at \"").add(relative).add("\";\n");
-      edit.paste(tmp.toString());
-
-    } catch(final Exception ex) {
-      BaseXDialog.error(gui, Util.message(ex));
+    final EditorArea ea = gui.editor.open(file);
+    if(ea != null) {
+      SwingUtilities.invokeLater(new Runnable() {
+        @Override
+        public void run() {
+          ea.jump(search);
+        }
+      });
     }
   }
 
   /**
-   * Changes the root directory.
+   * Shows a dialog for changing the root directory.
    */
-  private void change() {
+  private void changeRoot() {
     final ProjectNode child = tree.selectedNode();
     final IOFile file = (child != null ? child : root).file;
     final BaseXFileChooser fc = new BaseXFileChooser(CHOOSE_DIR, file.path(), gui);
@@ -295,8 +342,8 @@ public final class ProjectView extends BaseXPanel {
     if(!force && !project.isEmpty()) return;
     root.file = io;
     root.refresh();
-    filter.reset();
-    path.setText(io.path());
+    refresh();
+    rootPath.setText(io.path());
     if(force) {
       gui.gopts.set(GUIOptions.PROJECTPATH, io.path());
       gui.gopts.write();
