@@ -6,12 +6,12 @@ import org.basex.util.*;
 /**
  * This class stores a numeric range for index access.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class NumericRange implements IndexToken {
   /** Index type. */
-  private final boolean text;
+  private final IndexType type;
   /** Minimum value. */
   public final double min;
   /** Maximum value. */
@@ -19,19 +19,19 @@ public final class NumericRange implements IndexToken {
 
   /**
    * Constructor.
-   * @param text text/attribute index
+   * @param type index type
    * @param min minimum value
    * @param max maximum value
    */
-  public NumericRange(final boolean text, final double min, final double max) {
-    this.text = text;
+  public NumericRange(final IndexType type, final double min, final double max) {
+    this.type = type;
     this.min = min;
     this.max = max;
   }
 
   @Override
   public IndexType type() {
-    return text ? IndexType.TEXT : IndexType.ATTRIBUTE;
+    return type;
   }
 
   @Override
