@@ -9,7 +9,7 @@ import org.xml.sax.*;
 /**
  * {@link IO} reference, representing a byte array.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class IOContent extends IO {
@@ -29,7 +29,7 @@ public final class IOContent extends IO {
    * @param content contents
    */
   public IOContent(final String content) {
-    this(Token.token(content), "");
+    this(Token.token(content));
   }
 
   /**
