@@ -6,7 +6,7 @@ import java.io.*;
 
 import org.basex.build.csv.*;
 import org.basex.build.csv.CsvOptions.*;
-import org.basex.core.*;
+import org.basex.core.jobs.*;
 import org.basex.io.*;
 import org.basex.io.in.*;
 import org.basex.query.value.item.*;
@@ -15,10 +15,10 @@ import org.basex.util.list.*;
 /**
  * <p>This class converts CSV input to XML.</p>
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
-public abstract class CsvConverter extends Proc {
+public abstract class CsvConverter extends Job {
   /** CSV token. */
   public static final byte[] CSV = token("csv");
   /** CSV token. */
@@ -57,7 +57,7 @@ public abstract class CsvConverter extends Proc {
    * @return result
    * @throws IOException I/O exception
    */
-  public Item convert(final IO input) throws IOException {
+  public final Item convert(final IO input) throws IOException {
     try(final NewlineInput in = new NewlineInput(input)) {
       nli = in;
       CsvParser.parse(in.encoding(copts.get(CsvParserOptions.ENCODING)), copts, this);
