@@ -3,14 +3,14 @@ package org.basex.io.parse.json;
 /**
  * Fallback function for invalid XML characters.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
-public abstract class JsonFallback {
+public interface JsonFallback {
   /**
    * Converts the specified token.
    * @param string input string
    * @return converted token
    */
-  public abstract String convert(final String string);
+  String convert(final String string);
 }
