@@ -32,7 +32,7 @@ import org.basex.util.*;
  *     <code>{'foo':42, 'bar':()}</code>)
  * </dl>
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 public final class JsonMapConverter extends JsonConverter {
@@ -99,7 +99,7 @@ public final class JsonMapConverter extends JsonConverter {
   }
 
   @Override
-  void closeItem() throws QueryIOException {
+  void closeItem() {
     arrays.peek().add(stack.pop());
   }
 
