@@ -6,7 +6,6 @@ import static org.basex.util.Token.*;
 import java.io.*;
 
 import org.basex.build.csv.*;
-import org.basex.io.out.*;
 import org.basex.io.serial.*;
 import org.basex.query.value.item.*;
 import org.basex.util.*;
@@ -15,7 +14,7 @@ import org.basex.util.list.*;
 /**
  * This class serializes items as CSV.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 abstract class CsvSerializer extends StandardSerializer {
@@ -30,12 +29,12 @@ abstract class CsvSerializer extends StandardSerializer {
 
   /**
    * Constructor.
-   * @param out print output
+   * @param os output stream
    * @param opts serialization parameters
    * @throws IOException I/O exception
    */
-  CsvSerializer(final PrintOutput out, final SerializerOptions opts) throws IOException {
-    super(out, opts);
+  CsvSerializer(final OutputStream os, final SerializerOptions opts) throws IOException {
+    super(os, opts);
     copts = opts.get(SerializerOptions.CSV);
     quotes = copts.get(CsvOptions.QUOTES);
     backslashes = copts.get(CsvOptions.BACKSLASHES);
@@ -47,7 +46,7 @@ abstract class CsvSerializer extends StandardSerializer {
    * @param fields fields to be printed
    * @throws IOException I/O exception
    */
-  void record(final TokenList fields) throws IOException {
+  final void record(final TokenList fields) throws IOException {
     // print fields, skip trailing empty contents
     final int fs = fields.size();
     for(int i = 0; i < fs; i++) {
@@ -70,7 +69,7 @@ abstract class CsvSerializer extends StandardSerializer {
       }
       out.print(txt);
     }
-    newline();
+    out.print('\n');
   }
 
   @Override
