@@ -8,7 +8,7 @@ import org.basex.util.*;
 /**
  * Pragma for database options.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 public final class BaseXPragma extends Pragma {
@@ -22,7 +22,7 @@ public final class BaseXPragma extends Pragma {
   }
 
   @Override
-  void init(final QueryContext qc, final InputInfo info) throws QueryException {
+  void init(final QueryContext qc, final InputInfo info) {
   }
 
   @Override
