@@ -19,15 +19,16 @@ import org.basex.util.*;
 /**
  * Abstract parse expression. All non-value expressions are derived from this class.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public abstract class ParseExpr extends Expr {
   /** Input information. */
   public InputInfo info;
   /** Static type. */
-  protected SeqType seqType;
-  /** Cardinality of result; {@code -1} if unknown. */
+  public SeqType seqType;
+  /** Cardinality of result; {@code -1} if unknown
+   * ({@link #seqType} will then be requested to estimate result size). */
   protected long size = -1;
 
   /**
@@ -53,7 +54,7 @@ public abstract class ParseExpr extends Expr {
     if(n != null) {
       final ValueBuilder vb = new ValueBuilder().add(it).add(n);
       if(ir.next() != null) vb.add(Str.get(DOTS));
-      throw SEQFOUND_X.get(ii, vb.value());
+      throw SEQFOUND_X.get(info, vb.value());
     }
     return it;
   }
@@ -69,13 +70,13 @@ public abstract class ParseExpr extends Expr {
 
   @Override
   public Value atomValue(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return value(qc).atomValue(ii);
+    return value(qc).atomValue(info);
   }
 
   @Override
   public final Item atomItem(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Item it1 = item(qc, ii);
-    return it1 == null ? null : it1.atomItem(ii);
+    final Item it1 = item(qc, info);
+    return it1 == null ? null : it1.atomItem(info);
   }
 
   /**
@@ -103,7 +104,7 @@ public abstract class ParseExpr extends Expr {
         if(n != null) {
           final ValueBuilder vb = new ValueBuilder().add(it).add(n);
           if(ir.next() != null) vb.add(Str.get(DOTS));
-          throw EBV_X.get(ii, vb.value());
+          throw EBV_X.get(info, vb.value());
         }
       }
     }
@@ -128,14 +129,6 @@ public abstract class ParseExpr extends Expr {
 
   // OPTIMIZATIONS ================================================================================
 
-  /**
-   * Assigns a sequence type.
-   * @param type sequence type
-   */
-  public void seqType(final SeqType type) {
-    seqType = type;
-  }
-
   /**
    * Pre-evaluates the specified expression.
    * @param qc query context
@@ -162,7 +155,7 @@ public abstract class ParseExpr extends Expr {
    * @return optimized expression
    */
   protected final Expr optPre(final Expr ex, final QueryContext qc) {
-    if(ex != this) qc.compInfo(OPTPRE, this);
+    if(ex != this) qc.compInfo(OPTPRE_X, this);
     return ex == null ? Empty.SEQ : ex;
   }
 
@@ -172,10 +165,11 @@ public abstract class ParseExpr extends Expr {
    * returned as is. Otherwise, it will be wrapped into a boolean function.
    * @param ex expression to be rewritten
    * @param info input info
+   * @param sc static context
    * @return expression
    */
-  protected static Expr compBln(final Expr ex, final InputInfo info) {
-    return ex.seqType().eq(SeqType.BLN) ? ex : Function.BOOLEAN.get(null, info, ex);
+  protected static Expr compBln(final Expr ex, final InputInfo info, final StaticContext sc) {
+    return ex.seqType().eq(SeqType.BLN) ? ex : Function.BOOLEAN.get(sc, info, ex);
   }
 
   // VALIDITY CHECKS ==============================================================================
@@ -195,31 +189,31 @@ public abstract class ParseExpr extends Expr {
   /**
    * Ensures that none of the specified expressions performs an update.
    * Otherwise, throws an exception.
-   * @param ex expressions (may be {@code null}, and may contain {@code null} references)
+   * @param exprs expressions (may be {@code null}, and may contain {@code null} references)
    * @throws QueryException query exception
    */
-  protected final void checkNoneUp(final Expr... ex) throws QueryException {
-    if(ex == null) return;
-    checkAllUp(ex);
-    for(final Expr e : ex) {
-      if(e != null && e.has(Flag.UPD)) throw UPNOT_X.get(info, description());
+  protected final void checkNoneUp(final Expr... exprs) throws QueryException {
+    if(exprs == null) return;
+    checkAllUp(exprs);
+    for(final Expr expr : exprs) {
+      if(expr != null && expr.has(Flag.UPD)) throw UPNOT_X.get(info, description());
     }
   }
 
   /**
    * Ensures that all specified expressions are vacuous or either updating or non-updating.
    * Otherwise, throws an exception.
-   * @param ex expressions to be checked
+   * @param exprs expressions to be checked
    * @throws QueryException query exception
    */
-  void checkAllUp(final Expr... ex) throws QueryException {
+  void checkAllUp(final Expr... exprs) throws QueryException {
     // updating state: 0 = initial state, 1 = updating, -1 = non-updating
     int s = 0;
-    for(final Expr e : ex) {
-      e.checkUp();
-      if(e.isVacuous()) continue;
-      final boolean u = e.has(Flag.UPD);
-      if(u && s == -1 || !u && s == 1) throw UPALL_X.get(info, description());
+    for(final Expr expr : exprs) {
+      expr.checkUp();
+      if(expr.isVacuous()) continue;
+      final boolean u = expr.has(Flag.UPD);
+      if(u && s == -1 || !u && s == 1) throw UPALL.get(info, description());
       s = u ? 1 : -1;
     }
   }
@@ -257,7 +251,7 @@ public abstract class ParseExpr extends Expr {
    * Returns a value as token or throws an exception.
    * @param ex expression to be evaluated
    * @param qc query context
-   * @return token (empty string if result is empty)
+   * @return token (empty string if result is an empty sequence)
    * @throws QueryException query exception
    */
   protected final byte[] toEmptyToken(final Expr ex, final QueryContext qc)
@@ -276,13 +270,13 @@ public abstract class ParseExpr extends Expr {
   protected final byte[] toToken(final Item it) throws QueryException {
     final Type ip = it.type;
     if(ip.isStringOrUntyped()) return it.string(info);
-    throw it instanceof FItem ? FIATOM_X.get(info, it.type) : castError(info, it, AtomType.STR);
+    throw it instanceof FItem ? FIATOM_X.get(info, it.type) : castError(it, AtomType.STR, info);
   }
 
   /**
    * Checks if the specified expression yields a boolean.
    * Returns the boolean or throws an exception.
-   * @param ex expression to be checked
+   * @param ex expression to be evaluated
    * @param qc query context
    * @return boolean
    * @throws QueryException query exception
@@ -302,14 +296,14 @@ public abstract class ParseExpr extends Expr {
     final Type ip = checkNoEmpty(it, AtomType.BLN).type;
     if(ip == AtomType.BLN) return it.bool(info);
     if(ip.isUntyped()) return Bln.parse(it.string(info), info);
-    throw castError(info, it, AtomType.BLN);
+    throw castError(it, AtomType.BLN, info);
   }
 
 
   /**
    * Checks if the specified expression yields a double.
    * Returns the double or throws an exception.
-   * @param ex expression to be checked
+   * @param ex expression to be evaluated
    * @param qc query context
    * @return double
    * @throws QueryException query exception
@@ -333,7 +327,7 @@ public abstract class ParseExpr extends Expr {
   /**
    * Checks if the specified expression yields a number or {@code null}.
    * Returns the number, {@code null}, or throws an exception.
-   * @param ex expression to be checked
+   * @param ex expression to be evaluated
    * @param qc query context
    * @return double
    * @throws QueryException query exception
@@ -346,8 +340,8 @@ public abstract class ParseExpr extends Expr {
   /**
    * Checks if the specified, non-empty item is a double.
    * Returns the double or throws an exception.
-   * @param it item
-   * @return double
+   * @param it item to be checked
+   * @return number
    * @throws QueryException query exception
    */
   private ANum toNumber(final Item it) throws QueryException {
@@ -359,7 +353,7 @@ public abstract class ParseExpr extends Expr {
   /**
    * Checks if the specified expression yields a float.
    * Returns the float or throws an exception.
-   * @param ex expression to be checked
+   * @param ex expression to be evaluated
    * @param qc query context
    * @return float
    * @throws QueryException query exception
@@ -373,7 +367,7 @@ public abstract class ParseExpr extends Expr {
   /**
    * Checks if the specified expression yields an integer.
    * Returns a token representation or throws an exception.
-   * @param ex expression to be checked
+   * @param ex expression to be evaluated
    * @param qc query context
    * @return integer value
    * @throws QueryException query exception
@@ -392,13 +386,13 @@ public abstract class ParseExpr extends Expr {
   protected final long toLong(final Item it) throws QueryException {
     final Type ip = checkNoEmpty(it, AtomType.ITR).type;
     if(ip.instanceOf(AtomType.ITR) || ip.isUntyped()) return it.itr(info);
-    throw castError(info, it, AtomType.ITR);
+    throw castError(it, AtomType.ITR, info);
   }
 
   /**
    * Checks if the specified expression yields a node.
    * Returns the boolean or throws an exception.
-   * @param ex expression to be checked
+   * @param ex expression to be evaluated
    * @param qc query context
    * @return node
    * @throws QueryException query exception
@@ -410,7 +404,7 @@ public abstract class ParseExpr extends Expr {
   /**
    * Checks if the specified expression yields a node or {@code null}.
    * Returns the node, {@code null}, or throws an exception.
-   * @param ex expression to be checked
+   * @param ex expression to be evaluated
    * @param qc query context
    * @return node or {@code null}
    * @throws QueryException query exception
@@ -421,7 +415,7 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified non-item is a node.
+   * Checks if the specified non-empty item is a node.
    * Returns the node or throws an exception.
    * @param it item to be checked
    * @return node
@@ -429,7 +423,7 @@ public abstract class ParseExpr extends Expr {
    */
   protected final ANode toNode(final Item it) throws QueryException {
     if(it instanceof ANode) return (ANode) it;
-    throw castError(info, it, NodeType.NOD);
+    throw castError(it, NodeType.NOD, info);
   }
 
   /**
@@ -444,19 +438,27 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the evaluated expression yields a non-empty node or item.
+   * Checks if the evaluated expression yields a node or item.
    * Returns the item or throws an exception.
    * @param ex expression to be evaluated
    * @param qc query context
-   * @return item
+   * @return node or atomized item
    * @throws QueryException query exception
    */
   protected final Item toNodeOrAtomItem(final Expr ex, final QueryContext qc)
       throws QueryException {
+    return toNodeOrAtomItem(toItem(ex, qc));
+  }
 
-    Item it = toItem(ex, qc);
-    if(!(it instanceof ANode)) it = it.atomItem(info);
-    return it;
+  /**
+   * Checks if the specified item yields a node or item.
+   * Returns the item or throws an exception.
+   * @param it item to be checked (can be {@code null})
+   * @return node or atomized item
+   * @throws QueryException query exception
+   */
+  protected final Item toNodeOrAtomItem(final Item it) throws QueryException {
+    return it == null || it instanceof ANode ? it : it.atomItem(info);
   }
 
   /**
@@ -578,7 +580,7 @@ public abstract class ParseExpr extends Expr {
    * @throws QueryException query exception
    */
   protected final byte[] toBytes(final Item it) throws QueryException {
-    if(checkNoEmpty(it) instanceof AStr) return it.string(info);
+    if(checkNoEmpty(it).type.isStringOrUntyped()) return it.string(info);
     if(it instanceof Bin) return ((Bin) it).binary(info);
     throw STRBIN_X_X.get(info, it.type, it);
   }
@@ -586,7 +588,7 @@ public abstract class ParseExpr extends Expr {
   /**
    * Checks if the specified expression yields a QName.
    * Returns the item or throws an exception.
-   * @param ex expression to be checked
+   * @param ex expression to be evaluated
    * @param qc query context
    * @param empty allow empty result
    * @return QNm item
@@ -610,7 +612,7 @@ public abstract class ParseExpr extends Expr {
     final Type ip = checkNoEmpty(it, AtomType.QNM).type;
     if(ip == AtomType.QNM) return (QNm) it;
     if(ip.isUntyped()) throw NSSENS_X_X.get(info, ip, AtomType.QNM);
-    throw castError(info, it, AtomType.QNM);
+    throw castError(it, AtomType.QNM, info);
   }
 
   /**
@@ -622,7 +624,7 @@ public abstract class ParseExpr extends Expr {
    * @throws QueryException query exception
    */
   protected FItem toFunc(final Expr ex, final QueryContext qc) throws QueryException {
-    return (FItem) checkType(toItem(ex, qc, FuncType.ANY_FUN), FuncType.ANY_FUN);
+    return (FItem) checkType(toItem(ex, qc, SeqType.ANY_FUN), SeqType.ANY_FUN);
   }
 
   /**
@@ -646,7 +648,7 @@ public abstract class ParseExpr extends Expr {
    */
   protected Map toMap(final Item it) throws QueryException {
     if(it instanceof Map) return (Map) it;
-    throw castError(info, it, SeqType.ANY_MAP);
+    throw castError(it, SeqType.ANY_MAP, info);
   }
 
   /**
@@ -668,7 +670,7 @@ public abstract class ParseExpr extends Expr {
    */
   protected Array toArray(final Item it) throws QueryException {
     if(it instanceof Array) return (Array) it;
-    throw castError(info, it, SeqType.ANY_ARRAY);
+    throw castError(it, SeqType.ANY_ARRAY, info);
   }
 
   /**
@@ -695,7 +697,7 @@ public abstract class ParseExpr extends Expr {
    */
   protected Item checkType(final Item it, final Type type) throws QueryException {
     if(checkNoEmpty(it, type).type.instanceOf(type)) return it;
-    throw castError(info, it, type);
+    throw castError(it, type, info);
   }
 
   /**
