@@ -13,7 +13,6 @@ import org.basex.query.expr.Expr.Flag;
 import org.basex.query.func.admin.*;
 import org.basex.query.func.archive.*;
 import org.basex.query.func.array.*;
-import org.basex.query.func.basex.*;
 import org.basex.query.func.bin.*;
 import org.basex.query.func.client.*;
 import org.basex.query.func.convert.*;
@@ -30,6 +29,7 @@ import org.basex.query.func.html.*;
 import org.basex.query.func.http.*;
 import org.basex.query.func.index.*;
 import org.basex.query.func.inspect.*;
+import org.basex.query.func.jobs.*;
 import org.basex.query.func.json.*;
 import org.basex.query.func.map.*;
 import org.basex.query.func.math.*;
@@ -40,8 +40,10 @@ import org.basex.query.func.random.*;
 import org.basex.query.func.repo.*;
 import org.basex.query.func.sql.*;
 import org.basex.query.func.stream.*;
+import org.basex.query.func.strings.*;
 import org.basex.query.func.unit.*;
 import org.basex.query.func.user.*;
+import org.basex.query.func.util.*;
 import org.basex.query.func.validate.*;
 import org.basex.query.func.web.*;
 import org.basex.query.func.xquery.*;
@@ -59,7 +61,7 @@ import org.basex.util.hash.*;
  * New namespace mappings for function prefixes and URIs must be added to the static initializer of
  * the {@link NSGlobal} class.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public enum Function {
@@ -81,7 +83,7 @@ public enum Function {
   ANALYZE_STRING(FnAnalyzeString.class, "analyze-string(input,pattern[,mod])",
       arg(STR_ZO, STR, STR), ELM, flag(CNS)),
   /** XQuery function. */
-  APPLY(FnApply.class, "apply(function,args)", arg(FUN_O, ARRAY_O), ITEM_ZM),
+  APPLY(FnApply.class, "apply(function,args)", arg(FUN_O, ARRAY_O), ITEM_ZM, flag(HOF)),
   /** XQuery function. */
   AVAILABLE_ENVIRONMENT_VARIABLES(FnAvailableEnvironmentVariables.class,
       "available-environment-variables()", arg(), STR_ZM),
@@ -99,7 +101,7 @@ public enum Function {
   /** XQuery function. */
   CODEPOINTS_TO_STRING(FnCodepointsToString.class, "codepoints-to-string(nums)", arg(ITR_ZM), STR),
   /** XQuery function. */
-  COLLECTION(FnCollection.class, "collection([uri])", arg(STR_ZO), NOD_ZM),
+  COLLECTION(FnCollection.class, "collection([uri])", arg(STR_ZO), DOC_ZM),
   /** XQuery function. */
   COMPARE(FnCompare.class, "compare(first,second[,collation])", arg(STR_ZO, STR_ZO, STR), ITR_ZO),
   /** XQuery function. */
@@ -133,6 +135,8 @@ public enum Function {
   /** XQuery function. */
   DEFAULT_COLLATION(FnDefaultCollation.class, "default-collation()", arg(), STR),
   /** XQuery function. */
+  DEFAULT_LANGUAGE(FnDefaultLanguage.class, "default-language()", arg(), LAN),
+  /** XQuery function. */
   DISTINCT_VALUES(FnDistinctValues.class, "distinct-values(items[,collation])",
       arg(AAT_ZM, STR), AAT_ZM),
   /** XQuery function. */
@@ -239,7 +243,7 @@ public enum Function {
   /** XQuery function. */
   IRI_TO_URI(FnIriToUri.class, "iri-to-uri(string)", arg(STR_ZO), STR),
   /** XQuery function. */
-  JSON_DOC(FnJsonDoc.class, "json-doc(uri[,options])", arg(STR_ZO, ITEM), DOC_ZO),
+  JSON_DOC(FnJsonDoc.class, "json-doc(uri[,options])", arg(STR_ZO, MAP_O), DOC_ZO),
   /** XQuery function. */
   LANG(FnLang.class, "lang(ids[,node])", arg(STR_ZO, NOD), BLN),
   /** XQuery function. */
@@ -307,11 +311,12 @@ public enum Function {
   /** XQuery function. */
   XML_TO_JSON(FnXmlToJson.class, "xml-to-json(node[,options])", arg(NOD_ZO, MAP_O), STR_ZO),
   /** XQuery function. */
-  PARSE_JSON(FnParseJson.class, "parse-json(string[,options])", arg(STR_ZO, ITEM), ITEM_ZO),
+  PARSE_JSON(FnParseJson.class, "parse-json(string[,options])", arg(STR_ZO, MAP_O), ITEM_ZO),
   /** XQuery function. */
   PARSE_XML(FnParseXml.class, "parse-xml(string)", arg(STR_ZO), DOC_O, flag(CNS)),
   /** XQuery function. */
-  PARSE_XML_FRAGMENT(FnParseXmlFragment.class, "parse-xml-fragment(string)", arg(STR_ZO), DOC_ZO),
+  PARSE_XML_FRAGMENT(FnParseXmlFragment.class, "parse-xml-fragment(string)", arg(STR_ZO), DOC_ZO,
+      flag(CNS)),
   /** XQuery function. */
   PATH(FnPath.class, "path([node])", arg(NOD_ZO), STR_ZO),
   /** XQuery function. */
@@ -319,12 +324,12 @@ public enum Function {
   /** XQuery function. */
   PREFIX_FROM_QNAME(FnPrefixFromQName.class, "prefix-from-QName(qname)", arg(QNM_ZO), NCN_ZO),
   /** XQuery function. */
-  PUT(FnPut.class, "put(node,uri)", arg(NOD, STR_ZO), EMP, flag(UPD, NDT)),
+  PUT(FnPut.class, "put(node,uri)", arg(NOD, STR_ZO), EMP, flag(UPD)),
   /** XQuery function. */
   QNAME(FnQName.class, "QName(uri,name)", arg(STR_ZO, STR), QNM),
   /** XQuery function. */
   RANDOM_NUMBER_GENERATOR(FnRandomNumberGenerator.class, "random-number-generator([seed])",
-      arg(AAT), MAP_O, flag(NDT)),
+      arg(AAT), MAP_O),
   /** XQuery function. */
   REMOVE(FnRemove.class, "remove(items,pos)", arg(ITEM_ZM, ITR), ITEM_ZM),
   /** XQuery function. */
@@ -364,7 +369,7 @@ public enum Function {
   /** XQuery function. */
   STRING(FnString.class, "string([item])", arg(ITEM_ZO), STR),
   /** XQuery function. */
-  STRING_JOIN(FnStringJoin.class, "string-join(strings[,sep])", arg(STR_ZM, STR), STR),
+  STRING_JOIN(FnStringJoin.class, "string-join(items[,sep])", arg(ITEM_ZM, STR), STR),
   /** XQuery function. */
   STRING_LENGTH(FnStringLength.class, "string-length([string])", arg(STR_ZO), ITR),
   /** XQuery function. */
@@ -437,7 +442,7 @@ public enum Function {
   /** XQuery function. */
   _MAP_CONTAINS(MapContains.class, "contains(map,key)", arg(MAP_O, AAT), BLN, MAP_URI),
   /** XQuery function. */
-  _MAP_REMOVE(MapRemove.class, "remove(map,key)", arg(MAP_O, AAT), MAP_O, MAP_URI),
+  _MAP_REMOVE(MapRemove.class, "remove(map,keys)", arg(MAP_O, AAT_ZM), MAP_O, MAP_URI),
   /** XQuery function. */
   _MAP_SIZE(MapSize.class, "size(map)", arg(MAP_O), ITR, MAP_URI),
   /** XQuery function. */
@@ -445,8 +450,6 @@ public enum Function {
   /** XQuery function. */
   _MAP_FOR_EACH(MapForEach.class, "for-each(map,function)",
       arg(MAP_O, FuncType.get(ITEM_ZM, AAT, ITEM_ZM).seqType()), ITEM_ZM, flag(HOF), MAP_URI),
-  /** XQuery function. */
-  _MAP_SERIALIZE(MapSerialize.class, "serialize(map)", arg(MAP_O), STR, MAP_URI),
 
   /* Array Module. */
 
@@ -461,7 +464,10 @@ public enum Function {
   _ARRAY_SUBARRAY(ArraySubarray.class, "subarray(array,pos[,length])", arg(ARRAY_O, ITR, ITR),
       ARRAY_O, ARRAY_URI),
   /** XQuery function. */
-  _ARRAY_REMOVE(ArrayRemove.class, "remove(array,pos)", arg(ARRAY_O, ITR), ARRAY_O, ARRAY_URI),
+  _ARRAY_REMOVE(ArrayRemove.class, "remove(array,pos)", arg(ARRAY_O, ITR_ZM), ARRAY_O, ARRAY_URI),
+  /** XQuery function. */
+  _ARRAY_PUT(ArrayPut.class, "put(array,pos,member)", arg(ARRAY_O, ITR, ITEM_ZM),
+      ARRAY_O, ARRAY_URI),
   /** XQuery function. */
   _ARRAY_INSERT_BEFORE(ArrayInsertBefore.class, "insert-before(array,pos,value)",
       arg(ARRAY_O, ITR, ITEM_ZO), ARRAY_O, ARRAY_URI),
@@ -497,8 +503,6 @@ public enum Function {
   /** XQuery function. */
   _ARRAY_SORT(ArraySort.class, "sort(array[,key-func])",
       arg(ARRAY_O, FuncType.arity(1).seqType()), ARRAY_O, flag(HOF), ARRAY_URI),
-  /** XQuery function. */
-  _ARRAY_SERIALIZE(ArraySerialize.class, "serialize(array)", arg(ARRAY_O), STR, ARRAY_URI),
 
   /* Math Module. */
 
@@ -559,10 +563,10 @@ public enum Function {
 
   /** XQuery function. */
   _ARCHIVE_CREATE(ArchiveCreate.class, "create(entries,contents[,options])",
-      arg(ITEM_ZM, ITEM_ZM, ITEM), B64, ARCHIVE_URI),
+      arg(ITEM_ZM, ITEM_ZM, MAP_O), B64, ARCHIVE_URI),
   /** XQuery function. */
   _ARCHIVE_CREATE_FROM(ArchiveCreateFrom.class, "create-from(path[,options[,entries]])",
-      arg(STR, ITEM, ITEM_ZM), EMP, ARCHIVE_URI),
+      arg(STR, MAP_O, ITEM_ZM), EMP, ARCHIVE_URI),
   /** XQuery function. */
   _ARCHIVE_ENTRIES(ArchiveEntries.class, "entries(archive)", arg(B64), ELM_ZM, ARCHIVE_URI),
   /** XQuery function. */
@@ -581,23 +585,7 @@ public enum Function {
   _ARCHIVE_DELETE(ArchiveDelete.class, "delete(archive,entries)",
       arg(B64, ITEM_ZM), B64, ARCHIVE_URI),
   /** XQuery function. */
-  _ARCHIVE_OPTIONS(ArchiveOptions.class, "options(archive)", arg(B64), ELM, ARCHIVE_URI),
-  /** XQuery function (deprecated). */
-  @Deprecated _ARCHIVE_WRITE(ArchiveWrite.class, "write(path,archive[,entries])",
-      arg(STR, B64, ITEM_ZM), EMP, ARCHIVE_URI),
-
-  /* BaseX Module. */
-
-  /** XQuery function. */
-  _BASEX_DEEP_EQUAL(BaseXDeepEqual.class, "deep-equal(items1,items2[,options])",
-      arg(ITEM_ZM, ITEM_ZM, ITEM), BLN, BASEX_URI),
-  /** XQuery function. */
-  _BASEX_ITEM_AT(BaseXItemAt.class, "item-at(items,pos)", arg(ITEM_ZM, DBL), ITEM_ZO, BASEX_URI),
-  /** XQuery function. */
-  _BASEX_ITEM_RANGE(BaseXItemRange.class, "item-range(items,first,last)",
-      arg(ITEM_ZM, DBL, DBL), ITEM_ZM, BASEX_URI),
-  /** XQuery function. */
-  _BASEX_LAST_FROM(BaseXLastFrom.class, "last-from(items)", arg(ITEM_ZM), ITEM_ZO, BASEX_URI),
+  _ARCHIVE_OPTIONS(ArchiveOptions.class, "options(archive)", arg(B64), MAP_O, ARCHIVE_URI),
 
   /* Binary Module. */
 
@@ -680,7 +668,7 @@ public enum Function {
   _CLIENT_INFO(ClientInfo.class, "info(id)", arg(URI), STR, flag(NDT), CLIENT_URI),
   /** XQuery function. */
   _CLIENT_QUERY(ClientQuery.class, "query(id,query[,bindings])",
-      arg(URI, STR, ITEM), ITEM_ZO, flag(NDT), CLIENT_URI),
+      arg(URI, STR, MAP_ZO), ITEM_ZO, flag(NDT), CLIENT_URI),
   /** XQuery function. */
   _CLIENT_CLOSE(ClientClose.class, "close(id)", arg(URI), EMP, flag(NDT), CLIENT_URI),
 
@@ -693,11 +681,11 @@ public enum Function {
   _CONVERT_INTEGER_FROM_BASE(ConvertIntegerFromBase.class, "integer-from-base(string,base)",
       arg(STR, ITR), ITR, CONVERT_URI),
   /** XQuery function. */
-  _CONVERT_BINARY_TO_BYTES(ConvertBinaryToBytes.class, "binary-to-bytes(binary)", arg(ITEM), BYT_ZM,
-      CONVERT_URI),
+  _CONVERT_BINARY_TO_BYTES(ConvertBinaryToBytes.class, "binary-to-bytes(binary)",
+      arg(AAT), BYT_ZM, CONVERT_URI),
   /** XQuery function. */
-  _CONVERT_BINARY_TO_STRING(ConvertBinaryToString.class, "binary-to-string(binary[,encoding])",
-      arg(ITEM, STR), STR, CONVERT_URI),
+  _CONVERT_BINARY_TO_STRING(ConvertBinaryToString.class,
+      "binary-to-string(binary[,encoding[,fallback]])", arg(ITEM, STR, BLN), STR, CONVERT_URI),
   /** XQuery function. */
   _CONVERT_BYTES_TO_HEX(ConvertBytesToHex.class, "bytes-to-hex(bytes)", arg(BYT_ZM), HEX,
       CONVERT_URI),
@@ -753,77 +741,81 @@ public enum Function {
   /* Database Module. */
 
   /** XQuery function. */
-  _DB_OPEN(DbOpen.class, "open(database[,path])", arg(STR, STR), NOD_ZM, DB_URI),
+  _DB_OPEN(DbOpen.class, "open(database[,path])", arg(STR, STR), DOC_ZM, DB_URI),
   /** XQuery function. */
   _DB_OPEN_PRE(DbOpenPre.class, "open-pre(database,pre)", arg(STR, ITR), NOD_ZM, DB_URI),
   /** XQuery function. */
   _DB_OPEN_ID(DbOpenId.class, "open-id(database,id)", arg(STR, ITR), NOD_ZM, DB_URI),
   /** XQuery function. */
-  _DB_TEXT(DbText.class, "text(database,string)", arg(STR, ITEM), NOD_ZM, flag(NDT), DB_URI),
+  _DB_TEXT(DbText.class, "text(database,string)", arg(STR, ITEM), TXT_ZM, flag(NDT), DB_URI),
   /** XQuery function. */
   _DB_TEXT_RANGE(DbTextRange.class, "text-range(database,from,to)",
-      arg(STR, ITEM, ITEM), NOD_ZM, flag(NDT), DB_URI),
+      arg(STR, ITEM, ITEM), TXT_ZM, flag(NDT), DB_URI),
   /** XQuery function. */
   _DB_ATTRIBUTE(DbAttribute.class, "attribute(database,string[,name])",
-      arg(STR, ITEM, STR), NOD_ZM, flag(NDT), DB_URI),
+      arg(STR, ITEM, STR), ATT_ZM, flag(NDT), DB_URI),
   /** XQuery function. */
   _DB_ATTRIBUTE_RANGE(DbAttributeRange.class, "attribute-range(database,from,to[,name])",
-      arg(STR, ITEM, ITEM, STR), NOD_ZM, flag(NDT), DB_URI),
+      arg(STR, ITEM, ITEM, STR), ATT_ZM, flag(NDT), DB_URI),
+  /** XQuery function. */
+  _DB_TOKEN(DbToken.class, "token(database,string[,name])",
+      arg(STR, ITEM, STR), ATT_ZM, flag(NDT), DB_URI),
   /** XQuery function. */
   _DB_LIST(DbList.class, "list([database[,path]])", arg(STR, STR), STR_ZM, flag(NDT), DB_URI),
   /** XQuery function. */
-  _DB_LIST_DETAILS(DbListDetails.class, "list-details([database[,path]])", arg(STR, STR), ELM_ZM,
-      flag(NDT), DB_URI),
+  _DB_LIST_DETAILS(DbListDetails.class, "list-details([database[,path]])",
+      arg(STR, STR), ELM_ZM, flag(NDT), DB_URI),
   /** XQuery function. */
   _DB_BACKUPS(DbBackups.class, "backups([database])", arg(ITEM), ELM_ZM, DB_URI),
   /** XQuery function. */
-  _DB_CREATE_BACKUP(DbCreateBackup.class, "create-backup(database)", arg(STR), EMP,
-      flag(UPD, NDT), DB_URI),
+  _DB_CREATE_BACKUP(DbCreateBackup.class, "create-backup(database)",
+      arg(STR), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
-  _DB_COPY(DbCopy.class, "copy(database, new-name)", arg(STR, STR), EMP, flag(UPD, NDT),
-      DB_URI),
+  _DB_COPY(DbCopy.class, "copy(database, new-name)", arg(STR, STR), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
-  _DB_ALTER(DbAlter.class, "alter(database, new-name)", arg(STR, STR), EMP, flag(UPD, NDT), DB_URI),
+  _DB_ALTER(DbAlter.class, "alter(database, new-name)", arg(STR, STR), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
-  _DB_DROP_BACKUP(DbDropBackup.class, "drop-backup(name)", arg(STR), EMP, flag(UPD, NDT), DB_URI),
+  _DB_DROP_BACKUP(DbDropBackup.class, "drop-backup(name)", arg(STR), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
-  _DB_RESTORE(DbRestore.class, "restore(backup)", arg(STR), EMP, flag(UPD, NDT), DB_URI),
+  _DB_RESTORE(DbRestore.class, "restore(backup)", arg(STR), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
   _DB_SYSTEM(DbSystem.class, "system()", arg(), STR, DB_URI),
   /** XQuery function. */
-  _DB_INFO(DbInfo.class, "info(database)", arg(ITEM), STR, DB_URI),
+  _DB_INFO(DbInfo.class, "info(database)", arg(STR), STR, DB_URI),
+  /** XQuery function. */
+  _DB_PROPERTY(DbProperty.class, "property(database,name)", arg(STR, STR), ITEM, DB_URI),
   /** XQuery function. */
   _DB_NODE_ID(DbNodeId.class, "node-id(nodes)", arg(NOD_ZM), ITR_ZM, DB_URI),
   /** XQuery function. */
   _DB_NODE_PRE(DbNodePre.class, "node-pre(nodes)", arg(NOD_ZM), ITR_ZM, DB_URI),
   /** XQuery function. */
-  _DB_OUTPUT(DbOutput.class, "output(result)", arg(ITEM_ZM), EMP, flag(UPD, NDT), DB_URI),
+  _DB_OUTPUT(DbOutput.class, "output(result)", arg(ITEM_ZM), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
   _DB_OUTPUT_CACHE(DbOutputCache.class, "output-cache()", arg(), ITEM_ZO, flag(NDT), DB_URI),
   /** XQuery function. */
   _DB_ADD(DbAdd.class, "add(database,input[,path[,options]])",
-      arg(STR, NOD, STR, ITEM), EMP, flag(UPD, NDT), DB_URI),
+      arg(STR, NOD, STR, MAP_O), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
-  _DB_DELETE(DbDelete.class, "delete(database,path)", arg(STR, STR), EMP, flag(UPD, NDT), DB_URI),
+  _DB_DELETE(DbDelete.class, "delete(database,path)", arg(STR, STR), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
   _DB_CREATE(DbCreate.class, "create(name[,inputs[,paths[,options]]])",
-      arg(STR, ITEM_ZM, STR_ZM, ITEM), EMP, flag(UPD, NDT), DB_URI),
+      arg(STR, ITEM_ZM, STR_ZM, MAP_O), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
-  _DB_DROP(DbDrop.class, "drop(database)", arg(ITEM), EMP, flag(UPD, NDT), DB_URI),
+  _DB_DROP(DbDrop.class, "drop(database)", arg(ITEM), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
   _DB_RENAME(DbRename.class, "rename(database,path,new-path)", arg(STR, STR, STR), EMP,
-      flag(UPD, NDT), DB_URI),
+      flag(UPD), DB_URI),
   /** XQuery function. */
   _DB_REPLACE(DbReplace.class, "replace(database,path,input[,options])",
-      arg(STR, STR, ITEM, ITEM), EMP, flag(UPD, NDT), DB_URI),
+      arg(STR, STR, ITEM, MAP_O), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
   _DB_OPTIMIZE(DbOptimize.class, "optimize(database[,all[,options]])",
-      arg(STR, BLN, ITEM), EMP, flag(UPD, NDT), DB_URI),
+      arg(STR, BLN, MAP_O), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
   _DB_RETRIEVE(DbRetrieve.class, "retrieve(database,path)", arg(STR, STR), B64, flag(NDT), DB_URI),
   /** XQuery function. */
-  _DB_STORE(DbStore.class, "store(database,path,input)", arg(STR, STR, ITEM), EMP, flag(UPD, NDT),
-      DB_URI),
+  _DB_STORE(DbStore.class, "store(database,path,input)",
+      arg(STR, STR, ITEM), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
   _DB_IS_XML(DbIsXml.class, "is-xml(database,path)", arg(STR, STR), BLN, DB_URI),
   /** XQuery function. */
@@ -833,10 +825,10 @@ public enum Function {
   /** XQuery function. */
   _DB_CONTENT_TYPE(DbContentType.class, "content-type(database,path)", arg(STR, STR), STR, DB_URI),
   /** XQuery function. */
-  _DB_FLUSH(DbFlush.class, "flush(database)", arg(ITEM), EMP, flag(UPD, NDT), DB_URI),
+  _DB_FLUSH(DbFlush.class, "flush(database)", arg(ITEM), EMP, flag(UPD), DB_URI),
   /** XQuery function. */
-  _DB_EXPORT(DbExport.class, "export(database,path[,param]])", arg(STR, STR, ITEM), EMP, flag(NDT),
-      DB_URI),
+  _DB_EXPORT(DbExport.class, "export(database,path[,param]])",
+      arg(STR, STR, ITEM), EMP, flag(NDT), DB_URI),
   /** XQuery function. */
   _DB_NAME(DbName.class, "name(node)", arg(NOD), STR, DB_URI),
   /** XQuery function. */
@@ -845,11 +837,12 @@ public enum Function {
   /* Fetch Module. */
 
   /** XQuery function. */
-  _FETCH_TEXT(FetchText.class, "text(uri[,encoding)", arg(STR, STR), STR, flag(NDT), FETCH_URI),
+  _FETCH_TEXT(FetchText.class, "text(uri[,encoding[,fallback]])",
+      arg(STR, STR, BLN), STR, flag(NDT), FETCH_URI),
   /** XQuery function. */
   _FETCH_BINARY(FetchBinary.class, "binary(uri)", arg(STR), B64, flag(NDT), FETCH_URI),
   /** XQuery function. */
-  _FETCH_XML(FetchXml.class, "xml(uri[,options])", arg(STR, ITEM), DOC_ZO, flag(NDT), FETCH_URI),
+  _FETCH_XML(FetchXml.class, "xml(uri[,options])", arg(STR, MAP_O), DOC_O, flag(NDT), FETCH_URI),
   /** XQuery function. */
   _FETCH_CONTENT_TYPE(FetchContentType.class, "content-type(uri)", arg(STR), STR, flag(NDT),
       FETCH_URI),
@@ -904,11 +897,11 @@ public enum Function {
   _FILE_DELETE(FileDelete.class, "delete(path[,recursive])",
       arg(STR, BLN), EMP, flag(NDT), FILE_URI),
   /** XQuery function. */
-  _FILE_READ_TEXT(FileReadText.class, "read-text(path[,encoding])",
-      arg(STR, STR), STR, flag(NDT), FILE_URI),
+  _FILE_READ_TEXT(FileReadText.class, "read-text(path[,encoding[,fallback]])",
+      arg(STR, STR, BLN), STR, flag(NDT), FILE_URI),
   /** XQuery function. */
-  _FILE_READ_TEXT_LINES(FileReadTextLines.class, "read-text-lines(path[,encoding])",
-      arg(STR, STR), STR_ZM, flag(NDT), FILE_URI),
+  _FILE_READ_TEXT_LINES(FileReadTextLines.class, "read-text-lines(path[,encoding[,fallback]])",
+      arg(STR, STR, BLN), STR_ZM, flag(NDT), FILE_URI),
   /** XQuery function. */
   _FILE_READ_BINARY(FileReadBinary.class, "read-binary(path[,offset[,length]])",
       arg(STR, ITR, ITR), B64, flag(NDT), FILE_URI),
@@ -951,10 +944,10 @@ public enum Function {
 
   /** XQuery function. */
   _FT_CONTAINS(FtContains.class, "contains(input,terms[,options])",
-      arg(ITEM, ITEM_ZM, ITEM), NOD_ZM, flag(NDT), FT_URI),
+      arg(ITEM, ITEM_ZM, MAP_O), BLN, flag(NDT), FT_URI),
   /** XQuery function. */
   _FT_SEARCH(FtSearch.class, "search(database,terms[,options])",
-      arg(STR, ITEM_ZM, ITEM), NOD_ZM, flag(NDT), FT_URI),
+      arg(STR, ITEM_ZM, MAP_O), TXT_ZM, flag(NDT), FT_URI),
   /** XQuery function. */
   _FT_COUNT(FtCount.class, "count(nodes)", arg(NOD_ZM), ITR, FT_URI),
   /** XQuery function. */
@@ -968,9 +961,9 @@ public enum Function {
   _FT_TOKENS(FtTokens.class, "tokens(database[,prefix])", arg(STR, STR), ITEM_ZM, flag(NDT),
       FT_URI),
   /** XQuery function. */
-  _FT_TOKENIZE(FtTokenize.class, "tokenize(string[,options])", arg(STR, ITEM), STR_ZM, FT_URI),
+  _FT_TOKENIZE(FtTokenize.class, "tokenize(string[,options])", arg(STR, MAP_O), STR_ZM, FT_URI),
   /** XQuery function. */
-  _FT_NORMALIZE(FtNormalize.class, "normalize(string[,options])", arg(STR, ITEM), STR, FT_URI),
+  _FT_NORMALIZE(FtNormalize.class, "normalize(string[,options])", arg(STR, MAP_O), STR, FT_URI),
 
   /* Hash Module. */
 
@@ -1020,9 +1013,9 @@ public enum Function {
   /** XQuery function. */
   _HTML_PARSER(HtmlParser.class, "parser()", arg(), STR, HTML_URI),
   /** XQuery function. */
-  _HTML_PARSE(HtmlParse.class, "parse(input[,options)", arg(STR, ITEM), DOC_O, HTML_URI),
+  _HTML_PARSE(HtmlParse.class, "parse(input[,options)", arg(STR, MAP_O), DOC_O, HTML_URI),
 
-  /* Http Module. */
+  /* HTTP Module. */
 
   /** XQuery function. */
   _HTTP_SEND_REQUEST(HttpSendRequest.class, "send-request(request[,href,[bodies]])",
@@ -1035,30 +1028,58 @@ public enum Function {
       INDEX_URI),
   /** XQuery function. */
   _INDEX_TEXTS(IndexTexts.class, "texts(database[,prefix[,ascending]])",
-      arg(STR, STR, BLN), NOD_ZM, flag(NDT), INDEX_URI),
+      arg(STR, STR, BLN), ELM_ZM, flag(NDT), INDEX_URI),
   /** XQuery function. */
   _INDEX_ATTRIBUTES(IndexAttributes.class, "attributes(database[,prefix[,ascending]])",
-      arg(STR, STR, BLN), NOD_ZM, flag(NDT), INDEX_URI),
+      arg(STR, STR, BLN), ELM_ZM, flag(NDT), INDEX_URI),
   /** XQuery function. */
-  _INDEX_ELEMENT_NAMES(IndexElementNames.class, "element-names(database)", arg(STR), NOD_ZM,
+  _INDEX_TOKENS(IndexTokens.class, "tokens(database)", arg(STR), ELM_ZM, flag(NDT), INDEX_URI),
+  /** XQuery function. */
+  _INDEX_ELEMENT_NAMES(IndexElementNames.class, "element-names(database)", arg(STR), ELM_ZM,
       INDEX_URI),
   /** XQuery function. */
-  _INDEX_ATTRIBUTE_NAMES(IndexAttributeNames.class, "attribute-names(database)", arg(STR), NOD_ZM,
+  _INDEX_ATTRIBUTE_NAMES(IndexAttributeNames.class, "attribute-names(database)", arg(STR), ELM_ZM,
       INDEX_URI),
 
   /* Inspection Module. */
 
   /** XQuery function. */
-  _INSPECT_FUNCTION(InspectFunction.class, "function(function)", arg(STR), ELM, INSPECT_URI),
+  _INSPECT_FUNCTION(InspectFunction.class, "function(function)",
+      arg(STR), ELM, flag(HOF), INSPECT_URI),
   /** XQuery function. */
-  _INSPECT_MODULE(InspectModule.class, "module(path)", arg(STR), ELM, INSPECT_URI),
+  _INSPECT_MODULE(InspectModule.class, "module(uri)", arg(STR), ELM, INSPECT_URI),
   /** XQuery function. */
   _INSPECT_CONTEXT(InspectContext.class, "context()", arg(), ELM, INSPECT_URI),
   /** XQuery function. */
-  _INSPECT_FUNCTIONS(InspectFunctions.class, "functions([uri])", arg(STR), FUN_ZM, flag(HOF),
-      INSPECT_URI),
+  _INSPECT_FUNCTIONS(InspectFunctions.class, "functions([uri])",
+      arg(STR), FUN_ZM, flag(HOF), INSPECT_URI),
   /** XQuery function. */
-  _INSPECT_XQDOC(InspectXqdoc.class, "xqdoc(path)", arg(STR), ELM, INSPECT_URI),
+  _INSPECT_FUNCTION_ANNOTATIONS(InspectFunctionAnnotations.class, "function-annotations(function)",
+      arg(FUN_O), MAP_ZO, UTIL_URI),
+  /** XQuery function. */
+  _INSPECT_STATIC_CONTEXT(InspectStaticContext.class, "static-context(function,name)",
+      arg(FUN_O, STR), ITEM_ZM, INSPECT_URI),
+  /** XQuery function. */
+  _INSPECT_XQDOC(InspectXqdoc.class, "xqdoc(uri)", arg(STR), ELM, INSPECT_URI),
+
+  /* Jobs Module. */
+
+  /** XQuery function. */
+  _JOBS_EVAL(JobsEval.class, "eval(string[,bindings[,options]])",
+      arg(STR, MAP_ZO, MAP_O), STR, flag(NDT), JOBS_URI),
+  /** XQuery function. */
+  _JOBS_RESULT(JobsResult.class, "result(id)", arg(STR), ITEM_ZM, flag(NDT), JOBS_URI),
+  /** XQuery function. */
+  _JOBS_FINISHED(JobsFinished.class, "finished(id)", arg(STR), BLN, flag(NDT), JOBS_URI),
+  /** XQuery function. */
+  _JOBS_STOP(JobsStop.class, "stop(id)", arg(STR), BLN, flag(NDT), JOBS_URI),
+  /** XQuery function. */
+  _JOBS_LIST(JobsList.class, "list()", arg(), STR_ZM, flag(NDT), JOBS_URI),
+  /** XQuery function. */
+  _JOBS_LIST_DETAILS(JobsListDetails.class, "list-details([id])",
+      arg(STR), ELM_ZM, flag(NDT), JOBS_URI),
+  /** XQuery function. */
+  _JOBS_CURRENT(JobsCurrent.class, "current()", arg(), STR, flag(NDT), JOBS_URI),
 
   /* JSON Module. */
 
@@ -1085,6 +1106,11 @@ public enum Function {
   /** XQuery function. */
   _PROC_EXECUTE(ProcExecute.class, "execute(command[,args[,encoding]]])",
       arg(STR, STR_ZM, STR), ELM, flag(NDT), PROC_URI),
+  /** XQuery function. */
+  _PROC_PROPERTY_NAMES(ProcPropertyNames.class, "property-names()",
+      arg(), STR_ZO, flag(NDT), PROC_URI),
+  /** XQuery function. */
+  _PROC_PROPERTY(ProcProperty.class, "property(name)", arg(STR), STR, flag(NDT), PROC_URI),
 
   /* Profiling Module. */
 
@@ -1108,6 +1134,8 @@ public enum Function {
   _PROF_VOID(ProfVoid.class, "void(value)", arg(ITEM_ZM), EMP, flag(NDT), PROF_URI),
   /** XQuery function. */
   _PROF_VARIABLES(ProfVariables.class, "variables()", arg(), EMP, flag(NDT), PROF_URI),
+  /** XQuery function. */
+  _PROF_TYPE(ProfType.class, "type(value)", arg(ITEM_ZM), ITEM_ZM, PROF_URI),
 
   /* Random Module. */
 
@@ -1117,13 +1145,16 @@ public enum Function {
   _RANDOM_INTEGER(RandomInteger.class, "integer([max])", arg(ITR), ITR, flag(NDT), RANDOM_URI),
   /** XQuery function. */
   _RANDOM_SEEDED_DOUBLE(RandomSeededDouble.class, "seeded-double(seed,num)",
-      arg(ITR, ITR), DBL_ZM, flag(NDT), RANDOM_URI),
+      arg(ITR, ITR), DBL_ZM, RANDOM_URI),
   /** XQuery function. */
   _RANDOM_SEEDED_INTEGER(RandomSeededInteger.class, "seeded-integer(seed,num[,max])",
-      arg(ITR, ITR, ITR), ITR_ZM, flag(NDT), RANDOM_URI),
+      arg(ITR, ITR, ITR), ITR_ZM, RANDOM_URI),
   /** XQuery function. */
   _RANDOM_GAUSSIAN(RandomGaussian.class, "gaussian(num)", arg(ITR), DBL_ZM, flag(NDT), RANDOM_URI),
   /** XQuery function. */
+  _RANDOM_SEEDED_PERMUTATION(RandomSeededPermutation.class, "seeded-permutation(seed,items)",
+      arg(ITR, ITEM_ZM), ITEM_ZM, RANDOM_URI),
+  /** XQuery function. */
   _RANDOM_UUID(RandomUuid.class, "uuid()", arg(), STR, flag(NDT), RANDOM_URI),
 
   /* Repository Module. */
@@ -1141,7 +1172,7 @@ public enum Function {
   _SQL_INIT(SqlInit.class, "init(class)", arg(STR), EMP, flag(NDT), SQL_URI),
   /** XQuery function. */
   _SQL_CONNECT(SqlConnect.class, "connect(url[,user[,pass[,options]]]]])",
-      arg(STR, STR, STR, NOD_ZO), ITR, flag(NDT), SQL_URI),
+      arg(STR, STR, STR, MAP_O), ITR, flag(NDT), SQL_URI),
   /** XQuery function. */
   _SQL_PREPARE(SqlPrepare.class, "prepare(id,statement)", arg(ITR, STR), ITR, flag(NDT), SQL_URI),
   /** XQuery function. */
@@ -1165,6 +1196,17 @@ public enum Function {
   _STREAM_IS_STREAMABLE(StreamIsStreamable.class, "is-streamable(item)", arg(ITEM), BLN,
       STREAM_URI),
 
+  /* Strings Module. */
+
+  /** XQuery function. */
+  _STRINGS_LEVENSHTEIN(StringsLevenshtein.class, "levenshtein(string1,string2)",
+      arg(STR, STR), DBL, STRINGS_URI),
+  /** XQuery function. */
+  _STRINGS_SOUNDEX(StringsSoundex.class, "soundex(string)", arg(STR), STR, STRINGS_URI),
+  /** XQuery function. */
+  _STRINGS_COLOGNE_PHONETIC(StringsColognePhonetic.class, "cologne-phonetic(string)",
+      arg(STR), STR, STRINGS_URI),
+
   /* Unit Module. */
 
   /** XQuery function. */
@@ -1188,39 +1230,61 @@ public enum Function {
   _USER_LIST_DETAILS(UserListDetails.class, "list-details([name])",
       arg(STR), ELM_ZM, flag(NDT), USER_URI),
   /** XQuery function. */
-  _USER_CREATE(UserCreate.class, "create(name,password[,permission])",
-      arg(STR, STR, STR), EMP, flag(UPD), USER_URI),
+  _USER_CREATE(UserCreate.class, "create(name,password[,permissions[,patterns]])",
+      arg(STR, STR, STR_ZM, STR_ZM), EMP, flag(UPD), USER_URI),
   /** XQuery function. */
-  _USER_GRANT(UserGrant.class, "grant(name,permission[,pattern])",
-      arg(STR, STR, STR), EMP, flag(UPD), USER_URI),
+  _USER_GRANT(UserGrant.class, "grant(name,permissions[,patterns])",
+      arg(STR, STR_ZM, STR_ZM), EMP, flag(UPD), USER_URI),
   /** XQuery function. */
-  _USER_DROP(UserDrop.class, "drop(name[,pattern])", arg(STR, STR), EMP, flag(UPD), USER_URI),
+  _USER_DROP(UserDrop.class, "drop(name[,patterns])", arg(STR, STR_ZM), EMP, flag(UPD), USER_URI),
   /** XQuery function. */
   _USER_ALTER(UserAlter.class, "alter(name,newname)", arg(STR, STR), EMP, flag(UPD), USER_URI),
   /** XQuery function. */
   _USER_PASSWORD(UserPassword.class, "password(name,password)",
       arg(STR, STR), EMP, flag(UPD), USER_URI),
 
+  /* Utility Module. */
+
+  /** XQuery function. */
+  _UTIL_DEEP_EQUAL(UtilDeepEqual.class, "deep-equal(items1,items2[,options])",
+      arg(ITEM_ZM, ITEM_ZM, ITEM), BLN, UTIL_URI),
+  /** XQuery function. */
+  _UTIL_ITEM_AT(UtilItemAt.class, "item-at(items,pos)", arg(ITEM_ZM, DBL), ITEM_ZO, UTIL_URI),
+  /** XQuery function. */
+  _UTIL_ITEM_RANGE(UtilItemRange.class, "item-range(items,first,last)",
+      arg(ITEM_ZM, DBL, DBL), ITEM_ZM, UTIL_URI),
+  /** XQuery function. */
+  _UTIL_LAST_FROM(UtilLastFrom.class, "last-from(items)", arg(ITEM_ZM), ITEM_ZO, UTIL_URI),
+
   /* Validate Module. */
 
   /** XQuery function. */
-  _VALIDATE_XSD(ValidateXsd.class, "xsd(input[,schema])", arg(ITEM, ITEM), EMP, flag(NDT),
-      VALIDATE_URI),
+  _VALIDATE_XSD(ValidateXsd.class, "xsd(input[,schema[,version]])",
+      arg(ITEM, ITEM, STR), EMP, flag(NDT), VALIDATE_URI),
   /** XQuery function. */
-  _VALIDATE_XSD_INFO(ValidateXsdInfo.class, "xsd-info(input[,schema])",
-      arg(ITEM, ITEM), STR_ZM, flag(NDT), VALIDATE_URI),
+  _VALIDATE_XSD_INFO(ValidateXsdInfo.class, "xsd-info(input[,schema[,version]])",
+      arg(ITEM, ITEM, STR), STR_ZM, flag(NDT), VALIDATE_URI),
   /** XQuery function. */
-  _VALIDATE_DTD(ValidateDtd.class, "dtd(input[,schema])", arg(ITEM, ITEM), EMP, flag(NDT),
-      VALIDATE_URI),
+  _VALIDATE_XSD_REPORT(ValidateXsdReport.class, "xsd-report(input[,schema[,version]])",
+      arg(ITEM, ITEM, STR), ELM, flag(NDT), VALIDATE_URI),
+  /** XQuery function. */
+  _VALIDATE_DTD(ValidateDtd.class, "dtd(input[,schema])",
+      arg(ITEM, ITEM), EMP, flag(NDT), VALIDATE_URI),
   /** XQuery function. */
   _VALIDATE_DTD_INFO(ValidateDtdInfo.class, "dtd-info(input[,schema])",
       arg(ITEM, ITEM), STR_ZM, flag(NDT), VALIDATE_URI),
   /** XQuery function. */
+  _VALIDATE_DTD_REPORT(ValidateDtdReport.class, "dtd-report(input[,schema])",
+      arg(ITEM, ITEM), ELM, flag(NDT), VALIDATE_URI),
+  /** XQuery function. */
   _VALIDATE_RNG(ValidateRng.class, "rng(input,schema[,compact])",
       arg(ITEM, ITEM, BLN), STR_ZM, flag(NDT), VALIDATE_URI),
   /** XQuery function. */
   _VALIDATE_RNG_INFO(ValidateRngInfo.class, "rng-info(input,schema[,compact])",
       arg(ITEM, ITEM, BLN), STR_ZM, flag(NDT), VALIDATE_URI),
+  /** XQuery function. */
+  _VALIDATE_RNG_REPORT(ValidateRngReport.class, "rng-report(input,schema[,compact])",
+      arg(ITEM, ITEM, BLN), ELM, flag(NDT), VALIDATE_URI),
 
   /* Web Module. */
 
@@ -1242,18 +1306,22 @@ public enum Function {
 
   /** XQuery function. */
   _XQUERY_EVAL(XQueryEval.class, "eval(string[,bindings[,options]])",
-      arg(STR, ITEM, ITEM), ITEM_ZM, flag(NDT), XQUERY_URI),
+      arg(STR, MAP_ZO, MAP_O), ITEM_ZM, flag(NDT), XQUERY_URI),
   /** XQuery function. */
   _XQUERY_UPDATE(XQueryUpdate.class, "update(string[,bindings[,options]])",
-      arg(STR, ITEM, ITEM), ITEM_ZM, flag(UPD, NDT), XQUERY_URI),
+      arg(STR, MAP_ZO, MAP_O), ITEM_ZM, flag(UPD), XQUERY_URI),
   /** XQuery function. */
   _XQUERY_INVOKE(XQueryInvoke.class, "invoke(uri[,bindings[,options]])",
-      arg(STR, ITEM, ITEM), ITEM_ZM, flag(NDT), XQUERY_URI),
+      arg(STR, MAP_ZO, MAP_O), ITEM_ZM, flag(NDT), XQUERY_URI),
   /** XQuery function. */
   _XQUERY_PARSE(XQueryParse.class, "parse(string[,options])",
-      arg(STR, ITEM), NOD, flag(NDT), XQUERY_URI),
+      arg(STR, MAP_O), NOD, flag(NDT), XQUERY_URI),
   /** XQuery function. */
-  _XQUERY_TYPE(XQueryType.class, "type(value)", arg(ITEM_ZM), ITEM_ZM, XQUERY_URI),
+  _XQUERY_PARSE_URI(XQueryParseUri.class, "parse-uri(uri[,options])",
+      arg(STR, MAP_O), NOD, flag(NDT), XQUERY_URI),
+  /** XQuery function. */
+  _XQUERY_FORK_JOIN(XQueryForkJoin.class, "fork-join(functions[,options])",
+      arg(FUN_ZM, MAP_O), ITEM_ZM, flag(HOF), XQUERY_URI),
 
   /* XSLT Module. */
 
@@ -1263,10 +1331,10 @@ public enum Function {
   _XSLT_VERSION(XsltVersion.class, "version()", arg(), STR, XSLT_URI),
   /** XQuery function. */
   _XSLT_TRANSFORM(XsltTransform.class, "transform(input,stylesheet[,params])",
-      arg(ITEM, ITEM, ITEM), NOD, flag(NDT), XSLT_URI),
+      arg(ITEM, ITEM, MAP_O), NOD, flag(NDT), XSLT_URI),
   /** XQuery function. */
   _XSLT_TRANSFORM_TEXT(XsltTransformText.class, "transform-text(input,stylesheet[,params])",
-      arg(ITEM, ITEM, ITEM), STR, flag(NDT), XSLT_URI),
+      arg(ITEM, ITEM, MAP_O), STR, flag(NDT), XSLT_URI),
 
   /* ZIP Module. */
 
@@ -1314,7 +1382,7 @@ public enum Function {
   /** Descriptions. */
   final String desc;
   /** Return type. */
-  final SeqType ret;
+  final SeqType type;
 
   /** Compiler flags. */
   private final EnumSet<Flag> flags;
@@ -1329,11 +1397,11 @@ public enum Function {
    * @param func reference to the class containing the function implementation
    * @param desc descriptive function string
    * @param args types of the function arguments
-   * @param ret return type
+   * @param type return type
    */
   Function(final Class<? extends StandardFunc> func, final String desc, final SeqType[] args,
-      final SeqType ret) {
-    this(func, desc, args, ret, EnumSet.noneOf(Flag.class));
+      final SeqType type) {
+    this(func, desc, args, type, EnumSet.noneOf(Flag.class));
   }
 
   /**
@@ -1342,12 +1410,12 @@ public enum Function {
    * @param func reference to the class containing the function implementation
    * @param desc descriptive function string
    * @param args types of the function arguments
-   * @param ret return type
+   * @param type return type
    * @param uri uri
    */
   Function(final Class<? extends StandardFunc> func, final String desc, final SeqType[] args,
-      final SeqType ret, final byte[] uri) {
-    this(func, desc, args, ret, EnumSet.noneOf(Flag.class), uri);
+      final SeqType type, final byte[] uri) {
+    this(func, desc, args, type, EnumSet.noneOf(Flag.class), uri);
   }
 
   /**
@@ -1356,12 +1424,12 @@ public enum Function {
    * @param func reference to the class containing the function implementation
    * @param desc descriptive function string
    * @param args types of the function arguments
-   * @param ret return type
+   * @param type return type
    * @param flag static function properties
    */
   Function(final Class<? extends StandardFunc> func, final String desc, final SeqType[] args,
-      final SeqType ret, final EnumSet<Flag> flag) {
-    this(func, desc, args, ret, flag, FN_URI);
+      final SeqType type, final EnumSet<Flag> flag) {
+    this(func, desc, args, type, flag, FN_URI);
   }
 
   /**
@@ -1372,16 +1440,16 @@ public enum Function {
    *             square brackets; three dots indicate that the number of arguments of a
    *             function is not limited
    * @param args types of the function arguments
-   * @param ret return type
+   * @param type return type
    * @param flags static function properties
    * @param uri uri
    */
   Function(final Class<? extends StandardFunc> func, final String desc, final SeqType[] args,
-      final SeqType ret, final EnumSet<Flag> flags, final byte[] uri) {
+      final SeqType type, final EnumSet<Flag> flags, final byte[] uri) {
 
     this.func = func;
     this.desc = desc;
-    this.ret = ret;
+    this.type = type;
     this.args = args;
     this.flags = flags;
     this.uri = uri;
@@ -1449,7 +1517,7 @@ public enum Function {
     } else {
       System.arraycopy(args, 0, st, 0, arity);
     }
-    return FuncType.get(anns, ret, st);
+    return FuncType.get(anns, type, st);
   }
 
   /**
@@ -1549,12 +1617,21 @@ public enum Function {
     return new TokenBuilder(NSGlobal.prefix(uri)).add(':').add(desc).toString();
   }
 
+  /**
+   * Returns a string representation of the function with the specified arguments.
+   * @param exprs arguments
+   * @return function
+   */
+  public String toString(final Expr... exprs) {
+    return new TokenBuilder(id()).add('(').addSep(exprs, SEP).add(')').toString();
+  }
+
   /*
    * Returns the names of all functions. Used to update MediaWiki syntax highlighter.
    * All function names are listed in reverse order to give precedence to longer names.
    * @param args ignored
   public static void main(final String... args) {
-    final StringList sl = new StringList();
+    final org.basex.util.list.StringList sl = new org.basex.util.list.StringList();
     for(Function f : VALUES) {
       sl.add(f.toString().replaceAll("^fn:|\\(.*", ""));
     }
