@@ -8,7 +8,7 @@ import org.basex.query.value.item.*;
 /**
  * Archive constants.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 interface ArchiveText {
@@ -18,15 +18,9 @@ interface ArchiveText {
   String ZIP = "zip";
 
   /** QName. */
-  QNm Q_ENTRY = QNm.get(ARCHIVE_PREFIX, "entry", ARCHIVE_URI);
-  /** QName. */
-  QNm Q_OPTIONS = QNm.get(ARCHIVE_PREFIX, "options", ARCHIVE_URI);
-  /** QName. */
-  QNm Q_FORMAT = QNm.get(ARCHIVE_PREFIX, "format", ARCHIVE_URI);
-  /** QName. */
-  QNm Q_ALGORITHM = QNm.get(ARCHIVE_PREFIX, "algorithm", ARCHIVE_URI);
+  QNm Q_ENTRY = new QNm(ARCHIVE_PREFIX, "entry", ARCHIVE_URI);
   /** Root node test. */
-  NodeTest TEST = new NodeTest(Q_ENTRY);
+  NodeTest ENTRY = new NodeTest(Q_ENTRY);
 
   /** Level. */
   String LEVEL = "compression-level";
