@@ -8,7 +8,7 @@ import org.basex.util.*;
 /**
  * ZIP output.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 final class ZIPOut extends ArchiveOut {
@@ -18,7 +18,7 @@ final class ZIPOut extends ArchiveOut {
   /**
    * Writing constructor.
    */
-  public ZIPOut() {
+  ZIPOut() {
     zos = new ZipOutputStream(ao);
   }
 
