@@ -1,14 +1,17 @@
 package org.basex.query.func.array;
 
 import org.basex.query.*;
+import org.basex.query.expr.*;
 import org.basex.query.func.*;
 import org.basex.query.iter.*;
 import org.basex.query.value.*;
+import org.basex.query.value.type.*;
+import org.basex.query.var.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class ArrayGet extends StandardFunc {
@@ -21,4 +24,14 @@ public final class ArrayGet extends StandardFunc {
   public Value value(final QueryContext qc) throws QueryException {
     return toArray(exprs[0], qc).get(toAtomItem(exprs[1], qc), info);
   }
+
+  @Override
+  protected Expr opt(final QueryContext qc, final VarScope scp) {
+    final SeqType st = exprs[0].seqType();
+    if(st.type instanceof ArrayType) {
+      final SeqType rt = ((ArrayType) st.type).type;
+      if(rt != null) seqType = rt;
+    }
+    return this;
+  }
 }
