@@ -9,7 +9,7 @@ import org.basex.query.value.seq.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class ConvertBinaryToBytes extends StandardFunc {
@@ -20,6 +20,6 @@ public final class ConvertBinaryToBytes extends StandardFunc {
 
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    return BytSeq.get(toBytes(exprs[0], qc));
+    return BytSeq.get(toBin(exprs[0], qc).binary(info));
   }
 }
