@@ -8,13 +8,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Lukas Kircher
  */
 public final class CryptoEncrypt extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return new Encryption(ii).encryption(toToken(exprs[0], qc),
+    return new Encryption(info).encryption(toToken(exprs[0], qc),
         toToken(exprs[1], qc), toToken(exprs[2], qc), toToken(exprs[3], qc), true);
   }
 }
