@@ -11,7 +11,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Lukas Kircher
  */
 public final class CryptoGenerateSignature extends StandardFunc {
@@ -28,11 +28,11 @@ public final class CryptoGenerateSignature extends StandardFunc {
       }
     }
 
-    return new DigitalSignature(ii).generateSignature(
+    return new DigitalSignature(info).generateSignature(
         toNode(exprs[0], qc), toToken(exprs[1], qc),
         toToken(exprs[2], qc), toToken(exprs[3], qc),
         toToken(exprs[4], qc), toToken(exprs[5], qc),
-        arg6Str ? arg6.string(ii) : Token.token(""),
+        arg6Str ? arg6.string(info) : Token.token(""),
         exprs.length > 7 ? toNode(exprs[7], qc) :
           exprs.length == 7 && !arg6Str ? toNode(exprs[6], qc) : null,
         qc, info);
