@@ -8,12 +8,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Lukas Kircher
  */
 public final class CryptoValidateSignature extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return new DigitalSignature(ii).validateSignature(toNode(exprs[0], qc));
+    return new DigitalSignature(info).validateSignature(toNode(exprs[0], qc));
   }
 }
