@@ -8,20 +8,21 @@ import org.basex.build.csv.*;
 import org.basex.io.*;
 import org.basex.io.parse.csv.*;
 import org.basex.query.*;
+import org.basex.query.func.*;
 import org.basex.query.value.item.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
-public final class CsvParse extends CsvFn {
+public final class CsvParse extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final byte[] input = toToken(exprs[0], qc);
-    final CsvParserOptions opts = toOptions(1, Q_OPTIONS, new CsvParserOptions(), qc);
+    final CsvParserOptions opts = toOptions(1, new CsvParserOptions(), qc);
     try {
       return CsvConverter.get(opts).convert(new IOContent(input));
     } catch(final IOException ex) {
