@@ -1,17 +1,18 @@
 package org.basex.query.func.db;
 
+import org.basex.index.*;
 import org.basex.query.*;
 import org.basex.query.iter.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class DbAttribute extends DbText {
   @Override
   public Iter iter(final QueryContext qc) throws QueryException {
-    return attribute(valueAccess(false, qc), qc, 2);
+    return attribute(valueAccess(IndexType.ATTRIBUTE, qc), qc, 2);
   }
 }
