@@ -14,7 +14,7 @@ import org.basex.util.list.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class DbDropBackup extends DbAccess {
@@ -26,7 +26,7 @@ public final class DbDropBackup extends DbAccess {
     final StringList backups = qc.context.databases.backups(name);
     if(backups.isEmpty()) throw BXDB_WHICHBACK_X.get(info, name);
 
-    final Updates updates = qc.resources.updates();
+    final Updates updates = qc.updates();
     for(final String backup : backups) updates.add(new BackupDrop(backup, info, qc), qc);
     return null;
   }
