@@ -10,7 +10,7 @@ import org.basex.util.options.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class DbOptimize extends DbNew {
@@ -18,8 +18,8 @@ public final class DbOptimize extends DbNew {
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Data data = checkData(qc);
     final boolean all = exprs.length > 1 && toBoolean(exprs[1], qc);
-    final Options opts = toOptions(2, Q_OPTIONS, new Options(), qc);
-    qc.resources.updates().add(new DBOptimize(data, all, opts, qc, info), qc);
+    final Options opts = toOptions(2, new Options(), qc);
+    qc.updates().add(new DBOptimize(data, all, opts, qc, info), qc);
     return null;
   }
 }
