@@ -11,12 +11,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class DbRetrieve extends DbAccess {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
+  public B64Stream item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Data data = checkData(qc);
     final String path = path(1, qc);
     if(data.inMemory()) throw BXDB_MEM_X.get(info, data.meta.name);
