@@ -11,12 +11,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FetchBinary extends StandardFunc {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
+  public B64Stream item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final byte[] uri = toToken(exprs[0], qc);
     return new B64Stream(IO.get(Token.string(uri)), BXFE_IO_X);
   }
