@@ -11,7 +11,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FetchText extends StandardFunc {
@@ -19,6 +19,7 @@ public final class FetchText extends StandardFunc {
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final byte[] uri = toToken(exprs[0], qc);
     final String enc = toEncoding(1, BXFE_ENCODING_X, qc);
-    return new StrStream(IO.get(Token.string(uri)), enc, BXFE_IO_X, qc);
+    final boolean val = exprs.length < 3 || !toBoolean(exprs[2], qc);
+    return new StrStream(IO.get(Token.string(uri)), enc, BXFE_IO_X, val);
   }
 }
