@@ -9,13 +9,14 @@ import org.basex.query.value.item.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FileBaseDir extends FileFn {
   @Override
   public Item item(final QueryContext qc) {
     final IO base = sc.baseIO();
-    return base instanceof IOFile ? get(absolute(Paths.get(base.dir())), true) : null;
+    if(!(base instanceof IOFile)) return null;
+    return get(absolute(Paths.get(base.isDir() ? base.path() : base.dir())), true);
   }
 }
