@@ -11,7 +11,7 @@ import org.basex.query.value.item.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 abstract class FileRead extends FileFn {
@@ -24,8 +24,9 @@ abstract class FileRead extends FileFn {
   final StrStream text(final QueryContext qc) throws QueryException {
     final Path path = toPath(0, qc);
     final String enc = toEncoding(1, FILE_UNKNOWN_ENCODING_X, qc);
+    final boolean val = exprs.length < 3 || !toBoolean(exprs[2], qc);
     if(!Files.exists(path)) throw FILE_NOT_FOUND_X.get(info, path);
     if(Files.isDirectory(path)) throw FILE_IS_DIR_X.get(info, path);
-    return new StrStream(new IOFile(path.toFile()), enc, FILE_IO_ERROR_X, qc);
+    return new StrStream(new IOFile(path.toFile()), enc, FILE_IO_ERROR_X, val);
   }
 }
