@@ -1,6 +1,7 @@
 package org.basex.query.func.file;
 
 import static org.basex.query.QueryError.*;
+import static org.basex.util.Token.*;
 
 import java.nio.file.*;
 
@@ -10,19 +11,20 @@ import org.basex.query.value.item.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FileResolvePath extends FileFn {
   @Override
   public Item item(final QueryContext qc) throws QueryException {
-    final Path path = toPath(0, qc);
-    final Path abs;
+    final Path path = toPath(toToken(exprs[0], qc)), abs;
     if(exprs.length < 2) {
       abs = absolute(path);
     } else {
-      final Path base = toPath(1, qc);
+      final byte[] file = toToken(exprs[1], qc);
+      Path base = toPath(file);
       if(!base.isAbsolute()) throw FILE_IS_RELATIVE_X.get(info, base);
+      if(!endsWith(file, '/') && !endsWith(file, '\\')) base = base.getParent();
       abs = base.resolve(path);
     }
     return get(abs, Files.isDirectory(abs));
