@@ -12,7 +12,7 @@ import org.basex.query.value.item.*;
 /**
  * Aggregation function.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 abstract class Aggr extends StandardFunc {
@@ -37,9 +37,9 @@ abstract class Aggr extends StandardFunc {
         if(num) throw SUMNUM_X_X.get(info, i.type, i);
         if(dtd && i.type != DTD || ymd && i.type != YMD) throw SUMDUR_X_X.get(info, i.type, i);
       }
-      rs = Calc.PLUS.ev(info, rs, i);
+      rs = Calc.PLUS.ev(rs, i, info);
       ++c;
     }
-    return avg ? Calc.DIV.ev(info, rs, Int.get(c)) : rs;
+    return avg ? Calc.DIV.ev(rs, Int.get(c), info) : rs;
   }
 }
