@@ -3,6 +3,7 @@ package org.basex.query.func.fn;
 import static org.basex.query.QueryError.*;
 
 import org.basex.query.*;
+import org.basex.query.ann.*;
 import org.basex.query.func.*;
 import org.basex.query.iter.*;
 import org.basex.query.util.list.*;
@@ -13,7 +14,7 @@ import org.basex.query.value.item.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnApply extends StandardFunc {
@@ -25,6 +26,9 @@ public final class FnApply extends StandardFunc {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
     final FItem fun = toFunc(exprs[0], qc);
+    if(!sc.mixUpdates && fun.annotations().contains(Annotation.UPDATING))
+      throw FUNCUP_X.get(info, fun);
+
     final Array array = toArray(exprs[1], qc);
     final long as = array.arraySize();
     if(fun.arity() != as) throw APPLY_X_X.get(info, fun.arity(), as);
