@@ -8,13 +8,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnAvg extends Aggr {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Iter iter = exprs[0].atomIter(qc, ii);
+    final Iter iter = exprs[0].atomIter(qc, info);
     final Item it = iter.next();
     return it == null ? null : sum(iter, it, true);
   }
