@@ -1,6 +1,7 @@
 package org.basex.query.func.fn;
 
 import org.basex.core.locks.*;
+import org.basex.data.*;
 import org.basex.query.*;
 import org.basex.query.func.*;
 import org.basex.query.util.*;
@@ -12,7 +13,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnDocumentUri extends StandardFunc {
@@ -20,6 +21,10 @@ public final class FnDocumentUri extends StandardFunc {
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final ANode node = toEmptyNode(ctxArg(0, qc), qc);
     if(node == null || node.type != NodeType.DOC) return null;
+    // return empty sequence for documents constructed via parse-xml
+    final Data data = node.data();
+    if(data != null && data.meta.name.isEmpty()) return null;
+
     final byte[] uri = node.baseURI();
     return uri.length == 0 ? null : Uri.uri(uri, false);
   }
