@@ -11,7 +11,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnGenerateId extends StandardFunc {
@@ -19,7 +19,7 @@ public final class FnGenerateId extends StandardFunc {
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final ANode node = toEmptyNode(ctxArg(0, qc), qc);
     return node == null ? Str.ZERO :
-      Str.get(new TokenBuilder(QueryText.ID).addInt(node.id).finish());
+      Str.get(new TokenBuilder(Token.ID).addInt(node.id).finish());
   }
 
   @Override
