@@ -7,13 +7,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnHoursFromDuration extends DateTime {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Item it = exprs[0].atomItem(qc, info);
-    return it == null ? null : Int.get(checkDur(it).hou());
+    return it == null ? null : Int.get(checkDur(it).hour());
   }
 }
