@@ -8,13 +8,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnHoursFromTime extends DateTime {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Item it = exprs[0].atomItem(qc, info);
-    return it == null ? null : Int.get(checkDate(it, AtomType.TIM, qc).hou());
+    return it == null ? null : Int.get(checkDate(it, AtomType.TIM, qc).hour());
   }
 }
