@@ -7,13 +7,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnJsonDoc extends FnParseJson {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Item it = unparsedText(qc, false, false);
-    return it == null ? null : parse(it.string(ii), false, qc, ii);
+    return it == null ? null : parse(it.string(info), false, qc, info);
   }
 }
