@@ -7,7 +7,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public class FnJsonToXml extends FnParseJson {
@@ -15,6 +15,6 @@ public class FnJsonToXml extends FnParseJson {
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Item it = exprs[0].atomItem(qc, info);
     if(it == null) return null;
-    return parse(toToken(it), true, qc, ii);
+    return parse(toToken(it), true, qc, info);
   }
 }
