@@ -12,7 +12,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnResolveQName extends StandardFunc {
@@ -23,7 +23,7 @@ public final class FnResolveQName extends StandardFunc {
     final ANode base = toElem(exprs[1], qc);
 
     final byte[] name = toToken(it);
-    if(!XMLToken.isQName(name)) throw valueError(info, AtomType.QNM, name);
+    if(!XMLToken.isQName(name)) throw valueError(AtomType.QNM, name, info);
 
     final QNm nm = new QNm(name);
     final byte[] pref = nm.prefix();
