@@ -15,15 +15,15 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnString extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Item it = ctxArg(0, qc).item(qc, info);
-    if(it instanceof FItem) throw FISTRING_X.get(ii, it.type);
-    return it == null ? Str.ZERO : it.type == AtomType.STR ? it : Str.get(it.string(ii));
+    if(it instanceof FItem) throw FISTRING_X.get(info, it.type);
+    return it == null ? Str.ZERO : it.type == AtomType.STR ? it : Str.get(it.string(info));
   }
 
   @Override
