@@ -11,7 +11,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnStringJoin extends StandardFunc {
@@ -19,15 +19,20 @@ public final class FnStringJoin extends StandardFunc {
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Iter iter = exprs[0].atomIter(qc, info);
     final byte[] token = exprs.length == 2 ? toToken(exprs[1], qc) : EMPTY;
+
     // no results: empty string
     Item it = iter.next();
     if(it == null) return Str.ZERO;
+
     // single result
-    final byte[] first = toToken(it);
+    final byte[] first = it.string(info);
     if((it = iter.next()) == null) return Str.get(first);
+
     // join multiple strings
     final TokenBuilder tb = new TokenBuilder(first);
-    do tb.add(token).add(toToken(it)); while((it = iter.next()) != null);
+    do {
+      tb.add(token).add(it.string(info));
+    } while((it = iter.next()) != null);
     return Str.get(tb.finish());
   }
 }
