@@ -6,6 +6,7 @@ import static org.basex.util.Token.*;
 import java.util.regex.*;
 
 import org.basex.query.*;
+import org.basex.query.expr.*;
 import org.basex.query.iter.*;
 import org.basex.query.value.*;
 import org.basex.query.value.seq.*;
@@ -14,7 +15,7 @@ import org.basex.util.list.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class FnTokenize extends RegEx {
@@ -44,4 +45,13 @@ public final class FnTokenize extends RegEx {
     }
     return StrSeq.get(tl);
   }
+
+  /**
+   * Returns the input argument if no others are specified, and if it returns at most one item.
+   * @return first argument
+   */
+  public Expr input() {
+    // X must yield single result (otherwise, it may result in an error)
+    return exprs.length == 1 && exprs[0].seqType().zeroOrOne() ? exprs[0] : null;
+  }
 }
