@@ -1,16 +1,22 @@
 package org.basex.query.func.ft;
 
 import org.basex.query.*;
+import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public class FtNormalize extends FtTokenize {
+  @Override
+  public Value value(final QueryContext qc) throws QueryException {
+    return item(qc, null);
+  }
+
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final TokenBuilder tb = new TokenBuilder();
