@@ -1,7 +1,6 @@
 package org.basex.query.func.html;
 
 import static org.basex.query.QueryError.*;
-import static org.basex.query.QueryText.*;
 
 import java.io.*;
 
@@ -17,17 +16,14 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class HtmlParse extends StandardFunc {
-  /** QName. */
-  private static final QNm Q_OPTIONS = QNm.get("options", HTML_URI);
-
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final byte[] in = toBytes(exprs[0], qc);
-    final HtmlOptions hopts = toOptions(1, Q_OPTIONS, new HtmlOptions(), qc);
+    final HtmlOptions hopts = toOptions(1, new HtmlOptions(), qc);
     final MainOptions opts = MainOptions.get();
     try {
       return new DBNode(new org.basex.build.html.HtmlParser(new IOContent(in), opts, hopts));
