@@ -8,13 +8,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class InspectModule extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     checkCreate(qc);
-    return new PlainDoc(qc, info).parse(checkPath(exprs[0], qc));
+    return new PlainDoc(qc, info).parse(checkPath(0, qc));
   }
 }
