@@ -8,12 +8,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 public final class MapContains extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return Bln.get(toMap(exprs[0], qc).contains(toAtomItem(exprs[1], qc), ii));
+    return Bln.get(toMap(exprs[0], qc).contains(toAtomItem(exprs[1], qc), info));
   }
 }
