@@ -9,12 +9,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 public final class MapEntry extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return Map.EMPTY.put(toAtomItem(exprs[0], qc), qc.value(exprs[1]), ii);
+    return Map.EMPTY.put(toAtomItem(exprs[0], qc), qc.value(exprs[1]), info);
   }
 }
