@@ -1,7 +1,5 @@
 package org.basex.query.func.map;
 
-import static org.basex.query.QueryError.*;
-
 import org.basex.query.*;
 import org.basex.query.func.*;
 import org.basex.query.value.*;
@@ -12,7 +10,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 public final class MapPut extends StandardFunc {
@@ -21,7 +19,6 @@ public final class MapPut extends StandardFunc {
     final Map map = toMap(exprs[0], qc);
     final Item key = toAtomItem(exprs[1], qc);
     final Value val = qc.value(exprs[2]);
-    if(!map.checkTz(key)) throw MAP_TZ.get(ii);
-    return map.put(key, val, ii);
+    return map.put(key, val, info);
   }
 }
