@@ -8,7 +8,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class OutTab extends StandardFunc {
@@ -16,7 +16,7 @@ public final class OutTab extends StandardFunc {
   private static final Str TAB = Str.get("\t");
 
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
+  public Item item(final QueryContext qc, final InputInfo ii) {
     return TAB;
   }
 }
