@@ -11,13 +11,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class ProfVariables extends StandardFunc {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    FnTrace.dump(token(qc.stack.dump()), null, qc);
+  public Item item(final QueryContext qc, final InputInfo ii) {
+    FnTrace.trace(token(qc.stack.dump()), null, qc);
     return null;
   }
 }
