@@ -8,14 +8,14 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class RepoInstall extends RepoFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     checkCreate(qc);
-    new RepoManager(qc.context, ii).install(Token.string(toToken(exprs[0], qc)));
+    new RepoManager(qc.context, info).install(Token.string(toToken(exprs[0], qc)));
     return null;
   }
 }
