@@ -11,14 +11,14 @@ import org.basex.query.util.list.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class XQueryInvoke extends XQueryEval {
   @Override
   protected ItemList eval(final QueryContext qc) throws QueryException {
     checkCreate(qc);
-    final IO io = checkPath(exprs[0], qc);
+    final IO io = checkPath(0, qc);
     try {
       return eval(qc, io.read(), io.path(), false);
     } catch(final IOException ex) {
