@@ -6,7 +6,7 @@ import org.basex.query.value.node.*;
 /**
  * ANode iterator interface.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public abstract class NodeIter extends Iter {
@@ -14,7 +14,7 @@ public abstract class NodeIter extends Iter {
   public abstract ANode next() throws QueryException;
 
   @Override
-  public ANode get(final long i) throws QueryException {
+  public ANode get(final long i) {
     return null;
   }
 }
