@@ -17,7 +17,7 @@ import org.basex.util.hash.*;
 /**
  * Delete expression.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Lukas Kircher
  */
 public final class Delete extends Update {
@@ -35,11 +35,11 @@ public final class Delete extends Update {
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Iter t = qc.iter(exprs[0]);
     for(Item i; (i = t.next()) != null;) {
-      if(!(i instanceof ANode)) throw UPTRGDELEMPT.get(info);
+      if(!(i instanceof ANode)) throw UPTRGDELEMPT_X.get(info, i);
       final ANode n = (ANode) i;
       // nodes without parents are ignored
       if(n.parent() == null) continue;
-      final Updates updates = qc.resources.updates();
+      final Updates updates = qc.updates();
       final DBNode dbn = updates.determineDataRef(n, qc);
       updates.add(new DeleteNode(dbn.pre(), dbn.data(), info), qc);
     }
