@@ -10,7 +10,7 @@ import org.basex.util.list.*;
 /**
  * Update primitive for the {@link Function#_DB_DELETE} function.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class DBDelete extends DBUpdate {
@@ -48,5 +48,5 @@ public final class DBDelete extends DBUpdate {
   }
 
   @Override
-  public void prepare(final MemData tmp) { }
+  public void prepare() { }
 }
