@@ -16,21 +16,21 @@ import org.basex.util.list.*;
 /**
  * Abstract class for formatting data in different languages.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public abstract class Formatter extends FormatUtil {
   /** Military timezones. */
   private static final byte[] MIL = token("YXWVUTSRQPONZABCDEFGHIKLM");
-  /** Token: Nn. */
-  private static final byte[] NN = { 'N', 'n' };
+  /** Token: n. */
+  private static final byte[] N = { 'n' };
   /** Allowed calendars. */
   private static final byte[][] CALENDARS = tokens(
     "ISO", "AD", "AH", "AME", "AM", "AP", "AS", "BE", "CB", "CE", "CL", "CS", "EE", "FE",
     "JE", "KE", "KY", "ME", "MS", "NS", "OS", "RS", "SE", "SH", "SS", "TE", "VE", "VS");
 
   /** Default language: English. */
-  private static final byte[] EN = token("en");
+  public static final byte[] EN = token("en");
   /** Formatter instances. */
   private static final TokenObjMap<Formatter> MAP = new TokenObjMap<>();
 
@@ -119,26 +119,30 @@ public abstract class Formatter extends FormatUtil {
    * @param cal calendar
    * @param plc place
    * @param ii input info
+   * @param sc static context
    * @return formatted string
    * @throws QueryException query exception
    */
   public final byte[] formatDate(final ADate date, final byte[] lng, final byte[] pic,
-      final byte[] cal, final byte[] plc, final InputInfo ii) throws QueryException {
+      final byte[] cal, final byte[] plc, final InputInfo ii, final StaticContext sc)
+      throws QueryException {
 
     final TokenBuilder tb = new TokenBuilder();
     if(lng.length != 0 && MAP.get(lng) == null) tb.add("[Language: en]");
-    boolean iso = false;
     if(cal.length != 0) {
-      final QNm qnm = QNm.resolve(cal);
-      if(qnm == null) throw CALQNAME_X.get(ii, cal);
-      if(!qnm.hasURI()) {
+      final QNm qnm;
+      try {
+        qnm = QNm.resolve(cal, sc);
+      } catch(final QueryException ex) {
+        throw CALQNAME_X.get(ii, cal);
+      }
+      if(qnm.uri().length == 0) {
         int c = -1;
         final byte[] ln = qnm.local();
         final int cl = CALENDARS.length;
         while(++c < cl && !eq(CALENDARS[c], ln));
         if(c == cl) throw CALWHICH_X.get(ii, cal);
         if(c > 1) tb.add("[Calendar: AD]");
-        iso = c == 0;
       }
     }
     if(plc.length != 0) tb.add("[Place: ]");
@@ -184,7 +188,7 @@ public abstract class Formatter extends FormatUtil {
           case 'F':
             num = date.toJava().toGregorianCalendar().get(Calendar.DAY_OF_WEEK) - 1;
             if(num == 0) num = 7;
-            pres = NN;
+            pres = N;
             err = tim;
             break;
           case 'W':
@@ -193,25 +197,27 @@ public abstract class Formatter extends FormatUtil {
             break;
           case 'w':
             num = date.toJava().toGregorianCalendar().get(Calendar.WEEK_OF_MONTH);
-            if(iso && num == 0) num = 5;
+            // first week of month: fix value, according to ISO 8601
+            if(num == 0) num = new Dtm(new Dtm(date), new DTDur(date.day() * 24, 0), false, ii).
+                toJava().toGregorianCalendar().get(Calendar.WEEK_OF_MONTH);
             err = tim;
             break;
           case 'H':
-            num = date.hou();
+            num = date.hour();
             err = dat;
             break;
           case 'h':
-            num = date.hou() % 12;
+            num = date.hour() % 12;
             if(num == 0) num = 12;
             err = dat;
             break;
           case 'P':
-            num = date.hou() / 12;
-            pres = NN;
+            num = date.hour() / 12;
+            pres = N;
             err = dat;
             break;
           case 'm':
-            num = date.min();
+            num = date.minute();
             pres = token("01");
             err = dat;
             break;
@@ -231,11 +237,11 @@ public abstract class Formatter extends FormatUtil {
             pres = token("01:01");
             break;
           case 'C':
-            pres = NN;
+            pres = N;
             break;
           case 'E':
             num = date.yea();
-            pres = NN;
+            pres = N;
             err = tim;
             break;
           default:
@@ -246,7 +252,7 @@ public abstract class Formatter extends FormatUtil {
 
         // parse presentation modifier(s) and width modifier
         final DateFormat fp = new DateFormat(substring(marker, 1), pres, ii);
-        if(max) {
+        if(max && fp.max == Integer.MAX_VALUE) {
           // limit maximum length of numeric output
           int mx = 0;
           final int fl = fp.primary.length;
@@ -601,6 +607,7 @@ public abstract class Formatter extends FormatUtil {
       }
       reverse.add(ch);
     }
+    while(min-- >= 0) reverse.add(zero);
 
     // reverse result and add ordinal suffix
     final TokenBuilder result = new TokenBuilder();
