@@ -8,7 +8,7 @@ import org.basex.query.value.*;
 /**
  * An array containing more elements than fit into a {@link SmallArray}.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 final class BigArray extends Array {
@@ -40,7 +40,7 @@ final class BigArray extends Array {
    */
   BigArray(final Value[] left, final Value[] right) {
     this.left = left;
-    this.middle = FingerTree.empty();
+    middle = FingerTree.empty();
     this.right = right;
     assert left.length >= MIN_DIGIT && left.length <= MAX_DIGIT
         && right.length >= MIN_DIGIT && right.length <= MAX_DIGIT;
@@ -219,6 +219,31 @@ final class BigArray extends Array {
     return middle.get(index - left.length);
   }
 
+  @Override
+  public Array put(final long pos, final Value val) {
+    if(pos < 0) throw new IndexOutOfBoundsException(Long.toString(pos));
+    long p = pos;
+    if(p < left.length) {
+      final Value[] newLeft = left.clone();
+      newLeft[(int) p] = val;
+      return new BigArray(newLeft, middle, right);
+    }
+    p -= left.length;
+
+    final long m = middle.size();
+    if(p < m) {
+      return new BigArray(left, middle.set(p, val), right);
+    }
+    p -= m;
+
+    if(p < right.length) {
+      final Value[] newRight = right.clone();
+      newRight[(int) p] = val;
+      return new BigArray(left, middle, newRight);
+    }
+    throw new IndexOutOfBoundsException(pos + " > " + arraySize());
+  }
+
   @Override
   public Array reverseArray() {
     final int l = left.length, r = right.length;
@@ -527,7 +552,7 @@ final class BigArray extends Array {
    * @param merged the merged digits
    * @return the array
    */
-  private Array fromMerged(final Value[] merged) {
+  private static Array fromMerged(final Value[] merged) {
     if(merged.length <= MAX_SMALL) return new SmallArray(merged);
     final int mid = merged.length / 2;
     return new BigArray(slice(merged, 0, mid), slice(merged, mid, merged.length));
