@@ -8,7 +8,7 @@ import org.basex.util.*;
 /**
  * Java item.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class Jav extends Item {
@@ -30,12 +30,7 @@ public final class Jav extends Item {
 
   @Override
   public byte[] string(final InputInfo ii) throws QueryException {
-    return materialize(ii).value;
-  }
-
-  @Override
-  public Str materialize(final InputInfo ii) throws QueryException {
-    return Str.get(value, qc, ii);
+    return Str.get(value, qc, ii).value;
   }
 
   @Override
@@ -49,6 +44,11 @@ public final class Jav extends Item {
     return Token.eq(string(ii), it.string(ii));
   }
 
+  @Override
+  public boolean sameKey(final Item it, final InputInfo ii) {
+    return false;
+  }
+
   @Override
   public int diff(final Item it, final Collation coll, final InputInfo ii) throws QueryException {
     return Token.diff(string(ii), it.string(ii));
