@@ -18,7 +18,7 @@ import org.basex.util.*;
 /**
  * XQuery atomic types.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public enum AtomType implements Type {
@@ -400,8 +400,9 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       final Item it = value instanceof Item ? (Item) value : Str.get(value.toString());
       final BigDecimal v = checkNum(it, ii).dec(ii), i = v.setScale(0, RoundingMode.DOWN);
+      // equals() used to also test fractional digits
       if(v.signum() < 0 || v.compareTo(Uln.MAXULN) > 0 ||
-        it.type.isStringOrUntyped() && !v.equals(i)) throw funCastError(ii, this, it);
+        it.type.isStringOrUntyped() && !v.equals(i)) throw castError(this, it, ii);
       return Uln.get(i.toBigInteger());
     }
   },
@@ -469,7 +470,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item instanceof Dur) return new Dur((Dur) item);
       if(str(item)) return new Dur(item.string(ii), ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -485,7 +486,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item instanceof Dur) return new YMDur((Dur) item);
       if(str(item)) return new YMDur(item.string(ii), ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -501,7 +502,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item instanceof Dur) return new DTDur((Dur) item);
       if(str(item)) return new DTDur(item.string(ii), ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -517,7 +518,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item.type == DAT) return new Dtm((ADate) item);
       if(str(item)) return new Dtm(item.string(ii), ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -536,7 +537,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item.type == DTM) return new Dat((ADate) item);
       if(str(item)) return new Dat(item.string(ii), ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -552,7 +553,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item.type == DTM) return new Tim((ADate) item);
       if(str(item)) return new Tim(item.string(ii), ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -568,7 +569,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item.type == DTM || item.type == DAT) return new GDt((ADate) item, this);
       if(str(item)) return new GDt(item.string(ii), this, ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -584,7 +585,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item.type == DTM || item.type == DAT) return new GDt((ADate) item, this);
       if(str(item)) return new GDt(item.string(ii), this, ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -600,7 +601,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item.type == DTM || item.type == DAT) return new GDt((ADate) item, this);
       if(str(item)) return new GDt(item.string(ii), this, ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -616,7 +617,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item.type == DTM || item.type == DAT) return new GDt((ADate) item, this);
       if(str(item)) return new GDt(item.string(ii), this, ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -632,7 +633,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item.type == DTM || item.type == DAT) return new GDt((ADate) item, this);
       if(str(item)) return new GDt(item.string(ii), this, ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -648,7 +649,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item instanceof ANum) return Bln.get(item.bool(ii));
       if(str(item)) return Bln.get(Bln.parse(item.string(ii), ii));
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Bln cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -668,7 +669,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item instanceof Bin) return new B64((Bin) item, ii);
       if(str(item)) return new B64(item.string(ii), ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -684,7 +685,7 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
       if(item instanceof Bin) return new Hex((Bin) item, ii);
       if(str(item)) return new Hex(item.string(ii), ii);
-      throw castError(ii, item, this);
+      throw castError(item, this, ii);
     }
     @Override
     public Item cast(final Object value, final QueryContext qc, final StaticContext sc,
@@ -699,7 +700,7 @@ public enum AtomType implements Type {
     public Uri cast(final Item item, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) throws QueryException {
 
-      if(!item.type.isStringOrUntyped()) throw castError(ii, item, this);
+      if(!item.type.isStringOrUntyped()) throw castError(item, this, ii);
       final Uri u = Uri.uri(item.string(ii));
       if(!u.isValid()) throw funCastErr(item, ii);
       return u;
@@ -717,7 +718,7 @@ public enum AtomType implements Type {
     public QNm cast(final Item item, final QueryContext qc, final StaticContext sc,
         final InputInfo ii) throws QueryException {
 
-      if(item.type != STR && !item.type.isUntyped()) throw castError(ii, item, this);
+      if(item.type != STR && !item.type.isUntyped()) throw castError(item, this, ii);
       final byte[] nm = trim(item.string(ii));
       if(!XMLToken.isQName(nm)) throw funCastErr(item, ii);
       final QNm qn = new QNm(nm, sc);
@@ -819,7 +820,7 @@ public enum AtomType implements Type {
   public Item cast(final Item item, final QueryContext qc, final StaticContext sc,
       final InputInfo ii) throws QueryException {
     if(item.type == this) return item;
-    throw castError(ii, item, this);
+    throw castError(item, this, ii);
   }
 
   @Override
@@ -842,23 +843,23 @@ public enum AtomType implements Type {
   }
 
   @Override
-  public final boolean eq(final Type t) {
-    return this == t;
+  public final boolean eq(final Type type) {
+    return this == type;
   }
 
   @Override
-  public final boolean instanceOf(final Type t) {
-    return this == t || parent != null && parent.instanceOf(t);
+  public final boolean instanceOf(final Type type) {
+    return this == type || parent != null && parent.instanceOf(type);
   }
 
   @Override
-  public final Type union(final Type t) {
-    if(instanceOf(t)) return t;
-    if(t.instanceOf(this)) return this;
+  public final Type union(final Type type) {
+    if(instanceOf(type)) return type;
+    if(type.instanceOf(this)) return this;
 
-    if(t instanceof AtomType) {
+    if(type instanceof AtomType) {
       final List<AtomType> arr = new ArrayList<>();
-      for(AtomType at = (AtomType) t; (at = at.parent) != null;) arr.add(at);
+      for(AtomType at = (AtomType) type; (at = at.parent) != null;) arr.add(at);
       for(AtomType p = this; (p = p.parent) != null;)
         if(arr.contains(p)) return p;
     }
@@ -866,8 +867,8 @@ public enum AtomType implements Type {
   }
 
   @Override
-  public final Type intersect(final Type t) {
-    return instanceOf(t) ? this : t.instanceOf(this) ? t : null;
+  public final Type intersect(final Type type) {
+    return instanceOf(type) ? this : type.instanceOf(this) ? type : null;
   }
 
   @Override
@@ -895,39 +896,39 @@ public enum AtomType implements Type {
   final Item checkNum(final Item item, final InputInfo ii) throws QueryException {
     final Type ip = item.type;
     if(item instanceof ANum || ip.isStringOrUntyped() && ip != URI || ip == BLN) return item;
-    throw castError(ii, item, this);
+    throw castError(item, this, ii);
   }
 
   /**
    * Checks the validity of the specified object and returns its long value.
-   * @param o value to be checked
+   * @param value value to be checked
    * @param min minimum value
-   * @param max maximum value
+   * @param max maximum value (no limit if identical to min)
    * @param ii input info
    * @return integer value
    * @throws QueryException query exception
    */
-  final long checkLong(final Object o, final long min, final long max, final InputInfo ii)
+  final long checkLong(final Object value, final long min, final long max, final InputInfo ii)
       throws QueryException {
 
-    final Item it = o instanceof Item ? (Item) o : Str.get(o.toString());
+    final Item it = value instanceof Item ? (Item) value : Str.get(value.toString());
     checkNum(it, ii);
 
     final Type ip = it.type;
     if(ip == DBL || ip == FLT) {
       final double d = it.dbl(ii);
-      if(Double.isNaN(d) || Double.isInfinite(d)) throw valueError(ii, this, it.string(ii));
-      if(min != max && (d < min || d > max)) throw funCastError(ii, this, it);
+      if(Double.isNaN(d) || Double.isInfinite(d)) throw valueError(this, it.string(ii), ii);
+      if(min != max && (d < min || d > max)) throw castError(this, it, ii);
       if(d < Long.MIN_VALUE || d > Long.MAX_VALUE) throw INTRANGE_X.get(ii, d);
       return (long) d;
     }
     if(min == max) {
       final double d = it.dbl(ii);
-      if(d < Long.MIN_VALUE || d > Long.MAX_VALUE) throw funCastError(ii, this, it);
+      if(d < Long.MIN_VALUE || d > Long.MAX_VALUE) throw castError(this, it, ii);
     }
 
     final long l = it.itr(ii);
-    if(min != max && (l < min || l > max)) throw funCastError(ii, this, it);
+    if(min != max && (l < min || l > max)) throw castError(this, it, ii);
     return l;
   }
 
@@ -955,7 +956,7 @@ public enum AtomType implements Type {
   }
 
   /**
-   * Returns a casting exception.
+   * Returns a cast exception.
    * @param it item to be included in the error message
    * @param ii input info
    * @return query exception
