@@ -20,7 +20,7 @@ import java.util.*;
  * the following four bytes</li>
  * </ul>
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class Num {
@@ -91,13 +91,15 @@ public final class Num {
   }
 
   /**
-   * Compresses and stores an integer value to the specified byte array.
+   * Compresses and stores an integer value at the beginning of the byte array.
    * @param array array
    * @param value value to be stored
-   * @param pos position where the value is to be stored
+   * @return length
    */
-  public static void set(final byte[] array, final int value, final int pos) {
-    set(array, value, pos, length(value));
+  public static int set(final byte[] array, final int value) {
+    final int l = length(value);
+    set(array, value, 0, l);
+    return l;
   }
 
   /**
@@ -142,6 +144,21 @@ public final class Num {
     return v < 0 || v > 0x3FFFFFFF ? 5 : v > 0x3FFF ? 4 : v > 0x3F ? 2 : 1;
   }
 
+  /**
+   * Returns a string representation of the specified number array.
+   * @param num numbers
+   * @return string
+   */
+  public static String toString(final byte[] num) {
+    final StringBuilder sb = new StringBuilder();
+    final int pos = size(num);
+    for(int ip = 4; ip < pos; ip += length(num, ip)) {
+      if(ip > 4) sb.append(',');
+      sb.append(get(num, ip));
+    }
+    return sb.toString();
+  }
+
   // PRIVATE STATIC METHODS ===================================================
 
   /**
@@ -149,7 +166,7 @@ public final class Num {
    * @param a array to be resized
    * @param p current array position
    * @param l length of new entry
-   * @return new array
+   * @return original or new array
    */
   private static byte[] check(final byte[] a, final int p, final int l) {
     final int s = a.length;
