@@ -10,7 +10,7 @@ import org.basex.util.hash.*;
 /**
  * Simple stemming directory for full-text requests.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class StemDir extends TokenMap {
@@ -23,7 +23,7 @@ public final class StemDir extends TokenMap {
     try {
       for(final byte[] sl : split(fl.read(), '\n')) {
         byte[] val = null;
-        for(final byte[] st : split(normalize(sl), ' ')) {
+        for(final byte[] st : distinctTokens(sl)) {
           if(val == null) val = st;
           else put(st, val);
         }
