@@ -7,7 +7,7 @@ import org.basex.util.*;
 /**
  * Resizable-array implementation for native int values.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public class IntList extends ElementList {
@@ -207,7 +207,7 @@ public class IntList extends ElementList {
    * Returns an array with all elements and resets the array size.
    * @return array
    */
-  public int[] next() {
+  public final int[] next() {
     final int[] lst = Arrays.copyOf(list, size);
     reset();
     return lst;
@@ -218,7 +218,7 @@ public class IntList extends ElementList {
    * Warning: the function must only be called if the list is discarded afterwards.
    * @return array (internal representation!)
    */
-  public int[] finish() {
+  public final int[] finish() {
     final int[] lst = list;
     list = null;
     final int s = size;
@@ -226,19 +226,32 @@ public class IntList extends ElementList {
   }
 
   /**
-   * Removes duplicate entries from a sorted list.
+   * Removes duplicate entries.
    * @return self reference
    */
-  public IntList distinct() {
-    int i = 1;
-    for(int j = 1; j < size; ++j) {
-      while(j < size && list[i - 1] == list[j]) j++;
-      if(j < size) list[i++] = list[j];
+  public final IntList distinct() {
+    if(!isEmpty()) {
+      int i = 1;
+      for(int j = 1; j < size; ++j) {
+        while(j < size && list[i - 1] == list[j]) j++;
+        if(j < size) list[i++] = list[j];
+      }
+      size = i;
     }
-    size = i;
     return this;
   }
 
+  /**
+   * Sorts the data and returns an array with offsets to the sorted array.
+   * See {@link Array#createOrder(int[], boolean)} for more details.
+   * @return array with new order
+   */
+  public final int[] createOrder() {
+    final IntList il = Array.number(size);
+    il.sort(list, true);
+    return il.finish();
+  }
+
   /**
    * Sorts the data.
    * @return self reference
@@ -679,6 +692,6 @@ public class IntList extends ElementList {
 
   @Override
   public String toString() {
-    return Arrays.toString(toArray());
+    return list == null ? "" : Arrays.toString(toArray());
   }
 }
