@@ -3,7 +3,7 @@ package org.basex.util.options;
 /**
  * Single option, stored in {@link Options} instances.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  * @param <O> option type
  */
@@ -23,7 +23,7 @@ public abstract class Option<O> {
    * Returns the name of the option.
    * @return name
    */
-  public String name() {
+  public final String name() {
     return name;
   }
 
@@ -48,4 +48,13 @@ public abstract class Option<O> {
     if(v != null && !v.toString().isEmpty()) sb.append('=').append(v);
     return sb.toString();
   }
+
+  /**
+   * Returns a string representation of the option with the specified argument.
+   * @param arg argument
+   * @return string representation
+   */
+  public final String arg(final String arg) {
+    return "declare option output:" + name() + "'" + arg.replace("'", "''") + "';";
+  }
 }
