@@ -11,7 +11,7 @@ import org.junit.*;
 /**
  * Tests the command-line arguments of the standalone starter class.
  *
-* @author BaseX Team 2005-15, BSD License
+* @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class BaseXStandaloneTest extends BaseXTest {
@@ -28,15 +28,12 @@ public final class BaseXStandaloneTest extends BaseXTest {
 
   @Override
   protected String run(final String... args) throws IOException {
-    try {
-      final ArrayOutput ao = new ArrayOutput();
+    try(final ArrayOutput ao = new ArrayOutput()) {
       System.setOut(new PrintStream(ao));
-      System.setErr(NULL);
       new BaseX(args);
       return ao.toString();
     } finally {
       System.setOut(OUT);
-      System.setErr(ERR);
     }
   }
 }
