@@ -17,12 +17,12 @@ import org.junit.Test;
 /**
  * This class tests user permissions.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Andreas Weiler
  */
 public final class PermissionTest extends SandboxTest {
   /** Name of the database to be renamed. */
-  private static final String RENAMED = Util.className(PermissionTest.class) + 'r';
+  private static final String NAME2 = NAME + '2';
   /** Test folder. */
   private static final String FOLDER = "src/test/resources/";
   /** Test repository. **/
@@ -63,7 +63,7 @@ public final class PermissionTest extends SandboxTest {
       }
 
       ok(new CreateUser(NAME, NAME), adminSession);
-      ok(new CreateDB(RENAMED), adminSession);
+      ok(new CreateDB(NAME2), adminSession);
       server.context.soptions.set(StaticOptions.REPOPATH, REPO);
       testSession = createClient(NAME, NAME);
 
@@ -79,11 +79,11 @@ public final class PermissionTest extends SandboxTest {
   public void cleanUp() {
     try {
       testSession.close();
-      adminSession.execute(new DropDB(RENAMED));
+      adminSession.execute(new DropDB(NAME2));
       adminSession.execute(new DropDB(NAME));
       adminSession.close();
       // give the server some time to clean up the sessions before next test
-      Performance.sleep(100);
+      Performance.sleep(500);
     } catch(final Exception ex) {
       fail(Util.message(ex));
     }
@@ -117,10 +117,11 @@ public final class PermissionTest extends SandboxTest {
     no(new Find(NAME), testSession);
     no(new Optimize(), testSession);
     // XQuery update
+    no(new XQuery("Q{java.lang.String}new('x')"), testSession);
     no(new XQuery("for $item in doc('" + NAME + "')//xml " +
       "return rename node $item as 'null'"), testSession);
     no(new CreateDB(NAME, "<xml/>"), testSession);
-    no(new Rename(RENAMED, RENAMED + '2'), testSession);
+    no(new Rename(NAME2, NAME2 + '2'), testSession);
     no(new CreateIndex("SUMMARY"), testSession);
     no(new DropDB(NAME), testSession);
     no(new DropIndex("SUMMARY"), testSession);
@@ -133,6 +134,9 @@ public final class PermissionTest extends SandboxTest {
     no(new AlterPassword(NAME, NAME), testSession);
     no(new AlterUser(NAME, "test2"), testSession);
     no(new Flush(), testSession);
+
+    no(new JobsList(), testSession);
+    no(new JobsStop("job0"), testSession);
   }
 
   /** Tests all commands where read permission is needed. */
@@ -157,12 +161,13 @@ public final class PermissionTest extends SandboxTest {
     no(new RepoDelete("http://www.pkg3.com", null), testSession);
 
     // XQuery update
+    no(new XQuery("Q{java.lang.String}new('x')"), testSession);
     no(new XQuery("for $n in " + DOC.args(NAME) + "//xml return delete node $n"), testSession);
     no(new XQuery(_DB_CREATE.args(NAME)), testSession);
     no(new Optimize(), testSession);
     no(new CreateDB(NAME, "<xml/>"), testSession);
-    no(new Replace(RENAMED, "<xml />"), testSession);
-    no(new Rename(RENAMED, RENAMED + '2'), testSession);
+    no(new Replace(NAME2, "<xml />"), testSession);
+    no(new Rename(NAME2, NAME2 + '2'), testSession);
     no(new CreateIndex("SUMMARY"), testSession);
     no(new DropDB(NAME), testSession);
     no(new DropIndex("SUMMARY"), testSession);
@@ -177,19 +182,22 @@ public final class PermissionTest extends SandboxTest {
     no(new AlterUser(NAME, "test2"), testSession);
     no(new Flush(), testSession);
     ok(new Close(), testSession);
+
+    no(new JobsList(), testSession);
+    no(new JobsStop("job0"), testSession);
   }
 
   /** Tests all commands where write permission is needed. */
   @Test
   public void writePermsNeeded() {
     ok(new Grant("write", NAME), adminSession);
-    ok(new Open(RENAMED), testSession);
-    ok(new Rename(RENAMED, RENAMED + '2'), testSession);
-    ok(new Rename(RENAMED + '2', RENAMED), testSession);
+    ok(new Open(NAME2), testSession);
+    ok(new Rename(NAME2, NAME2 + '2'), testSession);
+    ok(new Rename(NAME2 + '2', NAME2), testSession);
 
     // replace Test
     ok(new Close(), testSession);
-    ok(new Open(RENAMED), testSession);
+    ok(new Open(NAME2), testSession);
     ok(new Add(NAME + ".xml", "<xml>1</xml>"), testSession);
     ok(new Optimize(), testSession);
     ok(new Replace(NAME + ".xml", "<xmlr>2</xmlr>"), testSession);
@@ -200,6 +208,7 @@ public final class PermissionTest extends SandboxTest {
     no(new RepoDelete("http://www.pkg3.com", null), testSession);
 
     // XQuery Update
+    no(new XQuery("Q{java.lang.String}new('x')"), testSession);
     ok(new XQuery("for $item in doc('" + NAME + "')//xml " +
         "return rename node $item as 'null'"), testSession);
     no(new XQuery(_DB_CREATE.args(NAME)), testSession);
@@ -225,6 +234,9 @@ public final class PermissionTest extends SandboxTest {
     no(new Grant("none", NAME), testSession);
     no(new AlterPassword(NAME, NAME), testSession);
     no(new AlterUser(NAME, "test2"), testSession);
+
+    no(new JobsList(), testSession);
+    no(new JobsStop("job0"), testSession);
   }
 
   /** Tests all commands where create permission is needed. */
@@ -253,6 +265,9 @@ public final class PermissionTest extends SandboxTest {
     no(new Grant("none", NAME), testSession);
     no(new AlterPassword(NAME, NAME), testSession);
     no(new org.basex.core.cmd.Test(FOLDER + "tests-ok.xqm"), testSession);
+
+    no(new JobsList(), testSession);
+    no(new JobsStop("job0"), testSession);
   }
 
   /** Tests all commands where admin permission is needed. */
@@ -279,6 +294,11 @@ public final class PermissionTest extends SandboxTest {
     ok(new RepoList(), testSession);
     ok(new RepoDelete("http://www.pkg3.com", null), testSession);
     ok(new org.basex.core.cmd.Test(FOLDER + "tests-ok.xqm"), testSession);
+
+    ok(new XQuery("Q{java.lang.String}new('x')"), testSession);
+
+    ok(new JobsList(), testSession);
+    ok(new JobsStop("job0"), testSession);
   }
 
   /** Drops users. */
