@@ -8,7 +8,7 @@ import org.junit.*;
 /**
  * Test class for IO methods.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class IOTest {
@@ -17,11 +17,12 @@ public final class IOTest {
   public void urlToFile() {
     if(Prop.WIN) {
       assertEquals("C:/x y", IO.get("file:/c:/x%20y").path());
-      assertEquals("C:/x y", IO.get("file://C:/x y").path());
       assertEquals("D:/x+y", IO.get("file:///D:/x%2By").path());
       assertEquals("G:/X", IO.get("file:///G:/X").path());
+      assertEquals("G:/X/", IO.get("file:///G:/X/").path());
     } else {
-      assertEquals("/x y", IOUrl.toFile("file:///x%20y"));
+      assertEquals("/x y", IO.get("file:///x%20y").path());
+      assertEquals("/x y/", IO.get("file:///x%20y/").path());
     }
   }
 
