@@ -5,12 +5,12 @@ import javax.xml.bind.annotation.*;
 /**
  * Class for testing the (un)marshalling and serialization of objects.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Michael Hedenus
  */
 @XmlRootElement(name = "domain-object")
 @XmlAccessorType(XmlAccessType.FIELD)
-class SAXSerializerObject {
+public class SAXSerializerObject {
   /** Name of the object. */
   @XmlAttribute
   private String name;
@@ -28,7 +28,7 @@ class SAXSerializerObject {
    * @param name name
    * @param value value
    */
-  public SAXSerializerObject(final String name, final long value) {
+  SAXSerializerObject(final String name, final long value) {
     this.name = name;
     this.value = value;
   }
