@@ -2,47 +2,23 @@ package org.basex.query;
 
 import static org.junit.Assert.*;
 
-import java.io.*;
-
 import org.basex.*;
-import org.basex.io.out.*;
-import org.basex.io.serial.*;
 import org.basex.util.*;
 
 /**
  * This class contains some methods for performing advanced query tests.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public abstract class AdvancedQueryTest extends SandboxTest {
-  /** Base uri. */
-  private static final String BASEURI = new File(".").getAbsolutePath();
-
-  /**
-   * Runs the specified query and normalizes newlines.
-   * @param query query string
-   * @return result
-   */
-  protected static String query(final String query) {
-    try {
-      return run(query);
-    } catch(final QueryException | IOException ex) {
-      Util.errln(Util.message(ex));
-      Util.stack(12);
-      final AssertionError err = new AssertionError("Query failed:\n" + query);
-      err.initCause(ex);
-      throw err;
-    }
-  }
-
   /**
    * Checks if a query yields the specified string.
    * @param query query string
    * @param expected expected query result
    */
   protected static void query(final String query, final Object expected) {
-    final String res = query(query);
+    final String res = query(query).replaceAll("(\r?\n|\r) *", "\n");
     final String exp = expected.toString();
     assertEquals("Wrong result:\n[Q] " + query + "\n[E] \u00bb" + exp +
         "\u00ab\n[F] \u00bb" + res + "\u00ab\n", exp, res);
@@ -82,7 +58,7 @@ public abstract class AdvancedQueryTest extends SandboxTest {
    * @param result query result
    */
   protected static void contains(final String query, final String result) {
-    final String res = query(query);
+    final String res = normNL(query(query));
     if(!res.contains(result))
       fail("Result does not contain \"" + result + "\":\n" + query + "\n[E] " +
           result + "\n[F] " + res);
@@ -95,11 +71,11 @@ public abstract class AdvancedQueryTest extends SandboxTest {
    */
   protected static void error(final String query, final QueryError... error) {
     try {
-      final String res = run(query);
-      final StringBuilder sb = new StringBuilder("Query did not fail:\n");
-      sb.append(query).append("\n[E]");
-      for(final QueryError e : error) sb.append(' ').append(e);
-      fail(sb.append("\n[F] ").append(res).toString());
+      final String res = eval(query);
+      final TokenBuilder tb = new TokenBuilder("Query did not fail:\n");
+      tb.add(query).add("\n[E] Error: ");
+      for(final QueryError e : error) tb.add(' ').add(e.qname().prefixId());
+      fail(tb.add("\n[F] ").add(res).toString());
     } catch(final QueryIOException ex) {
       check(query, ex.getCause(), error);
     } catch(final QueryException ex) {
@@ -131,7 +107,8 @@ public abstract class AdvancedQueryTest extends SandboxTest {
         int c = 0;
         for(final QueryError er : errors) tb.add(c++ == 0 ? "" : "/").add(er.name());
         ex.printStackTrace();
-        fail(tb.add("\nResult: ").add(err.name() + " (" + err.qname() + ')').toString());
+        fail(tb.add("\nResult: ").add(err.name() + " (" + ex.getLocalizedMessage() + ')').
+            toString());
       } else {
         int c = 0;
         for(final QueryError er : errors) tb.add(c++ == 0 ? "" : "/").add(er.qname().local());
@@ -150,22 +127,4 @@ public abstract class AdvancedQueryTest extends SandboxTest {
       "xmlns='http://www.w3.org/2010/xslt-xquery-serialization'>" + arg +
       "</serialization-parameters>";
   }
-
-  /**
-   * Runs the specified query and normalizes newlines.
-   * @param query query string
-   * @return result
-   * @throws QueryException query exception
-   * @throws IOException I/O exception
-   */
-  private static String run(final String query) throws QueryException, IOException {
-    final ArrayOutput ao = new ArrayOutput();
-    try(final QueryProcessor qp = new QueryProcessor(query, context)) {
-      qp.sc.baseURI(BASEURI);
-      try(final Serializer ser = qp.getSerializer(ao)) {
-        qp.value().serialize(ser);
-      }
-    }
-    return normNL(ao.toString());
-  }
 }
