@@ -5,6 +5,8 @@ import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 import static org.junit.Assert.*;
 
+import java.io.*;
+
 import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.data.*;
@@ -13,14 +15,13 @@ import org.basex.io.serial.*;
 import org.basex.query.up.primitives.node.*;
 import org.basex.query.util.*;
 import org.basex.query.value.node.*;
-import org.basex.util.*;
 import org.junit.*;
 import org.junit.Test;
 
 /**
  * This class tests namespaces.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Lukas Kircher
  */
 public final class NamespaceTest extends AdvancedQueryTest {
@@ -54,12 +55,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
   /**
    * Checks if namespace hierarchy structure is updated correctly on the
    * descendant axis after a NSNode has been inserted.
-   * @throws Exception exception
    */
   @Test
-  public void insertIntoShiftPreValues() throws Exception {
+  public void insertIntoShiftPreValues() {
     create(12);
-    query("insert node <b xmlns:ns='A'/> into doc('d12')/*:a/*:b");
+    query("insert node <b xmlns:ns='A'/> into db:open('d12')/*:a/*:b");
     assertEquals(NL +
         "  Pre[3] xmlns:ns=\"A\"" + NL +
         "  Pre[4] xmlns=\"B\"",
@@ -69,12 +69,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
   /**
    * Checks if namespace hierarchy structure is updated correctly on the
    * descendant axis after a NSNode has been inserted.
-   * @throws Exception exception
    */
   @Test
-  public void insertIntoShiftPreValues2() throws Exception {
+  public void insertIntoShiftPreValues2() {
     create(13);
-    query("insert node <c/> as first into doc('d13')/a");
+    query("insert node <c/> as first into db:open('d13')/a");
     assertEquals(NL +
         "  Pre[3] xmlns=\"A\"",
         context.data().nspaces.toString());
@@ -83,12 +82,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
   /**
    * Checks if namespace hierarchy structure is updated correctly on the
    * descendant axis after a NSNode has been inserted.
-   * @throws Exception exception
    */
   @Test
-  public void insertIntoShiftPreValues3() throws Exception {
+  public void insertIntoShiftPreValues3() {
     create(14);
-    query("insert node <n xmlns='D'/> into doc('d14')/*:a/*:b");
+    query("insert node <n xmlns='D'/> into db:open('d14')/*:a/*:b");
     assertEquals(NL +
         "  Pre[1] xmlns=\"A\"" + NL +
         "    Pre[2] xmlns=\"B\"" + NL +
@@ -100,12 +98,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
   /**
    * Checks if namespace hierarchy structure is updated correctly on the
    * descendant axis after a NSNode has been deleted.
-   * @throws Exception exception
    */
   @Test
-  public void deleteShiftPreValues() throws Exception {
+  public void deleteShiftPreValues() {
     create(12);
-    query("delete node doc('d12')/a/b");
+    query("delete node db:open('d12')/a/b");
     assertEquals(NL +
         "  Pre[2] xmlns=\"B\"",
         context.data().nspaces.toString());
@@ -114,12 +111,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
   /**
    * Checks if namespace hierarchy structure is updated correctly on the
    * descendant axis after a NSNode has been deleted.
-   * @throws Exception exception
    */
   @Test
-  public void deleteShiftPreValues2() throws Exception {
+  public void deleteShiftPreValues2() {
     create(14);
-    query("delete node doc('d14')/*:a/*:b");
+    query("delete node db:open('d14')/*:a/*:b");
     assertEquals(NL +
         "  Pre[1] xmlns=\"A\"" + NL +
         "    Pre[2] xmlns=\"C\"",
@@ -129,12 +125,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
   /**
    * Checks if namespace hierarchy structure is updated correctly on the
    * descendant axis after a NSNode has been deleted.
-   * @throws Exception exception
    */
   @Test
-  public void deleteShiftPreValues3() throws Exception {
+  public void deleteShiftPreValues3() {
     create(15);
-    query("delete node doc('d15')/*:a/*:c");
+    query("delete node db:open('d15')/*:a/*:c");
     assertEquals(NL +
         "  Pre[1] xmlns=\"A\"" + NL +
         "    Pre[2] xmlns=\"B\"" + NL +
@@ -145,21 +140,19 @@ public final class NamespaceTest extends AdvancedQueryTest {
   /**
    * Checks if namespace hierarchy structure is updated correctly on the
    * descendant axis after a NSNode has been deleted.
-   * @throws Exception exception
    */
   @Test
-  public void deleteShiftPreValues4() throws Exception {
+  public void deleteShiftPreValues4() {
     create(16);
-    query("delete node doc('d16')/a/b");
+    query("delete node db:open('d16')/a/b");
     assertTrue(context.data().nspaces.toString().isEmpty());
   }
 
   /**
    * Inserts an attribute with namespace.
-   * @throws Exception exception
    */
   @Test
-  public void insertAttributeWithNs() throws Exception {
+  public void insertAttributeWithNs() {
     create(1);
     query("insert node attribute { QName('ns', 'pref:local') } { } into /*");
     final Data data = context.data();
@@ -175,22 +168,20 @@ public final class NamespaceTest extends AdvancedQueryTest {
    * Tests for correct namespace hierarchy, esp. if namespace nodes
    * on the following axis of an insert/delete operation are
    * updated correctly.
-   * @throws Exception exception
    */
   @Test
-  public void delete1() throws Exception {
+  public void delete1() {
     create(11);
-    query("delete node doc('d11')/*:a/*:b",
-        "doc('d11')/*:a",
+    query("delete node db:open('d11')/*:a/*:b",
+        "db:open('d11')/*:a",
         "<a xmlns='A'><c xmlns:ns1='AA'><d/></c></a>");
   }
 
   /**
    * Tests if a namespace node is deleted.
-   * @throws Exception exception
    */
   @Test
-  public void delete2() throws Exception {
+  public void delete2() {
     create(21);
     query("delete node //b");
     assertEquals(NL +
@@ -208,27 +199,25 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Detects corrupt namespace hierarchy.
-   * @throws Exception exception
    */
   @Test
-  public void copy2() throws Exception {
+  public void copy2() {
     create(4);
     query(
         "declare namespace a='aa';" +
-        "copy $c:=doc('d4') modify () return $c//a:y",
+        "copy $c:=db:open('d4') modify () return $c//a:y",
         "<a:y xmlns:a='aa' xmlns:b='bb'/>");
   }
 
   /**
    * Detects missing prefix declaration.
-   * @throws Exception exception
    */
   @Test
-  public void copy3() throws Exception {
+  public void copy3() {
     create(4);
     query(
         "declare namespace a='aa';" +
-        "copy $c:=doc('d4')//a:y modify () return $c",
+        "copy $c:=db:open('d4')//a:y modify () return $c",
         "<a:y xmlns:a='aa' xmlns:b='bb'/>");
   }
 
@@ -244,14 +233,13 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Detects bogus namespace after insert.
-   * @throws Exception exception
    */
   @Test
-  public void bogusDetector() throws Exception {
+  public void bogusDetector() {
     create(1);
     query(
-        "insert node <a xmlns='test'><b><c/></b><d/></a> into doc('d1')/x",
-        "declare namespace na = 'test';doc('d1')/x/na:a",
+        "insert node <a xmlns='test'><b><c/></b><d/></a> into db:open('d1')/x",
+        "declare namespace na = 'test';db:open('d1')/x/na:a",
         "<a xmlns='test'><b><c/></b><d/></a>");
   }
 
@@ -275,12 +263,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Detects malformed namespace hierarchy.
-   * @throws Exception exception
    */
   @Test
-  public void nsHierarchy() throws Exception {
+  public void nsHierarchy() {
     create(9);
-    query("insert node <f xmlns='F'/> into doc('d9')//*:e");
+    query("insert node <f xmlns='F'/> into db:open('d9')//*:e");
     assertEquals(NL +
         "  Pre[1] xmlns=\"A\"" + NL +
         "    Pre[4] xmlns=\"D\"" + NL +
@@ -290,12 +277,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Detects malformed namespace hierarchy.
-   * @throws Exception exception
    */
   @Test
-  public void nsHierarchy2() throws Exception {
+  public void nsHierarchy2() {
     create(10);
-    query("insert node <f xmlns='F'/> into doc('d10')//*:e");
+    query("insert node <f xmlns='F'/> into db:open('d10')//*:e");
     assertEquals(NL +
         "  Pre[1] xmlns=\"A\"" + NL +
         "    Pre[4] xmlns=\"D\"" + NL +
@@ -306,10 +292,9 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Detects malformed namespace hierarchy inserting an element.
-   * @throws BaseXException exception
    */
   @Test
-  public void nsHierarchy3() throws BaseXException {
+  public void nsHierarchy3() {
     query(transform(
         "<a xmlns='x'/>",
         "insert node <a xmlns='y'/> into $input"),
@@ -317,7 +302,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
     // in-depth test
     create(2);
-    query("insert node <a xmlns='y'/> into doc('d2')//*:x");
+    query("insert node <a xmlns='y'/> into db:open('d2')//*:x");
     assertEquals(NL +
         "  Pre[1] xmlns=\"xx\"" + NL +
         "    Pre[2] xmlns=\"y\"",
@@ -326,12 +311,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Detects malformed namespace hierarchy adding a document to an empty DB.
-   * @throws BaseXException exception
    */
   @Test
-  public void nsHierarchy4() throws BaseXException {
-    new CreateDB("d00x").execute(context);
-    new Add("x", "<A xmlns='A'><B/><C/></A>").execute(context);
+  public void nsHierarchy4() {
+    execute(new CreateDB("d00x"));
+    execute(new Add("x", "<A xmlns='A'><B/><C/></A>"));
     query("/", "<A xmlns='A'><B/><C/></A>");
   }
 
@@ -346,54 +330,50 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Test query.
-   * @throws Exception exception
    */
   @Test
-  public void insertD2intoD1() throws Exception {
+  public void insertD2intoD1() {
     create(1, 2);
     query(
-        "insert node doc('d2') into doc('d1')/x",
-        "doc('d1')",
+        "insert node db:open('d2') into db:open('d1')/x",
+        "db:open('d1')",
         "<x><x xmlns='xx'/></x>");
   }
 
   /**
    * Test query.
-   * @throws Exception exception
    */
   @Test
-  public void insertD3intoD1() throws Exception {
+  public void insertD3intoD1() {
     create(1, 3);
     query(
-        "insert node doc('d3') into doc('d1')/x",
-        "doc('d1')/x/*",
+        "insert node db:open('d3') into db:open('d1')/x",
+        "db:open('d1')/x/*",
         "<a:x xmlns:a='aa'><b:y xmlns:b='bb'/></a:x>");
   }
 
   /**
    * Test query.
-   * @throws Exception exception
    */
   @Test
-  public void insertD3intoD1b() throws Exception {
+  public void insertD3intoD1b() {
     create(1, 3);
     query(
-        "insert node doc('d3') into doc('d1')/x",
-        "doc('d1')/x/*/*",
+        "insert node db:open('d3') into db:open('d1')/x",
+        "db:open('d1')/x/*/*",
         "<b:y xmlns:b='bb' xmlns:a='aa'/>");
   }
 
   /**
    * Detects missing prefix declaration.
-   * @throws Exception exception
    */
   @Test
-  public void insertD4intoD1() throws Exception {
+  public void insertD4intoD1() {
     create(1, 4);
     query(
-        "declare namespace a='aa'; insert node doc('d4')/a:x/a:y " +
-        "into doc('d1')/x",
-        "doc('d1')/x",
+        "declare namespace a='aa'; insert node db:open('d4')/a:x/a:y " +
+        "into db:open('d1')/x",
+        "db:open('d1')/x",
         "<x><a:y xmlns:a='aa' xmlns:b='bb'/></x>");
   }
 
@@ -402,41 +382,38 @@ public final class NamespaceTest extends AdvancedQueryTest {
    * insert.
    * Though result correct, prefix
    * a is declared twice. -> Solution?
-   * @throws Exception exception
    */
   @Test
-  public void insertD4intoD5() throws Exception {
+  public void insertD4intoD5() {
     create(4, 5);
     query(
-        "declare namespace a='aa';insert node doc('d4')//a:y " +
-        "into doc('d5')/a:x",
-        "declare namespace a='aa';doc('d5')//a:y",
+        "declare namespace a='aa';insert node db:open('d4')//a:y " +
+        "into db:open('d5')/a:x",
+        "declare namespace a='aa';db:open('d5')//a:y",
         "<a:y xmlns:a='aa' xmlns:b='bb'/>");
   }
 
   /**
    * Detects duplicate namespace declarations in MemData instance.
-   * @throws Exception exception
    */
   @Test
-  public void insertD7intoD1() throws Exception {
+  public void insertD7intoD1() {
     create(1, 7);
     query(
-        "declare namespace x='xx';insert node doc('d7')/x:x into doc('d1')/x",
-        "doc('d1')/x",
+        "declare namespace x='xx';insert node db:open('d7')/x:x into db:open('d1')/x",
+        "db:open('d1')/x",
         "<x><x xmlns='xx'><y/></x></x>");
   }
 
   /**
    * Detects general problems with namespace references.
-   * @throws Exception exception
    */
   @Test
-  public void insertD6intoD4() throws Exception {
+  public void insertD6intoD4() {
     create(4, 6);
     query(
-        "declare namespace a='aa';insert node doc('d6') into doc('d4')/a:x",
-        "declare namespace a='aa';doc('d4')/a:x/a:y",
+        "declare namespace a='aa';insert node db:open('d6') into db:open('d4')/a:x",
+        "declare namespace a='aa';db:open('d4')/a:x/a:y",
         "<a:y xmlns:a='aa' xmlns:b='bb'/>");
   }
 
@@ -476,13 +453,12 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Detects wrong namespace references.
-   * @throws Exception exception
    */
   @Test
-  public void uriStack() throws Exception {
+  public void uriStack() {
     create(8);
     query(
-        "doc('d8')",
+        "db:open('d8')",
         "<a><b xmlns='B'/><c/></a>");
   }
 
@@ -490,12 +466,11 @@ public final class NamespaceTest extends AdvancedQueryTest {
    * Deletes the document node and checks if namespace nodes of descendants
    * are deleted as well. F.i. adding a document via REST/PUT deletes a
    * document node if the given document/name is already stored in the target
-   * collection. If the test fails, this may lead to superfluous namespace
-   * nodes.
-   * @throws Exception exception
+   * collection. If the test fails, this may lead to superfluous namespace nodes.
+   * @throws IOException I/O exception
    */
   @Test
-  public void deleteDocumentNode() throws Exception {
+  public void deleteDocumentNode() throws IOException {
     create(2);
     context.data().startUpdate(context.options);
     context.data().delete(0);
@@ -506,31 +481,28 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Checks a path optimization fix.
-   * @throws BaseXException database exception
    */
   @Test
-  public void queryPathOpt() throws BaseXException {
+  public void queryPathOpt() {
     create(17);
-    query("doc('d17')/descendant::*:b", "<b xmlns:ns='NS'/>");
+    query("db:open('d17')/descendant::*:b", "<b xmlns:ns='NS'/>");
   }
 
   /**
    * Checks a path optimization fix.
-   * @throws BaseXException database exception
    */
   @Test
-  public void queryPathOpt2() throws BaseXException {
+  public void queryPathOpt2() {
     create(17);
-    query("doc('d17')/*:a/*:b", "<b xmlns:ns='NS'/>");
+    query("db:open('d17')/*:a/*:b", "<b xmlns:ns='NS'/>");
   }
 
   /**
    * GH-249: Inserts an element with a prefixed attribute and checks
    * if there are superfluous namespace declarations for the element.
-   * @throws BaseXException database exception
    */
   @Test
-  public void superfluousPrefixDeclaration() throws BaseXException {
+  public void superfluousPrefixDeclaration() {
     create(18);
     query(
       "declare namespace ns='ns'; " +
@@ -595,7 +567,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
       "copy $a := <a xmlns:p='A' a='v'/> " +
       "modify rename node $a/@a as QName('uri', 'p:a') " +
       "return $a",
-      UPNSCONFL);
+      UPNSCONFL_X_X);
   }
 
   /**
@@ -622,7 +594,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
       "modify for $el in $a/descendant-or-self::element() return " +
       "rename node $el as QName('',local-name($el)) " +
       "return $a",
-      UPNSCONFL);
+      UPNSCONFL_X_X);
   }
 
   /**
@@ -640,10 +612,9 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Checks duplicate namespace declarations.
-   * @throws BaseXException exception
    */
   @Test
-  public void avoidDuplicateNSDeclaration() throws BaseXException {
+  public void avoidDuplicateNSDeclaration() {
     create(19);
     query(
       "let $b := <a xmlns:x='X' x:id='0'/> " +
@@ -767,7 +738,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
     try(final QueryProcessor qp = new QueryProcessor(query, context)) {
       qp.value();
     } catch(final QueryException ex) {
-      assertEquals("XUTY0004", string(ex.qname().local()));
+      assertEquals("XUTY0004", ex.error().code);
     }
     fail("should throw XUTY0004");
   }
@@ -791,27 +762,25 @@ public final class NamespaceTest extends AdvancedQueryTest {
         "(copy $c := <my:n><my:a/></my:n>" +
         "modify insert node <new/> into $c " +
         "return $c)" +
-        "return insert node $v into doc('d2')/n",
-        "namespace-uri-for-prefix('my', doc('d2')//*:new)",
+        "return insert node $v into db:open('d2')/n",
+        "namespace-uri-for-prefix('my', db:open('d2')//*:new)",
         "");
   }
 
   /**
    * Checks if a query uses the outer default namespace.
-   * @throws Exception exception
    */
   @Test
-  public void defaultNS() throws Exception {
+  public void defaultNS() {
     create(1);
-    query("<h xmlns='U'>{ doc('d1')/x }</h>/*", "");
+    query("<h xmlns='U'>{ db:open('d1')/x }</h>/*", "");
   }
 
   /**
    * Test query.
-   * @throws Exception exception
    */
   @Test
-  public void precedingSiblingNsDecl() throws Exception {
+  public void precedingSiblingNsDecl() {
     create(20);
     query("//Q{A}a", "<x:a xmlns:x='A'><x:b xmlns:x='B'/><x:c/></x:a>");
     query("//Q{A}b", "");
@@ -823,10 +792,9 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Test query.
-   * @throws Exception exception
    */
   @Test
-  public void duplicateXMLNamespace() throws Exception {
+  public void duplicateXMLNamespace() {
     create(1);
     query("insert node attribute xml:space { 'preserve' } into /x", "");
     query(".", "<x xml:space='preserve'/>");
@@ -845,7 +813,7 @@ public final class NamespaceTest extends AdvancedQueryTest {
     error("copy $c := <a xmlns='X'/> modify (" +
         "  rename node $c as QName('Y','b')," +
         "  insert node attribute c{'a'} into $c" +
-        ") return $c", UPNSCONFL);
+        ") return $c", UPNSCONFL_X_X);
     query("copy $c := <a/> modify (" +
         "  rename node $c as QName('X','b')," +
         "  insert node attribute c{'a'} into $c" +
@@ -865,23 +833,21 @@ public final class NamespaceTest extends AdvancedQueryTest {
 
   /**
    * Creates the database context.
-   * @throws BaseXException database exception
    */
   @BeforeClass
-  public static void start() throws BaseXException {
+  public static void start() {
     // turn off pretty printing
-    new Set(MainOptions.SERIALIZER, SerializerOptions.get(false)).execute(context);
+    set(MainOptions.SERIALIZER, SerializerMode.NOINDENT.get());
   }
 
   /**
    * Creates the specified test databases.
    * @param db database numbers
-   * @throws BaseXException database exception
    */
-  private static void create(final int... db) throws BaseXException {
+  private static void create(final int... db) {
     for(final int d : db) {
       final String[] doc = DOCS[d - 1];
-      new CreateDB(doc[0], doc[1]).execute(context);
+      execute(new CreateDB(doc[0], doc[1]));
     }
   }
 
@@ -902,16 +868,12 @@ public final class NamespaceTest extends AdvancedQueryTest {
    * @param expected expected output
    */
   private static void query(final String first, final String second, final String expected) {
-    try {
-      if(first != null) new XQuery(first).execute(context);
-      final String result = new XQuery(second).execute(context).trim();
+    if(first != null) Sandbox.query(first);
+    final String result = Sandbox.query(second).trim();
 
-      // quotes are replaced by apostrophes to simplify comparison
-      final String res = result.replaceAll("\"", "'");
-      final String exp = expected.replaceAll("\"", "'");
-      if(!exp.equals(res)) fail("\n[E] " + exp + "\n[F] " + res);
-    } catch(final BaseXException ex) {
-      fail(Util.message(ex));
-    }
+    // quotes are replaced by apostrophes to simplify comparison
+    final String res = result.replaceAll("\"", "'");
+    final String exp = expected.replaceAll("\"", "'");
+    if(!exp.equals(res)) fail("\n[E] " + exp + "\n[F] " + res);
   }
 }
