@@ -3,7 +3,6 @@ package org.basex.query;
 import static org.junit.Assert.*;
 
 import org.basex.*;
-import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.query.func.fn.*;
 import org.basex.query.value.*;
@@ -17,7 +16,7 @@ import org.junit.Test;
 /**
  * This class tests the database commands.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public abstract class QueryTest extends SandboxTest {
@@ -39,22 +38,17 @@ public abstract class QueryTest extends SandboxTest {
 
       try(final QueryProcessor qp = new QueryProcessor(query, context)) {
         final Value val = qp.value();
-        if(!correct || !new Compare().equal(val, cmp)) {
+        if(!correct || !new DeepEqual().equal(val, cmp)) {
           sb.append("[" + qu[0] + "] " + query);
-          String s = correct && cmp.size() != 1 ? "#" + cmp.size() : "";
-          sb.append("\n[E" + s + "] ");
+          sb.append("\n[E] " + cmp.size() + " result(s): ");
           if(correct) {
-            final String cp = cmp.serialize().toString();
-            sb.append('\'');
-            sb.append(cp.length() > 5000 ? cp.substring(0, 5000) + "..." : cp);
-            sb.append('\'');
+            for(final Item it : cmp) sb.append(it.serialize()).append(", ");
           } else {
             sb.append("error");
           }
-          final TokenBuilder types = new TokenBuilder();
-          for(final Item it : val) types.add(it.type.toString()).add(" ");
-          s = val.size() == 1 ? "" : "#" + val.size();
-          sb.append("\n[F" + s + "] '" + val + "', " + types + details() + '\n');
+          sb.append("\n[F] " + val.size() + " result(s): ");
+          for(final Item it : val) sb.append(it.serialize()).append(", ");
+          sb.append(details()).append('\n');
           ++fail;
         }
       } catch(final Exception ex) {
@@ -84,11 +78,7 @@ public abstract class QueryTest extends SandboxTest {
    * @param doc document
    */
   protected static void create(final String doc) {
-    try {
-      new CreateDB(Util.className(SandboxTest.class), doc).execute(context);
-    } catch(final BaseXException ex) {
-      Util.notExpected(ex);
-    }
+    execute(new CreateDB(Util.className(SandboxTest.class), doc));
   }
 
   /**
