@@ -12,7 +12,7 @@ import org.junit.*;
 /**
  * Tests for compiling function items.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 public final class FuncItemTest extends QueryPlanTest {
@@ -209,7 +209,7 @@ public final class FuncItemTest extends QueryPlanTest {
   @Test
   public void funcItemCoercion() {
     error("let $f := function($g as function() as item()) { $g() }" +
-        "return $f(function() { 1, 2 })", INVPROMOTE_X_X_X);
+        "return $f(function() { 1, 2 })", INVPROMOTE_X);
   }
 
   /** Checks if nested closures are inlined. */
@@ -294,7 +294,7 @@ public final class FuncItemTest extends QueryPlanTest {
   @Test
   public void gh1113() {
     check("let $join := array:join#1 return $join(([], []))",
-        "[\n]",
+        "[]",
         "empty(//" + Util.className(DynFuncCall.class) + ')',
         "empty(//" + Util.className(StaticFuncCall.class) + ')');
   }
