@@ -6,12 +6,11 @@ import static org.junit.Assert.*;
 import org.basex.query.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.node.*;
-import org.basex.util.*;
 
 /**
  * Abstract test class for properties on the Query Plan.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 public abstract class QueryPlanTest extends AdvancedQueryTest {
@@ -37,7 +36,7 @@ public abstract class QueryPlanTest extends AdvancedQueryTest {
         }
       }
     } catch(final Exception ex) {
-      final AssertionError err = new AssertionError(Util.message(ex));
+      final AssertionError err = new AssertionError(qu);
       err.initCause(ex);
       throw err;
     }
