@@ -2,13 +2,14 @@ package org.basex.query.expr;
 
 import static org.basex.query.QueryError.*;
 
+import org.basex.io.*;
 import org.basex.query.*;
 import org.junit.*;
 
 /**
  * Higher-order function tests.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Leo Woerteler
  */
 public final class HigherOrderTest extends AdvancedQueryTest {
@@ -90,10 +91,14 @@ public final class HigherOrderTest extends AdvancedQueryTest {
     error("string-join(('a', 'b'), )(',')", FUNCMISS_X);
   }
 
-  /**  Test for empty-sequence() as function item. */
+  /**  Test for invalid function expressions. */
   @Test
-  public void emptyFunTest() {
-    error("()()", EMPTYFOUND);
+  public void invalidFunTest() {
+    error("()()", NOPAREN_X_X);
+    error("1()", NOPAREN_X_X);
+    error("1.0()", NOPAREN_X_X);
+    error("1e0()", NOPAREN_X_X);
+    error("'x'()", NOPAREN_X_X);
   }
 
   /**  Tests the creation of a cast function as function item. */
@@ -120,4 +125,53 @@ public final class HigherOrderTest extends AdvancedQueryTest {
     query("declare function local:a($a) { local:b#1($a) };" +
           "declare function local:b($b) { $b }; local:a(1)", "1");
   }
+
+  /** Do not pre-evaluate function items with non-deterministic expressions (see GH-1191). */
+  @Test
+  public void nonDeterministic() {
+    final IOFile sandbox = sandbox();
+    query(
+      "let $files := ('a','b') ! (\"" + sandbox + "/\" || . || '.txt')" +
+      "return (\n" +
+      "  for $file in $files return (file:write-text($file, ?))(''),\n" +
+      "  $files ! file:exists(.),\n" +
+      "  $files ! file:delete(?)(.),\n" +
+      "  $files ! file:exists(.)\n" +
+      ")",
+      "true\ntrue\nfalse\nfalse"
+    );
+  }
+
+  /** Tests the %non-deterministic annotation (see GH-1212). */
+  @Test
+  public void ndtAnnotation() {
+    // FLWOR will be optimized away (empty result)
+    query("for $f in (prof:void#1(?), error#0) let $ignore := $f() return ()", "");
+    // FLWOR expression will be evaluated (due to non-deterministic keyword)
+    query("try {"
+        + "  let $f := error#0 let $err := non-deterministic $f() return ()"
+        + "} catch * { 'ERR' }", "ERR");
+    query("try {"
+        + "  for $f in (prof:void#1(?), error#0)"
+        + "  let $err := non-deterministic $f() return ()"
+        + "} catch * { 'ERR' }", "ERR");
+    // FLWOR expression will be evaluated (due to internal optimizations)
+    query("try {"
+        + "  let $f := error#0 let $err := $f() return ()"
+        + "} catch * { 'ERR' }", "ERR");
+    query("try {"
+        + "  let $f := function() { fn:error(()) }"
+        + "  let $e := $f()"
+        + "  return ()"
+        + "} catch * { 'ERR' }", "ERR");
+  }
+
+  /** Ensures that updating flag is not assigned before function body is known (see GH-1222). */
+  @Test
+  public void gh1222() {
+    query("declare function local:f($i) {"
+        + "  for-each($i, function($k) { if($k) then local:f('') else () })"
+        + "};"
+        + "local:f('a')", "");
+  }
 }
