@@ -4,20 +4,22 @@ import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 import static org.junit.Assert.*;
 
+import java.util.*;
+
 import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.io.*;
 import org.basex.query.*;
 import org.basex.query.util.pkg.*;
+import org.basex.query.util.pkg.Pkg;
 import org.basex.util.*;
-import org.basex.util.hash.*;
 import org.junit.*;
 import org.junit.Test;
 
 /**
  * This class tests the EXPath package API.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Rositsa Shadura
  */
 public final class PackageAPITest extends AdvancedQueryTest {
@@ -57,29 +59,29 @@ public final class PackageAPITest extends AdvancedQueryTest {
   @Test
   public void repoInit() {
     // check namespace dictionary
-    final TokenObjMap<TokenSet> nsDict = context.repo.nsDict();
-    final TokenMap pkgDict = context.repo.pkgDict();
+    final HashMap<String, HashSet<String>> nsDict = context.repo.nsDict();
+    final HashMap<String, Pkg> pkgDict = context.repo.pkgDict();
 
     assertEquals(3, nsDict.size());
-    assertTrue(nsDict.contains(token("ns1")));
-    assertTrue(nsDict.contains(token("ns2")));
-    assertTrue(nsDict.contains(token("ns3")));
-    TokenSet ts = nsDict.get(token("ns1"));
+    assertTrue(nsDict.containsKey("ns1"));
+    assertTrue(nsDict.containsKey("ns2"));
+    assertTrue(nsDict.containsKey("ns3"));
+    HashSet<String> ts = nsDict.get("ns1");
     assertEquals(ts.size(), 2);
-    assertTrue(ts.contains(token(PKG1ID)));
-    assertTrue(ts.contains(token(PKG2ID)));
-    ts = nsDict.get(token("ns2"));
+    assertTrue(ts.contains(PKG1ID));
+    assertTrue(ts.contains(PKG2ID));
+    ts = nsDict.get("ns2");
     assertEquals(ts.size(), 1);
-    assertTrue(ts.contains(token(PKG1ID)));
-    ts = nsDict.get(token("ns3"));
+    assertTrue(ts.contains(PKG1ID));
+    ts = nsDict.get("ns3");
     assertEquals(ts.size(), 1);
-    assertTrue(ts.contains(token(PKG2ID)));
+    assertTrue(ts.contains(PKG2ID));
     // check package dictionary
     assertEquals(pkgDict.size(), 2);
-    assertTrue(pkgDict.contains(token(PKG1ID)));
-    assertTrue(pkgDict.contains(token(PKG2ID)));
-    assertEquals("pkg1", string(pkgDict.get(token(PKG1ID))));
-    assertEquals("pkg2", string(pkgDict.get(token(PKG2ID))));
+    assertTrue(pkgDict.containsKey(PKG1ID));
+    assertTrue(pkgDict.containsKey(PKG2ID));
+    assertEquals("pkg1", pkgDict.get(PKG1ID).dir());
+    assertEquals("pkg2", pkgDict.get(PKG2ID).dir());
   }
 
   /** Test for missing mandatory attributes. */
@@ -219,10 +221,9 @@ public final class PackageAPITest extends AdvancedQueryTest {
 
   /**
    * Tests package installation.
-   * @throws BaseXException database exception
    */
   @Test
-  public void repoInstall() throws BaseXException {
+  public void repoInstall() {
     // try to install non-existing package
     try {
       new RepoManager(context).install("src/test/resources/pkg");
@@ -232,7 +233,7 @@ public final class PackageAPITest extends AdvancedQueryTest {
     }
 
     // try to install a XAR package
-    new RepoInstall(REPO + "pkg3.xar", null).execute(context);
+    execute(new RepoInstall(REPO + "pkg3.xar", null));
     final String dir = normalize(PKG3ID);
     assertTrue(isDir(dir));
     assertTrue(isFile(dir + "/expath-pkg.xml"));
@@ -242,7 +243,7 @@ public final class PackageAPITest extends AdvancedQueryTest {
     assertTrue(new IOFile(REPO, dir).delete());
 
     // try to install a URN package
-    new RepoInstall(REPO + "12345.xqm", null).execute(context);
+    execute(new RepoInstall(REPO + "12345.xqm", null));
     assertTrue(isFile("urn/isbn/12345.xqm"));
   }
 
@@ -253,7 +254,7 @@ public final class PackageAPITest extends AdvancedQueryTest {
   @Test
   public void installJar() throws Exception {
     // install package
-    new RepoInstall(REPO + "testJar.xar", null).execute(context);
+    execute(new RepoInstall(REPO + "testJar.xar", null));
 
     // ensure package was properly installed
     final String dir = normalize("jarPkg-1.0.0");
@@ -294,10 +295,9 @@ public final class PackageAPITest extends AdvancedQueryTest {
 
   /**
    * Tests package delete.
-   * @throws BaseXException database exception
    */
   @Test
-  public void delete() throws BaseXException {
+  public void delete() {
     // try to delete a package which is not installed
     try {
       new RepoManager(context).delete("xyz");
@@ -306,10 +306,10 @@ public final class PackageAPITest extends AdvancedQueryTest {
       check(null, ex, BXRE_WHICH_X);
     }
     // install a package without dependencies (pkg3)
-    new RepoInstall(REPO + "pkg3.xar", null).execute(context);
+    execute(new RepoInstall(REPO + "pkg3.xar", null));
 
     // check if pkg3 is registered in the repo
-    assertTrue(context.repo.pkgDict().contains(token(PKG3ID)));
+    assertTrue(context.repo.pkgDict().containsKey(PKG3ID));
 
     // check if pkg3 was correctly unzipped
     final String pkg3Dir = normalize(PKG3ID);
@@ -320,9 +320,9 @@ public final class PackageAPITest extends AdvancedQueryTest {
     assertTrue(isFile(pkg3Dir + "/pkg3/mod/pkg3mod1.xql"));
 
     // install another package (pkg4) with a dependency to pkg3
-    new RepoInstall(REPO + "pkg4.xar", null).execute(context);
+    execute(new RepoInstall(REPO + "pkg4.xar", null));
     // check if pkg4 is registered in the repo
-    assertTrue(context.repo.pkgDict().contains(token(PKG4ID)));
+    assertTrue(context.repo.pkgDict().containsKey(PKG4ID));
     // check if pkg4 was correctly unzipped
     final String pkg4Dir = normalize(PKG4ID);
     assertTrue(isDir(pkg4Dir));
@@ -339,16 +339,16 @@ public final class PackageAPITest extends AdvancedQueryTest {
       check(null, ex, BXRE_DEP_X_X);
     }
     // try to delete pkg4 (use package name)
-    new RepoDelete(PKG4, null).execute(context);
+    execute(new RepoDelete(PKG4, null));
     // check if pkg4 is unregistered from the repo
-    assertFalse(context.repo.pkgDict().contains(token(PKG4ID)));
+    assertFalse(context.repo.pkgDict().containsKey(PKG4ID));
 
     // check if pkg4 directory was deleted
     assertFalse(isDir(pkg4Dir));
     // try to delete pkg3 (use package dir)
-    new RepoDelete(PKG3ID, null).execute(context);
+    execute(new RepoDelete(PKG3ID, null));
     // check if pkg3 is unregistered from the repo
-    assertFalse(context.repo.pkgDict().contains(token(PKG3ID)));
+    assertFalse(context.repo.pkgDict().containsKey(PKG3ID));
     // check if pkg3 directory was deleted
     assertFalse(isDir(pkg3Dir));
   }
@@ -372,9 +372,7 @@ public final class PackageAPITest extends AdvancedQueryTest {
    */
   private static IOContent desc(final String name, final String abbrev, final String version,
       final String cont) {
-
-    return new IOContent(concat(Util.inf(HEADER, name, abbrev, version),
-        token(cont), FOOTER));
+    return new IOContent(concat(Util.inf(HEADER, name, abbrev, version), token(cont), FOOTER));
   }
 
   /**
