@@ -8,15 +8,15 @@ import org.junit.*;
 /**
  * This class tests the functions of the Math Module.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class MathModuleTest extends AdvancedQueryTest {
   /** Test method. */
   @Test
   public void crc32() {
-    query(_MATH_CRC32.args(""), "00000000");
-    query(_MATH_CRC32.args("BaseX"), "4C06FC7F");
+    query(STRING.args(_MATH_CRC32.args("")), "00000000");
+    query(STRING.args(_MATH_CRC32.args("BaseX")), "4C06FC7F");
   }
 
   /** Test method. */
