@@ -5,7 +5,7 @@ import org.basex.query.*;
 /**
  * Simple XQuery tests.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Christian Gruen
  */
 public final class SimpleTest extends QueryTest {
@@ -73,11 +73,13 @@ public final class SimpleTest extends QueryTest {
       { "And 1", booleans(true), "<a/> and <a/>" },
       { "And 2", booleans(true), "<a/> and (<a/> and <a/>)" },
       { "And 3", booleans(false), "<a/> and (<a/> and not(<a/>))" },
+      { "And 4", booleans(false), "0 and (1 + 'x')" },
 
       { "Or 1", booleans(true), "<a/> or <a/>" },
       { "Or 2", booleans(true), "<a/> or (<a/> or <a/>)" },
       { "Or 3", booleans(false), "not(<a/>) or (not(<a/>) or not(<a/>))" },
       { "Or 4", booleans(true), "fold-left(true(), false(), function($a, $b) { $a or $b })" },
+      { "Or 5", booleans(true), "1 or (1 + 'x')" },
 
       { "Seq 1", integers(), "((( )  )    )" },
       { "Seq 2", integers(1), "((( 1 )  )    )" },
@@ -87,6 +89,11 @@ public final class SimpleTest extends QueryTest {
       { "Seq 6", "()()" },
       { "Seq 7", "() ()" },
 
+      { "IntersectExcept 1", empty(), "<a/> intersect <b/>" },
+      { "IntersectExcept 2", empty(), "<a/> intersect <b/> except <c/>" },
+      { "IntersectExcept 3", empty(), "<a/> except <b/> intersect <c/>" },
+      { "IntersectExcept 4", integers(1), "count(<a/> except <b/>)" },
+
       { "Filter 1", "1[1][error()]" },
       { "Filter 2", empty(), "1[1][<x/>/a]" },
       { "Filter 3", strings("b"), "name(<x><a/><b c='d'/></x>/(a,b)[@c])" },
@@ -115,6 +122,7 @@ public final class SimpleTest extends QueryTest {
 
       { "Path 1", empty(), "<a/>[./(@*)]" },
       { "Path 2", strings("A", "B"), "<_><x><x>A</x>B</x></_>//x/node()[last()] ! string()" },
+      { "Path 3", integers(2, 2), "<a><b/><b/></a>/b/last()" },
 
       { "Cast 1", integers(1), "xs:integer('+1')" },
       { "Cast 2", "xs:integer('++1')" },
