@@ -5,13 +5,11 @@ import static org.junit.Assert.*;
 import java.util.*;
 import java.util.List;
 
-import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.data.*;
 import org.basex.query.*;
 import org.basex.query.up.primitives.*;
 import org.basex.query.up.primitives.node.*;
-import org.basex.util.*;
 import org.junit.*;
 import org.junit.Test;
 import org.junit.rules.*;
@@ -20,7 +18,7 @@ import org.junit.rules.*;
  * Tests {@link NodeUpdateComparator} that creates an order on update primitives
  * and is part of the XQuery Update Facility implementation.
  *
- * @author BaseX Team 2005-15, BSD License
+ * @author BaseX Team 2005-16, BSD License
  * @author Lukas Kircher
  */
 public final class NodeUpdateComparatorTest extends AdvancedQueryTest {
@@ -490,11 +488,7 @@ public final class NodeUpdateComparatorTest extends AdvancedQueryTest {
    * @return database instance
    */
   private static Data data(final String s) {
-    try {
-      new CreateDB(NAME, s).execute(context);
-    } catch(final BaseXException ex) {
-      fail(Util.message(ex));
-    }
+    execute(new CreateDB(NAME, s));
     return context.data();
   }
 
